from module_constants import *
from ID_factions import *
from header_items import  *
from header_operations import *
from header_triggers import *

####################################################################################################################
#  Each item record contains the following fields:
#  1) Item id: used for referencing items in other files.
#     The prefix itm_ is automatically added before each item id.
#  2) Item name. Name of item as it'll appear in inventory window
#  3) List of meshes.  Each mesh record is a tuple containing the following fields:
#    3.1) Mesh name.
#    3.2) Modifier bits that this mesh matches.
#     Note that the first mesh record is the default.
#  4) Item flags. See header_items.py for a list of available flags.
#  5) Item capabilities. Used for which animations this item is used with. See header_items.py for a list of available flags.
#  6) Item value.
#  7) Item stats: Bitwise-or of various stats about the item such as:
#      weight, abundance, difficulty, head_armor, body_armor,leg_armor, etc...
#  8) Modifier bits: Modifiers that can be applied to this item.
#  9) [Optional] Triggers: List of simple triggers to be associated with the item.
#  10) [Optional] Factions: List of factions that item can be found as merchandise.
####################################################################################################################

# Some constants for ease of use.
imodbits_none = 0
imodbits_horse_basic = imodbit_swaybacked|imodbit_lame|imodbit_spirited|imodbit_heavy|imodbit_stubborn
imodbits_cloth  = imodbit_tattered | imodbit_ragged | imodbit_sturdy | imodbit_thick | imodbit_hardened
imodbits_armor  = imodbit_rusty | imodbit_battered | imodbit_crude | imodbit_thick | imodbit_reinforced |imodbit_lordly
imodbits_plate  = imodbit_cracked | imodbit_rusty | imodbit_battered | imodbit_crude | imodbit_thick | imodbit_reinforced |imodbit_lordly
imodbits_polearm = imodbit_cracked | imodbit_bent | imodbit_balanced
imodbits_shield  = imodbit_cracked | imodbit_battered |imodbit_thick | imodbit_reinforced
imodbits_sword   = imodbit_rusty | imodbit_chipped | imodbit_balanced |imodbit_tempered
imodbits_sword_high   = imodbit_rusty | imodbit_chipped | imodbit_balanced |imodbit_tempered|imodbit_masterwork
imodbits_axe   = imodbit_rusty | imodbit_chipped | imodbit_heavy
imodbits_mace   = imodbit_rusty | imodbit_chipped | imodbit_heavy
imodbits_pick   = imodbit_rusty | imodbit_chipped | imodbit_balanced | imodbit_heavy
imodbits_bow = imodbit_cracked | imodbit_bent | imodbit_strong |imodbit_masterwork
imodbits_crossbow = imodbit_cracked | imodbit_bent | imodbit_masterwork
imodbits_missile   = imodbit_bent | imodbit_balanced| imodbit_large_bag
imodbits_thrown   = imodbit_bent | imodbit_heavy| imodbit_balanced| imodbit_large_bag
imodbits_thrown_minus_heavy = imodbit_bent | imodbit_balanced| imodbit_large_bag

imodbits_horse_good = imodbit_spirited|imodbit_heavy
imodbits_good   = imodbit_sturdy | imodbit_thick | imodbit_hardened | imodbit_reinforced
imodbits_bad    = imodbit_rusty | imodbit_chipped | imodbit_tattered | imodbit_ragged | imodbit_cracked | imodbit_bent
# Replace winged mace/spiked mace with: Flanged mace / Knobbed mace?
# Fauchard (majowski glaive) 
items = [
# item_name, mesh_name, item_properties, item_capabilities, slot_no, cost, bonus_flags, weapon_flags, scale, view_dir, pos_offset
 ["no_item","INVALID ITEM", [("invalid_item",0)], itp_type_one_handed_wpn|itp_primary|itp_secondary, itc_longsword, 3,weight(1.5)|spd_rtng(103)|weapon_length(90)|swing_damage(16,blunt)|thrust_damage(10,blunt),imodbits_none],

 ["tutorial_spear", "Spear", [("spear",0)], itp_type_polearm| itp_primary|itp_penalty_with_shield|itp_wooden_parry, itc_spear, 0 , weight(4.5)|difficulty(0)|spd_rtng(80) | weapon_length(158)|swing_damage(0 , cut) | thrust_damage(19 ,  pierce),imodbits_polearm ],
 ["tutorial_club", "Club", [("club",0)], itp_type_one_handed_wpn| itp_primary|itp_wooden_parry|itp_wooden_attack, itc_scimitar, 0 , weight(2.5)|difficulty(0)|spd_rtng(95) | weapon_length(95)|swing_damage(11 , blunt) | thrust_damage(0 ,  pierce),imodbits_none ],
 ["tutorial_battle_axe", "Battle Axe", [("battle_ax",0)], itp_type_two_handed_wpn| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry, itc_nodachi|itcf_carry_axe_back, 0 , weight(5)|difficulty(0)|spd_rtng(88) | weapon_length(108)|swing_damage(27 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
 ["tutorial_arrows","Arrows", [("arrow",0),("flying_missile",ixmesh_flying_ammo),("quiver", ixmesh_carry)], itp_type_arrows, itcf_carry_quiver_back, 0,weight(3)|abundance(160)|weapon_length(95)|thrust_damage(0,pierce)|max_ammo(20),imodbits_missile],
 ["tutorial_bolts","Bolts", [("bolt",0),("flying_missile",ixmesh_flying_ammo),("bolt_bag", ixmesh_carry),("bolt_bag_b", ixmesh_carry|imodbit_large_bag)], itp_type_bolts, itcf_carry_quiver_right_vertical, 0,weight(2.25)|abundance(90)|weapon_length(55)|thrust_damage(0,pierce)|max_ammo(18),imodbits_missile],
 ["tutorial_short_bow", "Short Bow", [("short_bow",0),("short_bow_carry",ixmesh_carry)], itp_type_bow |itp_primary|itp_two_handed ,itcf_shoot_bow|itcf_carry_bow_back, 0 , weight(1)|difficulty(0)|spd_rtng(98) | shoot_speed(49) | thrust_damage(12 ,  pierce  ),imodbits_bow ],
 ["tutorial_crossbow", "Crossbow", [("crossbow",0)], itp_type_crossbow |itp_primary|itp_two_handed|itp_cant_reload_on_horseback ,itcf_shoot_crossbow|itcf_carry_crossbow_back, 0 , weight(3)|difficulty(0)|spd_rtng(42)|  shoot_speed(68) | thrust_damage(32,pierce)|max_ammo(1),imodbits_crossbow ],
 ["tutorial_throwing_daggers", "Throwing Daggers", [("throwing_dagger",0)], itp_type_thrown |itp_primary ,itcf_throw_knife, 0 , weight(3.5)|difficulty(0)|spd_rtng(102) | shoot_speed(25) | thrust_damage(16 ,  cut)|max_ammo(14)|weapon_length(0),imodbits_missile ],
 ["tutorial_saddle_horse", "Saddle Horse", [("saddle_horse",0)], itp_type_horse, 0, 0,abundance(90)|body_armor(3)|difficulty(0)|horse_speed(40)|horse_maneuver(38)|horse_charge(8),imodbits_horse_basic],
 ["tutorial_shield", "Kite Shield", [("shield_kite_a",0)], itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  118 , weight(2.5)|hit_points(480)|body_armor(1)|spd_rtng(82)|weapon_length(150),imodbits_shield ],
 ["tutorial_staff_no_attack","Staff", [("wooden_staff",0)],itp_type_polearm|itp_offset_lance|itp_primary|itp_penalty_with_shield|itp_wooden_parry|itp_wooden_attack,itc_parry_polearm|itcf_carry_sword_back,9, weight(3.5)|spd_rtng(120) | weapon_length(115)|swing_damage(0,blunt) | thrust_damage(0,blunt),imodbits_none],
 ["tutorial_staff","Staff", [("wooden_staff",0)],itp_type_polearm|itp_offset_lance|itp_primary|itp_penalty_with_shield|itp_wooden_parry|itp_wooden_attack,itc_staff|itcf_carry_sword_back,9, weight(3.5)|spd_rtng(120) | weapon_length(115)|swing_damage(16,blunt) | thrust_damage(16,blunt),imodbits_none],
 ["tutorial_sword", "Sword", [("long_sword",0),("scab_longsw_a", ixmesh_carry)], itp_type_one_handed_wpn|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn, 0 , weight(1.5)|difficulty(0)|spd_rtng(100) | weapon_length(102)|swing_damage(18 , cut) | thrust_damage(15 ,  pierce),imodbits_sword ],
 ["tutorial_axe", "Axe", [("iron_ax",0)], itp_type_two_handed_wpn| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry, itc_nodachi|itcf_carry_axe_back, 0 , weight(4)|difficulty(0)|spd_rtng(91) | weapon_length(108)|swing_damage(19 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],

 ["tutorial_dagger","Dagger", [("practice_dagger",0)], itp_type_one_handed_wpn|itp_primary|itp_secondary, itc_longsword, 3,weight(1.5)|spd_rtng(103)|weapon_length(40)|swing_damage(16,blunt)|thrust_damage(10,blunt),imodbits_none],


 ["horse_meat","Horse Meat", [("raw_meat",0)], itp_type_goods|itp_consumable|itp_food, 0, 12,weight(40)|food_quality(30)|max_ammo(40),imodbits_none],
# Items before this point are hardwired and their order should not be changed!
 ["practice_sword","Practice Sword", [("practice_sword",0)], itp_type_one_handed_wpn|itp_primary|itp_secondary|itp_wooden_parry|itp_wooden_attack, itc_longsword, 3,weight(1.5)|spd_rtng(103)|weapon_length(90)|swing_damage(22,blunt)|thrust_damage(20,blunt),imodbits_none],
 ["heavy_practice_sword","Heavy Practice Sword", [("heavy_practicesword",0)], itp_type_two_handed_wpn|itp_two_handed|itp_primary|itp_wooden_parry|itp_wooden_attack, itc_greatsword,
    21, weight(6.25)|spd_rtng(94)|weapon_length(128)|swing_damage(30,blunt)|thrust_damage(24,blunt),imodbits_none],
 ["practice_dagger","Practice Dagger", [("practice_dagger",0)], itp_type_one_handed_wpn|itp_primary|itp_secondary|itp_no_parry|itp_wooden_attack, itc_dagger|itcf_carry_dagger_front_left, 2,weight(0.5)|spd_rtng(110)|weapon_length(47)|swing_damage(16,blunt)|thrust_damage(14,blunt),imodbits_none],
 ["practice_axe", "Practice Axe", [("hatchet",0)], itp_type_one_handed_wpn| itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_axe_left_hip, 24 , weight(2) | spd_rtng(95) | weapon_length(75) | swing_damage(24, blunt) | thrust_damage(0, pierce), imodbits_axe],
 ["arena_axe", "Axe", [("arena_axe",0)], itp_type_one_handed_wpn|itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_axe_left_hip,
 137 , weight(1.5)|spd_rtng(100) | weapon_length(69)|swing_damage(24 , blunt) | thrust_damage(0 ,  pierce),imodbits_axe ],
 ["arena_sword", "Sword", [("arena_sword_one_handed",0),("sword_medieval_b_scabbard", ixmesh_carry),], itp_type_one_handed_wpn|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 243 , weight(1.5)|spd_rtng(99) | weapon_length(95)|swing_damage(22 , blunt) | thrust_damage(20 ,  blunt),imodbits_sword_high ],
 ["arena_sword_two_handed",  "Two Handed Sword", [("arena_sword_two_handed",0)], itp_type_two_handed_wpn|itp_two_handed|itp_primary, itc_greatsword|itcf_carry_sword_back,
 670 , weight(2.75)|spd_rtng(93) | weapon_length(110)|swing_damage(30 , blunt) | thrust_damage(24 ,  blunt),imodbits_sword_high ],
 ["arena_lance",         "Lance", [("arena_lance",0)], itp_couchable|itp_type_polearm|itp_offset_lance|itp_primary|itp_penalty_with_shield|itp_wooden_parry, itc_staff|itcf_carry_spear,
 90 , weight(2.5)|spd_rtng(96) | weapon_length(150)|swing_damage(20 , blunt) | thrust_damage(25 ,  blunt),imodbits_polearm ],
 ["practice_staff","Practice Staff", [("wooden_staff",0)],itp_type_polearm|itp_offset_lance|itp_primary|itp_penalty_with_shield|itp_wooden_parry|itp_wooden_attack,itc_staff|itcf_carry_sword_back,9, weight(2.5)|spd_rtng(103) | weapon_length(118)|swing_damage(18,blunt) | thrust_damage(18,blunt),imodbits_none],
 ["practice_lance","Practice Lance", [("joust_of_peace",0)], itp_couchable|itp_type_polearm|itp_primary|itp_penalty_with_shield|itp_wooden_parry|itp_wooden_attack, itc_greatlance, 18,weight(4.25)|spd_rtng(58)|weapon_length(240)|swing_damage(0,blunt)|thrust_damage(15,blunt),imodbits_none],
 ["practice_shield","Practice Shield", [("shield_round_a",0)], itp_type_shield|itp_wooden_parry, itcf_carry_round_shield, 20,weight(3.5)|body_armor(1)|hit_points(200)|spd_rtng(100)|shield_width(50),imodbits_none],
 ["practice_bow","Practice Bow", [("hunting_bow",0), ("hunting_bow_carry",ixmesh_carry)], itp_type_bow |itp_primary|itp_two_handed,itcf_shoot_bow|itcf_carry_bow_back, 0, weight(1.5)|spd_rtng(90) | shoot_speed(40) | thrust_damage(5, blunt),imodbits_bow ],
##                                                     ("hunting_bow",0)],                  itp_type_bow|itp_two_handed|itp_primary|itp_attach_left_hand, itcf_shoot_bow, 4,weight(1.5)|spd_rtng(90)|shoot_speed(40)|thrust_damage(19,blunt),imodbits_none],
 ["practice_crossbow", "Practice Crossbow", [("crossbow_a",0)], itp_type_crossbow |itp_primary|itp_two_handed ,itcf_shoot_crossbow|itcf_carry_crossbow_back, 0, weight(3)|spd_rtng(42)| shoot_speed(68) | thrust_damage(32,blunt)|max_ammo(1),imodbits_crossbow],
 ["practice_javelin", "Practice Javelins", [("javelin",0),("javelins_quiver_new", ixmesh_carry)], itp_type_thrown |itp_primary|itp_next_item_as_melee,itcf_throw_javelin|itcf_carry_quiver_back|itcf_show_holster_when_drawn, 0, weight(5) | spd_rtng(91) | shoot_speed(28) | thrust_damage(27, blunt) | max_ammo(50) | weapon_length(75), imodbits_thrown],
 ["practice_javelin_melee", "practice_javelin_melee", [("javelin",0)], itp_type_polearm|itp_primary|itp_penalty_with_shield|itp_wooden_parry , itc_staff, 0, weight(1)|difficulty(0)|spd_rtng(91) |swing_damage(12, blunt)| thrust_damage(14,  blunt)|weapon_length(75),imodbits_polearm ],
 ["practice_throwing_daggers", "Throwing Daggers", [("throwing_dagger",0)], itp_type_thrown |itp_primary ,itcf_throw_knife, 0 , weight(3.5)|spd_rtng(102) | shoot_speed(25) | thrust_damage(16, blunt)|max_ammo(10)|weapon_length(0),imodbits_thrown ],
 ["practice_throwing_daggers_100_amount", "Throwing Daggers", [("throwing_dagger",0)], itp_type_thrown |itp_primary ,itcf_throw_knife, 0 , weight(3.5)|spd_rtng(102) | shoot_speed(25) | thrust_damage(16, blunt)|max_ammo(100)|weapon_length(0),imodbits_thrown ],
# ["cheap_shirt","Cheap Shirt", [("shirt",0)], itp_type_body_armor|itp_covers_legs, 0, 4,weight(1.25)|body_armor(3),imodbits_none],
 ["practice_horse","Practice Horse", [("saddle_horse",0)], itp_type_horse, 0, 37,
 hit_points(50)|difficulty(1)|horse_speed(40)|horse_maneuver(40)|horse_charge(5),imodbits_none],
 ["practice_arrows","Practice Arrows", [("arena_arrow",0),("flying_missile",ixmesh_flying_ammo),("quiver", ixmesh_carry)], itp_type_arrows, itcf_carry_quiver_back, 0,weight(1.5)|weapon_length(95)|max_ammo(80),imodbits_missile],
## ["practice_arrows","Practice Arrows", [("arrow",0),("flying_missile",ixmesh_flying_ammo)], itp_type_arrows, 0, 31,weight(1.5)|weapon_length(95)|max_ammo(80),imodbits_none],
 ["practice_bolts","Practice Bolts", [("bolt",0),("flying_missile",ixmesh_flying_ammo),("bolt_bag", ixmesh_carry),("bolt_bag_b", ixmesh_carry|imodbit_large_bag)], itp_type_bolts, itcf_carry_quiver_right_vertical, 0,weight(2.25)|weapon_length(55)|max_ammo(49),imodbits_missile],
 ["practice_arrows_10_amount","Practice Arrows", [("arena_arrow",0),("flying_missile",ixmesh_flying_ammo),("quiver", ixmesh_carry)], itp_type_arrows, itcf_carry_quiver_back, 0,weight(1.5)|weapon_length(95)|max_ammo(10),imodbits_missile],
 ["practice_arrows_100_amount","Practice Arrows", [("arrow",0),("flying_missile",ixmesh_flying_ammo),("quiver", ixmesh_carry)], itp_type_arrows, itcf_carry_quiver_back, 0,weight(1.5)|weapon_length(95)|max_ammo(100),imodbits_missile],
 ["practice_bolts_9_amount","Practice Bolts", [("bolt",0),("flying_missile",ixmesh_flying_ammo),("bolt_bag", ixmesh_carry),("bolt_bag_b", ixmesh_carry|imodbit_large_bag)], itp_type_bolts, itcf_carry_quiver_right_vertical, 0,weight(2.25)|weapon_length(55)|max_ammo(9),imodbits_missile],
 ["practice_boots", "Practice Boots", [("boot_nomad_a",0)], itp_type_foot_armor |itp_civilian  | itp_attach_armature,0, 11 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(10), imodbits_cloth ],
 ["red_tourney_armor","Red Tourney Armor", [("tourn_armor_a",0)], itp_type_body_armor|itp_covers_legs, 0, 152,weight(15.0)|body_armor(20)|leg_armor(6),imodbits_none],
 ["blue_tourney_armor","Blue Tourney Armor", [("mail_shirt",0)], itp_type_body_armor|itp_covers_legs, 0, 152,weight(15.0)|body_armor(20)|leg_armor(6),imodbits_none],
 ["green_tourney_armor","Green Tourney Armor", [("leather_vest",0)], itp_type_body_armor|itp_covers_legs, 0, 152,weight(15.0)|body_armor(20)|leg_armor(6),imodbits_none],
 ["gold_tourney_armor","Gold Tourney Armor", [("padded_armor",0)], itp_type_body_armor|itp_covers_legs, 0, 152,weight(15.0)|body_armor(20)|leg_armor(6),imodbits_none],
 ["red_tourney_helmet","Red Tourney Helmet",[("flattop_helmet",0)],itp_type_head_armor,0,126, weight(2)|head_armor(16),imodbits_none],
 ["blue_tourney_helmet","Blue Tourney Helmet",[("segmented_helm",0)],itp_type_head_armor,0,126, weight(2)|head_armor(16),imodbits_none],
 ["green_tourney_helmet","Green Tourney Helmet",[("hood_c",0)],itp_type_head_armor,0,126, weight(2)|head_armor(16),imodbits_none],
 ["gold_tourney_helmet","Gold Tourney Helmet",[("hood_a",0)],itp_type_head_armor,0,126, weight(2)|head_armor(16),imodbits_none],

["arena_shield_red", "Shield", [("arena_shield_red",0)], itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  42 , weight(2)|hit_points(360)|body_armor(1)|spd_rtng(100)|weapon_length(60),imodbits_shield ],
["arena_shield_blue", "Shield", [("arena_shield_blue",0)], itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  42 , weight(2)|hit_points(360)|body_armor(1)|spd_rtng(100)|weapon_length(60),imodbits_shield ],
["arena_shield_green", "Shield", [("arena_shield_green",0)], itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  42 , weight(2)|hit_points(360)|body_armor(1)|spd_rtng(100)|weapon_length(60),imodbits_shield ],
["arena_shield_yellow", "Shield", [("arena_shield_yellow",0)], itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  42 , weight(2)|hit_points(360)|body_armor(1)|spd_rtng(100)|weapon_length(60),imodbits_shield ],

["arena_armor_white", "Arena Armor White", [("arena_armorW_new",0)], itp_type_body_armor  |itp_covers_legs ,0, 650 , weight(16)|abundance(100)|head_armor(0)|body_armor(29)|leg_armor(13), imodbits_armor ],
["arena_armor_red", "Arena Armor Red", [("arena_armorR_new",0)], itp_type_body_armor  |itp_covers_legs ,0, 650 , weight(16)|abundance(100)|head_armor(0)|body_armor(29)|leg_armor(13), imodbits_armor ],
["arena_armor_blue", "Arena Armor Blue", [("arena_armorB_new",0)], itp_type_body_armor  |itp_covers_legs ,0, 650 , weight(16)|abundance(100)|head_armor(0)|body_armor(29)|leg_armor(13), imodbits_armor ],
["arena_armor_green", "Arena Armor Green", [("arena_armorG_new",0)], itp_type_body_armor  |itp_covers_legs ,0, 650 , weight(16)|abundance(100)|head_armor(0)|body_armor(29)|leg_armor(13), imodbits_armor ],
["arena_armor_yellow", "Arena Armor Yellow", [("arena_armorY_new",0)], itp_type_body_armor  |itp_covers_legs ,0, 650 , weight(16)|abundance(100)|head_armor(0)|body_armor(29)|leg_armor(13), imodbits_armor ],
["arena_tunic_white", "Arena Tunic White ", [("arena_tunicW_new",0)], itp_type_body_armor |itp_covers_legs ,0, 47 , weight(2)|abundance(100)|head_armor(0)|body_armor(16)|leg_armor(6), imodbits_cloth ],
["arena_tunic_red", "Arena Tunic Red", [("arena_tunicR_new",0)], itp_type_body_armor |itp_covers_legs ,0, 27 , weight(2)|abundance(100)|head_armor(0)|body_armor(16)|leg_armor(6), imodbits_cloth ], 
["arena_tunic_blue", "Arena Tunic Blue", [("arena_tunicB_new",0)], itp_type_body_armor |itp_covers_legs ,0, 27 , weight(2)|abundance(100)|head_armor(0)|body_armor(16)|leg_armor(6), imodbits_cloth ], 
["arena_tunic_green", "Arena Tunic Green", [("arena_tunicG_new",0)], itp_type_body_armor |itp_covers_legs ,0, 27 , weight(2)|abundance(100)|head_armor(0)|body_armor(16)|leg_armor(6), imodbits_cloth ],
["arena_tunic_yellow", "Arena Tunic Yellow", [("arena_tunicY_new",0)], itp_type_body_armor |itp_covers_legs ,0, 27 , weight(2)|abundance(100)|head_armor(0)|body_armor(16)|leg_armor(6), imodbits_cloth ],
#headwear
["arena_helmet_red", "Arena Helmet Red", [("arena_helmetR",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(26)|body_armor(0)|leg_armor(0), imodbits_plate ],
["arena_helmet_blue", "Arena Helmet Blue", [("arena_helmetB",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(26)|body_armor(0)|leg_armor(0), imodbits_plate ],
["arena_helmet_green", "Arena Helmet Green", [("arena_helmetG",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(26)|body_armor(0)|leg_armor(0), imodbits_plate ],
["arena_helmet_yellow", "Arena Helmet Yellow", [("arena_helmetY",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(26)|body_armor(0)|leg_armor(0), imodbits_plate ],
["steppe_helmet_white", "Steppe Helmet White", [("steppe_helmetW",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0), imodbits_plate ], 
["steppe_helmet_red", "Steppe Helmet Red", [("steppe_helmetR",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0), imodbits_plate ], 
["steppe_helmet_blue", "Steppe Helmet Blue", [("steppe_helmetB",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0), imodbits_plate ], 
["steppe_helmet_green", "Steppe Helmet Green", [("steppe_helmetG",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0), imodbits_plate ], 
["steppe_helmet_yellow", "Steppe Helmet Yellow", [("steppe_helmetY",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0), imodbits_plate ], 
["tourney_helm_white", "Tourney Helm White", [("tourney_helmR",0)], itp_type_head_armor|itp_covers_head,0, 760 , weight(2.75)|abundance(100)|head_armor(30)|body_armor(0)|leg_armor(0), imodbits_plate ],
["tourney_helm_red", "Tourney Helm Red", [("tourney_helmR",0)], itp_type_head_armor|itp_covers_head,0, 760 , weight(2.75)|abundance(100)|head_armor(30)|body_armor(0)|leg_armor(0), imodbits_plate ],
["tourney_helm_blue", "Tourney Helm Blue", [("tourney_helmB",0)], itp_type_head_armor|itp_covers_head,0, 760 , weight(2.75)|abundance(100)|head_armor(30)|body_armor(0)|leg_armor(0), imodbits_plate ],
["tourney_helm_green", "Tourney Helm Green", [("tourney_helmG",0)], itp_type_head_armor|itp_covers_head,0, 760 , weight(2.75)|abundance(100)|head_armor(30)|body_armor(0)|leg_armor(0), imodbits_plate ],
["tourney_helm_yellow", "Tourney Helm Yellow", [("tourney_helmY",0)], itp_type_head_armor|itp_covers_head,0, 760 , weight(2.75)|abundance(100)|head_armor(30)|body_armor(0)|leg_armor(0), imodbits_plate ],
["arena_turban_red", "Arena Turban", [("tuareg_open",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(26)|body_armor(0)|leg_armor(0), imodbits_plate ],
["arena_turban_blue", "Arena Turban", [("tuareg_open",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(26)|body_armor(0)|leg_armor(0), imodbits_plate ],
["arena_turban_green", "Arena Turban", [("tuareg_open",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(26)|body_armor(0)|leg_armor(0), imodbits_plate ],
["arena_turban_yellow", "Arena Turban", [("tuareg_open",0)], itp_type_head_armor|itp_fit_to_head ,0, 187 , weight(1.25)|abundance(100)|head_armor(26)|body_armor(0)|leg_armor(0), imodbits_plate ],

# A treatise on The Method of Mechanical Theorems Archimedes
 
#This book must be at the beginning of readable books
 ["book_tactics","De Re Militari", [("book_a",0)], itp_type_book, 0, 4000,weight(2)|abundance(100),imodbits_none],
 ["book_persuasion","Rhetorica ad Herennium", [("book_b",0)], itp_type_book, 0, 5000,weight(2)|abundance(100),imodbits_none],
 ["book_leadership","The Life of Alixenus the Great", [("book_d",0)], itp_type_book, 0, 4200,weight(2)|abundance(100),imodbits_none],
 ["book_intelligence","Essays on Logic", [("book_e",0)], itp_type_book, 0, 2900,weight(2)|abundance(100),imodbits_none],
 ["book_trade","A Treatise on the Value of Things", [("book_f",0)], itp_type_book, 0, 3100,weight(2)|abundance(100),imodbits_none],
 ["book_weapon_mastery", "On the Art of Fighting with Swords", [("book_d",0)], itp_type_book, 0, 4200,weight(2)|abundance(100),imodbits_none],
 ["book_engineering","Method of Mechanical Theorems", [("book_open",0)], itp_type_book, 0, 4000,weight(2)|abundance(100),imodbits_none],

#Reference books
#This book must be at the beginning of reference books
 ["book_wound_treatment_reference","The Book of Healing", [("book_c",0)], itp_type_book, 0, 3500,weight(2)|abundance(100),imodbits_none],
 ["book_training_reference","Manual of Arms", [("book_open",0)], itp_type_book, 0, 3500,weight(2)|abundance(100),imodbits_none],
 ["book_surgery_reference","The Great Book of Surgery", [("book_c",0)], itp_type_book, 0, 3500,weight(2)|abundance(100),imodbits_none],

 #other trade goods (first one is spice)
 ["spice","Spice", [("spice_sack",0)], itp_always_loot|itp_merchandise|itp_type_goods|itp_consumable, 0, 880,weight(40)|abundance(25)|max_ammo(50),imodbits_none],
 ["salt","Salt", [("salt_sack",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 255,weight(50)|abundance(120),imodbits_none],


 #["flour","Flour", [("salt_sack",0)], itp_merchandise|itp_type_goods|itp_consumable, 0, 40,weight(50)|abundance(100)|food_quality(45)|max_ammo(50),imodbits_none],

 ["oil","Oil", [("oil",0)], itp_always_loot|itp_merchandise|itp_type_goods|itp_consumable, 0, 450,weight(50)|abundance(60)|max_ammo(50),imodbits_none],

 ["pottery","Pottery", [("jug",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 100,weight(50)|abundance(90),imodbits_none],

 ["raw_flax","Flax Bundle", [("raw_flax",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 150,weight(40)|abundance(90),imodbits_none],
 ["linen","Linen", [("linen",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 250,weight(40)|abundance(90),imodbits_none],

 ["wool","Wool", [("wool_sack",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 130,weight(40)|abundance(90),imodbits_none],
 ["wool_cloth","Wool Cloth", [("wool_cloth",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 250,weight(40)|abundance(90),imodbits_none],

 ["raw_silk","Raw Silk", [("raw_silk_bundle",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 600,weight(30)|abundance(90),imodbits_none],
 ["raw_dyes","Dyes", [("dyes",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 200,weight(10)|abundance(90),imodbits_none],
 ["velvet","Velvet", [("velvet",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 1025,weight(40)|abundance(30),imodbits_none],

 ["iron","Iron", [("iron",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0,264,weight(60)|abundance(60),imodbits_none],
 ["tools","Tools", [("iron_hammer",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 410,weight(50)|abundance(90),imodbits_none],

 ["raw_leather","Hides", [("leatherwork_inventory",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 120,weight(40)|abundance(90),imodbits_none],
 ["leatherwork","Leatherwork", [("leatherwork_frame",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 220,weight(40)|abundance(90),imodbits_none],
 
 ["raw_date_fruit","Date Fruit", [("date_inventory",0)], itp_always_loot|itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 120,weight(40)|food_quality(10)|max_ammo(10),imodbits_none],
 ["furs","Furs", [("fur_pack",0)], itp_always_loot|itp_merchandise|itp_type_goods, 0, 391,weight(40)|abundance(90),imodbits_none],

 ["wine","Wine", [("amphora_slim",0)], itp_always_loot|itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 220,weight(30)|abundance(60)|max_ammo(50),imodbits_none],
 ["ale","Ale", [("ale_barrel",0)], itp_always_loot|itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 120,weight(30)|abundance(70)|max_ammo(50),imodbits_none],

# ["dry_bread", "wheat_sack", itp_type_goods|itp_consumable, 0, slt_none,view_goods,95,weight(2),max_ammo(50),imodbits_none],
#foods (first one is smoked_fish)
 ["smoked_fish","Smoked Fish", [("smoked_fish",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 65,weight(15)|abundance(110)|food_quality(50)|max_ammo(50),imodbits_none],
 ["cheese","Cheese", [("cheese_b",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 75,weight(6)|abundance(110)|food_quality(40)|max_ammo(30),imodbits_none],
 ["honey","Honey", [("honey_pot",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 220,weight(5)|abundance(110)|food_quality(40)|max_ammo(30),imodbits_none],
 ["sausages","Sausages", [("sausages",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 85,weight(10)|abundance(110)|food_quality(40)|max_ammo(40),imodbits_none],
 ["cabbages","Cabbages", [("cabbage",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 30,weight(15)|abundance(110)|food_quality(40)|max_ammo(50),imodbits_none],
 ["dried_meat","Dried Meat", [("smoked_meat",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 85,weight(15)|abundance(100)|food_quality(70)|max_ammo(50),imodbits_none],
 ["apples","Fruit", [("apple_basket",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 44,weight(20)|abundance(110)|food_quality(40)|max_ammo(50),imodbits_none],
 ["raw_grapes","Grapes", [("grapes_inventory",0)], itp_merchandise|itp_consumable|itp_type_goods, 0, 75,weight(40)|abundance(90)|food_quality(10)|max_ammo(10),imodbits_none], #x2 for wine
 ["raw_olives","Olives", [("olive_inventory",0)], itp_merchandise|itp_consumable|itp_type_goods, 0, 100,weight(40)|abundance(90)|food_quality(10)|max_ammo(10),imodbits_none], #x3 for oil
 ["grain","Grain", [("wheat_sack",0)], itp_merchandise|itp_type_goods|itp_consumable, 0, 30,weight(30)|abundance(110)|food_quality(40)|max_ammo(50),imodbits_none],

 ["cattle_meat","Beef", [("raw_meat",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 80,weight(20)|abundance(100)|food_quality(80)|max_ammo(50),imodbits_none],
 ["bread","Bread", [("bread_a",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 50,weight(30)|abundance(110)|food_quality(40)|max_ammo(50),imodbits_none],
 ["chicken","Chicken", [("chicken",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 95,weight(10)|abundance(110)|food_quality(40)|max_ammo(50),imodbits_none],
 ["pork","Pork", [("pork",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 75,weight(15)|abundance(100)|food_quality(70)|max_ammo(50),imodbits_none],
 ["butter","Butter", [("butter_pot",0)], itp_merchandise|itp_type_goods|itp_consumable|itp_food, 0, 150,weight(6)|abundance(110)|food_quality(40)|max_ammo(30),imodbits_none],
 

 #Would like to remove flour altogether and reduce chicken, pork and butter (perishables) to non-trade items. Apples could perhaps become a generic "fruit", also representing dried fruit and grapes
 # Armagan: changed order so that it'll be easier to remove them from trade goods if necessary.
#************************************************************************************************
# ITEMS before this point are hardcoded into item_codes.h and their order should not be changed!
#************************************************************************************************

# Quest Items

 ["siege_supply","Supplies", [("ale_barrel",0)], itp_type_goods, 0, 96,weight(40)|abundance(70),imodbits_none],
 ["quest_wine","Wine", [("amphora_slim",0)], itp_type_goods, 0, 46,weight(40)|abundance(60)|max_ammo(50),imodbits_none],
 ["quest_ale","Ale", [("ale_barrel",0)], itp_type_goods, 0, 31,weight(40)|abundance(70)|max_ammo(50),imodbits_none],

 
# Tutorial Items

 ["tutorial_sword", "Sword", [("long_sword",0),("scab_longsw_a", ixmesh_carry)], itp_type_one_handed_wpn|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn, 0 , weight(1.5)|difficulty(0)|spd_rtng(100) | weapon_length(102)|swing_damage(18 , cut) | thrust_damage(15 ,  pierce),imodbits_sword ],
 ["tutorial_axe", "Axe", [("iron_ax",0)], itp_type_two_handed_wpn| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry, itc_nodachi|itcf_carry_axe_back, 0 , weight(4)|difficulty(0)|spd_rtng(91) | weapon_length(108)|swing_damage(19 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
 ["tutorial_spear", "Spear", [("spear",0)], itp_type_polearm| itp_primary|itp_penalty_with_shield|itp_wooden_parry, itc_spear, 0 , weight(4.5)|difficulty(0)|spd_rtng(80) | weapon_length(158)|swing_damage(0 , cut) | thrust_damage(19 ,  pierce),imodbits_polearm ],
 ["tutorial_club", "Club", [("club",0)], itp_type_one_handed_wpn| itp_primary|itp_wooden_parry|itp_wooden_attack, itc_scimitar, 0 , weight(2.5)|difficulty(0)|spd_rtng(95) | weapon_length(95)|swing_damage(11 , blunt) | thrust_damage(0 ,  pierce),imodbits_none ],
 ["tutorial_battle_axe", "Battle Axe", [("battle_ax",0)], itp_type_two_handed_wpn| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry, itc_nodachi|itcf_carry_axe_back, 0 , weight(5)|difficulty(0)|spd_rtng(88) | weapon_length(108)|swing_damage(27 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
 ["tutorial_arrows","Arrows", [("arrow",0),("flying_missile",ixmesh_flying_ammo),("quiver", ixmesh_carry)], itp_type_arrows, itcf_carry_quiver_back, 0,weight(3)|abundance(160)|weapon_length(95)|thrust_damage(0,pierce)|max_ammo(20),imodbits_missile],
 ["tutorial_bolts","Bolts", [("bolt",0),("flying_missile",ixmesh_flying_ammo),("bolt_bag", ixmesh_carry),("bolt_bag_b", ixmesh_carry|imodbit_large_bag)], itp_type_bolts, itcf_carry_quiver_right_vertical, 0,weight(2.25)|abundance(90)|weapon_length(63)|thrust_damage(0,pierce)|max_ammo(18),imodbits_missile],
 ["tutorial_short_bow", "Short Bow", [("short_bow",0),("short_bow_carry",ixmesh_carry)], itp_type_bow |itp_primary|itp_two_handed ,itcf_shoot_bow|itcf_carry_bow_back, 0 , weight(1)|difficulty(0)|spd_rtng(98) | shoot_speed(49) | thrust_damage(12 ,  pierce  ),imodbits_bow ],
 ["tutorial_crossbow", "Crossbow", [("crossbow_a",0)], itp_type_crossbow |itp_primary|itp_two_handed|itp_cant_reload_on_horseback ,itcf_shoot_crossbow|itcf_carry_crossbow_back, 0 , weight(3)|difficulty(0)|spd_rtng(42)|  shoot_speed(68) | thrust_damage(32,pierce)|max_ammo(1),imodbits_crossbow ],
 ["tutorial_throwing_daggers", "Throwing Daggers", [("throwing_dagger",0)], itp_type_thrown |itp_primary ,itcf_throw_knife, 0 , weight(3.5)|difficulty(0)|spd_rtng(102) | shoot_speed(25) | thrust_damage(16 ,  cut)|max_ammo(14)|weapon_length(0),imodbits_missile ],
 ["tutorial_saddle_horse", "Saddle Horse", [("saddle_horse",0)], itp_type_horse, 0, 0,abundance(90)|body_armor(3)|difficulty(0)|horse_speed(40)|horse_maneuver(38)|horse_charge(8),imodbits_horse_basic],
 ["tutorial_shield", "Kite Shield", [("shield_kite_a",0)], itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  118 , weight(2.5)|hit_points(480)|body_armor(1)|spd_rtng(82)|weapon_length(150),imodbits_shield ],
 ["tutorial_staff_no_attack","Staff", [("wooden_staff",0)],itp_type_polearm|itp_offset_lance|itp_primary|itp_penalty_with_shield|itp_wooden_parry|itp_wooden_attack,itc_parry_polearm|itcf_carry_sword_back,9, weight(3.5)|spd_rtng(120) | weapon_length(115)|swing_damage(0,blunt) | thrust_damage(0,blunt),imodbits_none],
 ["tutorial_staff","Staff", [("wooden_staff",0)],itp_type_polearm|itp_offset_lance|itp_primary|itp_penalty_with_shield|itp_wooden_parry|itp_wooden_attack,itc_staff|itcf_carry_sword_back,9, weight(3.5)|spd_rtng(120) | weapon_length(115)|swing_damage(16,blunt) | thrust_damage(16,blunt),imodbits_none],

# Horses: sumpter horse/ pack horse, saddle horse, steppe horse, warm blood, geldling, stallion,   war mount, charger, 
# Carthorse, hunter, heavy hunter, hackney, palfrey, courser, destrier.
 ["sumpter_horse","Horse", [("sumpter_horse",0)], itp_merchandise|itp_type_horse, 0,
  740,abundance(50)|hit_points(150)|body_armor(14)|difficulty(1)|horse_speed(37)|horse_maneuver(39)|horse_charge(9)|horse_scale(100),
  imodbits_horse_basic, [], [fac_kingdom_2, fac_kingdom_1]],
 ["saddle_horse","Horse", [("saddle_horse",0)], itp_merchandise|itp_type_horse, 0,
  800,abundance(50)|hit_points(170)|body_armor(14)|difficulty(1)|horse_speed(39)|horse_maneuver(34)|horse_charge(10)|horse_scale(100),
  imodbits_horse_basic, [], [fac_kingdom_2, fac_kingdom_1]],
 ["sumpter_horse_2","Horse", [("steppe_horse",0)], itp_merchandise|itp_type_horse, 0,
  840,abundance(50)|hit_points(150)|body_armor(14)|difficulty(1)|horse_speed(37)|horse_maneuver(39)|horse_charge(9)|horse_scale(100),
  imodbits_horse_basic, [], [fac_kingdom_2, fac_kingdom_1]],

 ["steppe_horse","Steppe Horse", [("sumpter_horse",0)], itp_merchandise|itp_type_horse, 0,
  720,abundance(50)|hit_points(120)|body_armor(14)|difficulty(1)|horse_speed(36)|horse_maneuver(41)|horse_charge(8)|horse_scale(95),
  imodbits_horse_basic, [], [fac_kingdom_3]],
 ["steppe_horse_2","Horse", [("saddle_horse",0)], itp_merchandise|itp_type_horse, 0,
  1400,abundance(50)|hit_points(130)|body_armor(14)|difficulty(1)|horse_speed(41)|horse_maneuver(51)|horse_charge(10)|horse_scale(95),
  imodbits_horse_basic, [], [fac_kingdom_3]],
 ["steppe_horse_3","Steppe Horse", [("steppe_horse",0)], itp_merchandise|itp_type_horse, 0,
  1320,abundance(50)|hit_points(120)|body_armor(14)|difficulty(1)|horse_speed(40)|horse_maneuver(51)|horse_charge(8)|horse_scale(95),
  imodbits_horse_basic, [], [fac_kingdom_3]],
 
 ["arabian_horse_a","Sarranid Horse", [("arabian_horse_a",0)], itp_merchandise|itp_type_horse, 0,
  5500,abundance(30)|hit_points(210)|body_armor(14)|difficulty(3)|horse_speed(45)|horse_maneuver(50)|horse_charge(21)|horse_scale(100),
  imodbits_horse_basic|imodbit_champion, [], [fac_kingdom_6]],
 ["arabian_horse_b","Sarranid Horse", [("arabian_horse_b",0)], itp_merchandise|itp_type_horse, 0,
  6000,abundance(30)|hit_points(230)|body_armor(24)|difficulty(5)|horse_speed(50)|horse_maneuver(54)|horse_charge(24)|horse_scale(100),
  imodbits_horse_basic|imodbit_champion, [], [fac_kingdom_6]],
 ["arabian_horse_c","Sarranid Horse", [("arabian_horse_b",0)], itp_merchandise|itp_type_horse, 0,
  600,abundance(30)|hit_points(110)|body_armor(9)|difficulty(1)|horse_speed(40)|horse_maneuver(24)|horse_charge(9)|horse_scale(97),
  imodbits_horse_basic, [], [fac_kingdom_6]],
 
 ["courser","War Horse", [("courser",0)], itp_merchandise|itp_type_horse, 0,
  6000,abundance(30)|body_armor(25)|hit_points(150)|difficulty(5)|horse_speed(50)|horse_maneuver(44)|horse_charge(12)|horse_scale(106),
  imodbits_horse_basic|imodbit_champion, [], [fac_kingdom_1, fac_kingdom_2, fac_kingdom_3]],
 ["hunter","War Horse", [("hunting_horse",0),("hunting_horse",imodbits_horse_good)], itp_merchandise|itp_type_horse, 0,
  6100,abundance(30)|hit_points(160)|body_armor(28)|difficulty(5)|horse_speed(50)|horse_maneuver(44)|horse_charge(24)|horse_scale(108),
  imodbits_horse_basic|imodbit_champion, [], [fac_kingdom_1, fac_kingdom_2, fac_kingdom_3]],

 ["warhorse","War Armored Horse", [("warhorse_chain",0)], itp_merchandise|itp_type_horse, 0,
  12240,abundance(15)|hit_points(325)|body_armor(40)|difficulty(7)|horse_speed(40)|horse_maneuver(41)|horse_charge(38)|horse_scale(110),
  imodbits_horse_basic|imodbit_champion, [], [fac_culture_1, fac_culture_2]],
 ["charger","War Armored Horse", [("charger_new",0)], itp_merchandise|itp_type_horse, 0,
  19110,abundance(12)|hit_points(350)|body_armor(58)|difficulty(7)|horse_speed(40)|horse_maneuver(44)|horse_charge(48)|horse_scale(112),
  imodbits_horse_basic|imodbit_champion, [], [fac_culture_1]],
 ["warhorse_sarranid","War Armored Horse", [("warhorse_sarranid",0)], itp_merchandise|itp_type_horse, 0,
  18110,abundance(12)|hit_points(325)|body_armor(58)|difficulty(7)|horse_speed(40)|horse_maneuver(44)|horse_charge(38)|horse_scale(112),
  imodbits_horse_basic|imodbit_champion, [], [fac_culture_3,fac_culture_6]],
 ["warhorse_steppe","War Armored Horse", [("warhorse_steppe",0)], itp_merchandise|itp_type_horse, 0,
  18110,abundance(12)|hit_points(325)|body_armor(40)|difficulty(7)|horse_speed(40)|horse_maneuver(44)|horse_charge(38)|horse_scale(112),
  imodbits_horse_basic|imodbit_champion, [], [fac_culture_3,fac_culture_6]],



#whalebone crossbow, yew bow, war bow, arming sword 
 ["arrows","Arrows", [("arrow",0),("arrow",ixmesh_flying_ammo),("quiver", ixmesh_carry)], itp_type_arrows|itp_merchandise|itp_default_ammo, itcf_carry_quiver_back_right,
  72,weight(3)|abundance(50)|weapon_length(95)|thrust_damage(1,pierce)|max_ammo(25),imodbits_missile],
 ["barbed_arrows","Arrows", [("barbed_arrow",0),("barbed_arrow",ixmesh_flying_ammo),("quiver_d", ixmesh_carry)], itp_type_arrows, itcf_carry_quiver_back_right,
  72,weight(3)|abundance(50)|weapon_length(95)|thrust_damage(1,pierce)|max_ammo(20),imodbits_missile, [], [fac_kingdom_2,fac_kingdom_4]],

 
 ["arrows_b","Arrows", [("arrow",0),("arrow",ixmesh_flying_ammo),("arena_quiver", ixmesh_carry)], itp_type_arrows|itp_merchandise|itp_default_ammo, itcf_carry_quiver_back_right,
  410,weight(3)|abundance(100)|weapon_length(95)|thrust_damage(5,pierce)|max_ammo(30),imodbits_missile, [], [fac_kingdom_3,fac_kingdom_6]], 
 ["khergit_arrows","Arrows", [("arrow_b",0),("arrow_b",ixmesh_flying_ammo),("quiver_b", ixmesh_carry)], itp_type_arrows|itp_merchandise, itcf_carry_quiver_back_right,
  410,weight(3.5)|abundance(30)|weapon_length(95)|thrust_damage(5,pierce)|max_ammo(35),imodbits_missile, [], [fac_kingdom_3]],
 ["bodkin_arrows","Arrows", [("piercing_arrow",0),("piercing_arrow",ixmesh_flying_ammo),("quiver_c", ixmesh_carry)], itp_type_arrows|itp_merchandise, itcf_carry_quiver_back_right,
  910,weight(4)|abundance(30)|weapon_length(91)|thrust_damage(9,pierce)|max_ammo(40),imodbits_missile, [], [fac_culture_1,fac_culture_2,fac_culture_4]],

 ["barbed_bolts","Bolts", [("bolt",0),("bolt",ixmesh_flying_ammo),("bolt_bag_c", ixmesh_carry)], itp_type_bolts|itp_default_ammo|itp_can_penetrate_shield,
  itcf_carry_quiver_right_vertical, 64,weight(2.25)|abundance(20)|weapon_length(63)|thrust_damage(1,pierce)|max_ammo(20),imodbits_missile, [], [fac_kingdom_1]],
 
 ["bolts","Bolts", [("bolt",0),("bolt",ixmesh_flying_ammo),("bolt_bag", ixmesh_carry)], itp_type_bolts|itp_merchandise|itp_default_ammo|itp_can_penetrate_shield,
  itcf_carry_quiver_right_vertical, 364,weight(2.25)|abundance(90)|weapon_length(63)|thrust_damage(3,pierce)|max_ammo(30),imodbits_missile, [], [fac_kingdom_1,fac_culture_2]],
 ["steel_bolts","Steel Bolts", [("bolt",0),("bolt",ixmesh_flying_ammo),("bolt_bag_b", ixmesh_carry)], itp_type_bolts|itp_merchandise|itp_bonus_against_shield|itp_can_penetrate_shield,
  itcf_carry_quiver_right_vertical, 1210,weight(2.5)|abundance(30)|weapon_length(63)|thrust_damage(9,pierce)|max_ammo(40),imodbits_missile, [], [fac_culture_1]],


 
 ["cartridges","Cartridges", [("cartridge_a",0)], itp_type_bullets|itp_merchandise|itp_can_penetrate_shield|itp_default_ammo, 0,
  41,weight(2.25)|abundance(90)|weapon_length(3)|thrust_damage(1,pierce)|max_ammo(50),imodbits_missile],

["pilgrim_disguise", "Pilgrim Disguise", [("pilgrim_outfit",0)], 0| itp_type_body_armor |itp_covers_legs |itp_civilian ,0, 250 , weight(2)|abundance(100)|head_armor(0)|body_armor(19)|leg_armor(8)|difficulty(0) ,imodbits_cloth ],
["pilgrim_hood", "Pilgrim Hood", [("pilgrim_hood",0)], 0| itp_type_head_armor |itp_civilian  ,0, 350 , weight(1.25)|abundance(100)|head_armor(14)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["pilgrim_staff", "Pilgrim Staff", [("pilgrim_staff",0)], itp_type_polearm|itp_offset_lance| itp_primary, itc_staff|itcf_carry_sword_back,
 202 , weight(2)|difficulty(0)|spd_rtng(120) | weapon_length(140)|swing_damage(35 , blunt) | thrust_damage(36 ,  blunt),imodbits_polearm ],

# ARMOR
#handwear
["leather_gloves","Leather Gloves", [("leather_gloves_L",0)], itp_merchandise|itp_type_hand_armor,0,
 190, weight(0.25)|abundance(120)|body_armor(4)|difficulty(5),imodbits_cloth, [], [fac_kingdom_1,fac_kingdom_2,fac_kingdom_3,fac_kingdom_4]],
["mail_mittens","Mail Mittens", [("mail_mittens_L",0)], itp_merchandise|itp_type_hand_armor,0,
 350, weight(0.5)|abundance(50)|body_armor(8)|difficulty(9),imodbits_armor, [], [fac_culture_1,fac_culture_2,fac_culture_4]],
["scale_gauntlets","Scale Gauntlets", [("scale_gauntlets_b_L",0)], itp_merchandise|itp_type_hand_armor,0,
 710, weight(0.75)|abundance(30)|body_armor(14)|difficulty(15),imodbits_armor, [], [fac_culture_3,fac_culture_6]],
["lamellar_gauntlets","Lamellar Gauntlets", [("scale_gauntlets_a_L",0)], itp_merchandise|itp_type_hand_armor,0,
 910, weight(0.75)|abundance(30)|body_armor(14)|difficulty(15),imodbits_armor, [], [fac_culture_3,fac_culture_6]],
["gauntlets","Gauntlets", [("gauntlets_L",0),("gauntlets_L",imodbit_reinforced)], itp_merchandise|itp_type_hand_armor,0,
 1040, weight(1.0)|abundance(20)|body_armor(21)|difficulty(22),imodbits_armor, [], [fac_culture_1]],

#footwear
["wrapping_boots", "Wrapping Boots", [("wrapping_boots_a",0)], itp_merchandise| itp_type_foot_armor |itp_civilian | itp_attach_armature ,0,
 54 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(3)|difficulty(0) ,imodbits_cloth, [], [fac_kingdom_1] ],
["woolen_hose", "Woolen Hose", [("woolen_hose_a",0)], itp_merchandise| itp_type_foot_armor |itp_civilian | itp_attach_armature ,0,
 56 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(4)|difficulty(0) ,imodbits_cloth, [], [fac_kingdom_1] ],
["blue_hose", "Blue Hose", [("blue_hose_a",0)], itp_merchandise| itp_type_foot_armor |itp_civilian | itp_attach_armature ,0,
 61 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(5)|difficulty(0) ,imodbits_cloth, [], [fac_kingdom_1] ],
["hunter_boots", "Hunter Boots", [("hunter_boots_a",0)], itp_merchandise| itp_type_foot_armor |itp_civilian | itp_attach_armature,0,
 59 , weight(1.25)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(9)|difficulty(0) ,imodbits_cloth, [], [fac_kingdom_2,fac_kingdom_4] ],
["hide_boots", "Hide Boots", [("hide_boots_a",0)], itp_merchandise| itp_type_foot_armor |itp_civilian  | itp_attach_armature,0,
 54 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(10)|difficulty(0) ,imodbits_cloth, [], [fac_kingdom_2,fac_kingdom_3,fac_kingdom_4] ],
["ankle_boots", "Ankle Boots", [("ankle_boots_a_new",0)], itp_merchandise| itp_type_foot_armor |itp_civilian  | itp_attach_armature,0,
 65 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(12)|difficulty(0) ,imodbits_cloth, [], [fac_kingdom_1] ],
["nomad_boots", "Nomad Boots", [("nomad_boots_a",0)], itp_merchandise| itp_type_foot_armor  |itp_civilian | itp_attach_armature,0,
 70 , weight(1.25)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(14)|difficulty(0) ,imodbits_cloth, [], [fac_kingdom_2,fac_kingdom_3,fac_kingdom_4] ],
["leather_boots", "Leather Boots", [("leather_boots_a",0)], itp_merchandise| itp_type_foot_armor  |itp_civilian | itp_attach_armature,0,
 174 , weight(1.25)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(21)|difficulty(0) ,imodbits_cloth, [], [fac_kingdom_2,fac_kingdom_4] ],
 
["splinted_leather_greaves", "Splinted Leather Greaves", [("leather_greaves_a",0)], itp_merchandise| itp_type_foot_armor | itp_attach_armature,0,
 510 , weight(2)|abundance(50)|head_armor(0)|body_armor(0)|leg_armor(27)|difficulty(9) ,imodbits_armor, [], [fac_culture_2,fac_culture_4] ],
["mail_chausses", "Mail Chausses", [("mail_chausses_a",0)], itp_merchandise| itp_type_foot_armor | itp_attach_armature  ,0,
 530 , weight(4)|abundance(50)|head_armor(0)|body_armor(0)|leg_armor(27)|difficulty(9) ,imodbits_armor, [], [fac_kingdom_1] ],
 
["splinted_greaves", "Splinted Greaves", [("splinted_greaves_a",0)], itp_merchandise| itp_type_foot_armor | itp_attach_armature,0,
 1253 , weight(3.75)|abundance(30)|head_armor(0)|body_armor(0)|leg_armor(38)|difficulty(12) ,imodbits_armor, [], [fac_kingdom_1] ],
["mail_boots", "Mail Boots", [("mail_boots_a",0)], itp_merchandise| itp_type_foot_armor | itp_attach_armature  ,0,
 1250 , weight(4)|abundance(30)|head_armor(0)|body_armor(0)|leg_armor(38)|difficulty(12) ,imodbits_armor, [], [fac_culture_2,fac_culture_3,fac_culture_4] ],
 
["iron_greaves", "Iron Greaves", [("iron_greaves_a",0)], itp_merchandise| itp_type_foot_armor | itp_attach_armature,0,
 2770 , weight(5.5)|abundance(20)|head_armor(0)|body_armor(0)|leg_armor(43)|difficulty(19) ,imodbits_armor, [], [fac_culture_1] ],
["plate_boots", "Plate Boots", [("plate_boots",0)], itp_merchandise| itp_type_foot_armor | itp_attach_armature,0,
 2770 , weight(5.5)|abundance(20)|head_armor(0)|body_armor(0)|leg_armor(43)|difficulty(19) ,imodbits_plate, [], [fac_culture_1] ],
 
["black_greaves", "Black Greaves", [("black_greaves",0)], itp_type_foot_armor  | itp_attach_armature,0,
 2361 , weight(3.5)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(35)|difficulty(0) ,imodbits_armor ], 
["khergit_leather_boots", "Khergit Leather Boots", [("khergit_leather_boots",0)], itp_type_foot_armor |itp_civilian | itp_attach_armature ,0,
 120 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(18)|difficulty(0) ,imodbits_cloth ],
 
["sarranid_boots_a", "Sarranid Shoes", [("sarranid_shoes",0)], itp_type_foot_armor |itp_civilian | itp_attach_armature ,0,
 130 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(8)|difficulty(6) ,imodbits_cloth, [], [fac_kingdom_6]  ],
["sarranid_boots_b", "Sarranid Leather Boots", [("sarranid_boots",0)], itp_merchandise| itp_type_foot_armor |itp_civilian | itp_attach_armature ,0,
 120 , weight(2)|abundance(50)|head_armor(0)|body_armor(0)|leg_armor(16)|difficulty(8) ,imodbits_cloth, [], [fac_kingdom_6]  ],
["sarranid_boots_c", "Plated Boots", [("sarranid_camel_boots",0)], itp_merchandise| itp_type_foot_armor |itp_civilian | itp_attach_armature ,0,
 780 , weight(3)|abundance(30)|head_armor(0)|body_armor(0)|leg_armor(24)|difficulty(12) ,imodbits_plate, [], [fac_culture_6]  ],
["sarranid_boots_d", "Sarranid Mail Boots", [("sarranid_mail_chausses",0)], itp_merchandise| itp_type_foot_armor |itp_civilian | itp_attach_armature ,0,
 1220 , weight(5)|abundance(20)|head_armor(0)|body_armor(0)|leg_armor(34)|difficulty(16) ,imodbits_armor, [], [fac_culture_6]  ],

["sarranid_head_cloth", "Lady Head Cloth", [("tulbent",0)],  itp_type_head_armor | itp_doesnt_cover_hair |itp_civilian |itp_attach_armature,0, 1 , weight(0.5)|abundance(100)|head_armor(4)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["sarranid_head_cloth_b", "Lady Head Cloth", [("tulbent_b",0)],  itp_type_head_armor | itp_doesnt_cover_hair |itp_civilian |itp_attach_armature,0, 1 , weight(0.5)|abundance(100)|head_armor(4)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["sarranid_felt_head_cloth", "Head Cloth", [("common_tulbent",0)],  itp_type_head_armor  |itp_civilian |itp_attach_armature,0, 1 , weight(0.5)|abundance(100)|head_armor(4)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["sarranid_felt_head_cloth_b", "Head Cloth", [("common_tulbent_b",0)],  itp_type_head_armor  |itp_civilian |itp_attach_armature,0, 1 , weight(0.5)|abundance(100)|head_armor(4)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],


#bodywear
["lady_dress_ruby", "Lady Dress", [("lady_dress_r",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["lady_dress_green", "Lady Dress", [("lady_dress_g",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["lady_dress_blue", "Lady Dress", [("lady_dress_b",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["red_dress", "Red Dress", [("red_dress",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["brown_dress", "Brown Dress", [("brown_dress",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["green_dress", "Green Dress", [("green_dress",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["khergit_lady_dress", "Khergit Lady Dress", [("khergit_lady_dress",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["khergit_lady_dress_b", "Khergit Leather Lady Dress", [("khergit_lady_dress_b",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["sarranid_lady_dress", "Sarranid Lady Dress", [("sarranid_lady_dress",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["sarranid_lady_dress_b", "Sarranid Lady Dress", [("sarranid_lady_dress_b",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["sarranid_common_dress", "Sarranid Dress", [("sarranid_common_dress",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["sarranid_common_dress_b", "Sarranid Dress", [("sarranid_common_dress_b",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],


["courtly_outfit", "Courtly Outfit", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian   ,0,
 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["nobleman_outfit", "Nobleman Outfit", [("nobleman_outfit_b_new",0)], itp_type_body_armor|itp_covers_legs|itp_civilian   ,0,
 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(15)|leg_armor(12)|difficulty(0) ,imodbits_cloth ], 




#for future:
["coat", "Coat", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["leather_coat", "Leather Coat", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["mail_coat", "Coat of Mail", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["long_mail_coat", "Long Coat of Mail", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["mail_with_tunic_red", "Mail with Tunic", [("arena_armorR_new",0)], itp_type_body_armor  |itp_covers_legs ,0, 650 , weight(16)|abundance(100)|head_armor(0)|body_armor(39)|leg_armor(8), imodbits_armor ],
["mail_with_tunic_green", "Mail with Tunic", [("arena_armorG_new",0)], itp_type_body_armor  |itp_covers_legs ,0, 650 , weight(16)|abundance(100)|head_armor(0)|body_armor(39)|leg_armor(8), imodbits_armor ],
["hide_coat", "Hide Coat", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["merchant_outfit", "Merchant Outfit", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["homespun_dress", "Homespun Dress", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["thick_coat", "Thick Coat", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["coat_with_cape", "Coat with Cape", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["steppe_outfit", "Steppe Outfit", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["nordic_outfit", "Nordic Outfit", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["nordic_armor", "Nordic Armor", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["hide_armor", "Hide Armor", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["cloaked_tunic", "Cloaked Tunic", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["sleeveless_tunic", "Sleeveless Tunic", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["sleeveless_leather_tunic", "Sleeveless Leather Tunic", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["linen_shirt", "Linen Shirt", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
["wool_coat", "Wool Coat", [("nobleman_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(10)|difficulty(0) ,imodbits_cloth ],
#end

["dress", "Dress", [("dress",0)],  itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 6 , weight(1)|abundance(100)|head_armor(0)|body_armor(6)|leg_armor(2)|difficulty(0) ,imodbits_cloth ],
["blue_dress", "Blue Dress", [("blue_dress_new",0)],  itp_type_body_armor  |itp_covers_legs|itp_civilian ,0,
 76 , weight(1)|abundance(100)|head_armor(0)|body_armor(6)|leg_armor(2)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_1]],
["peasant_dress", "Peasant Dress", [("peasant_dress_b_new",0)],  itp_type_body_armor  |itp_covers_legs|itp_civilian ,0,
 76 , weight(1)|abundance(100)|head_armor(0)|body_armor(6)|leg_armor(2)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_2,fac_kingdom_4]], 
["woolen_dress", "Woolen Dress", [("woolen_dress",0)],  itp_type_body_armor|itp_civilian  |itp_covers_legs ,0,
 10 , weight(1.75)|abundance(100)|head_armor(0)|body_armor(8)|leg_armor(2)|difficulty(0) ,imodbits_cloth ],
["shirt", "Shirt", [("shirt",0)],  itp_type_body_armor  |itp_covers_legs|itp_civilian ,0,
 3 , weight(1)|abundance(100)|head_armor(0)|body_armor(5)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
 #NEW: was "linen_tunic"
["linen_tunic", "Linen Tunic", [("shirt_a",0)],  itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 56 , weight(1)|abundance(100)|head_armor(0)|body_armor(6)|leg_armor(1)|difficulty(0) ,imodbits_cloth ],
 #NEW was cvl_costume_a
["short_tunic", "Red Tunic", [("rich_tunic_a",0)], itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 70 , weight(1)|abundance(100)|head_armor(0)|body_armor(7)|leg_armor(1)|difficulty(0) ,imodbits_cloth ],
#TODO:
 ["red_shirt", "Red Shirt", [("rich_tunic_a",0)],  itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 10 , weight(1)|abundance(100)|head_armor(0)|body_armor(7)|leg_armor(1)|difficulty(0) ,imodbits_cloth ],
 ["red_tunic", "Red Tunic", [("arena_tunicR_new",0)],  itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 10 , weight(1)|abundance(100)|head_armor(0)|body_armor(7)|leg_armor(1)|difficulty(0) ,imodbits_cloth ],

 ["green_tunic", "Green Tunic", [("arena_tunicG_new",0)],  itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 10 , weight(1)|abundance(100)|head_armor(0)|body_armor(7)|leg_armor(1)|difficulty(0) ,imodbits_cloth ],
 ["blue_tunic", "Blue Tunic", [("arena_tunicB_new",0)],  itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 10 , weight(1)|abundance(100)|head_armor(0)|body_armor(7)|leg_armor(1)|difficulty(0) ,imodbits_cloth ],
["robe", "Robe", [("robe",0)],  itp_type_body_armor  |itp_covers_legs |itp_civilian,0,
 31 , weight(1.5)|abundance(100)|head_armor(0)|body_armor(8)|leg_armor(6)|difficulty(0) ,imodbits_cloth ],
#NEW: was coarse_tunic
["leather_apron", "Leather Apron", [("leather_apron",0)],  itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 61 , weight(3)|abundance(100)|head_armor(0)|body_armor(12)|leg_armor(7)|difficulty(0) ,imodbits_cloth ],
#NEW: was tabard_a
["gambeson", "Gambeson", [("white_gambeson",0)],  itp_type_body_armor|itp_covers_legs|itp_civilian,0,
 260 , weight(5)|abundance(100)|head_armor(0)|body_armor(20)|leg_armor(5)|difficulty(0) ,imodbits_cloth ],
["blue_gambeson", "Blue Gambeson", [("blue_gambeson",0)],  itp_type_body_armor|itp_covers_legs|itp_civilian,0,
 270 , weight(5)|abundance(100)|head_armor(0)|body_armor(21)|leg_armor(5)|difficulty(0) ,imodbits_cloth ], 

#NEW: was aketon_a


["coarse_tunic", "Tunic with vest", [("coarse_tunic_a",0)], itp_merchandise| itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 47 , weight(2)|abundance(100)|head_armor(0)|body_armor(11)|leg_armor(6)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_1]],
["tabard", "Tabard", [("tabard_b",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs |itp_civilian,0,
 107 , weight(3)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(6)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_1]],
#NEW: was leather_vest
["leather_vest", "Leather Vest", [("leather_vest_a",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs|itp_civilian ,0,
 146 , weight(4)|abundance(100)|head_armor(0)|body_armor(15)|leg_armor(7)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_3]],
["steppe_armor", "Steppe Armor", [("lamellar_leather",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 295 , weight(5)|abundance(100)|head_armor(0)|body_armor(32)|leg_armor(11)|difficulty(9) ,imodbits_cloth, [], [fac_kingdom_3] ],
 
["padded_cloth", "Aketon", [("padded_cloth_a",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 297 , weight(11)|abundance(100)|head_armor(0)|body_armor(22)|leg_armor(6)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_1]],
#NEW:
 ["aketon_green", "Padded Cloth", [("padded_cloth_b",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 297 , weight(11)|abundance(100)|head_armor(0)|body_armor(22)|leg_armor(6)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_1]],
["red_gambeson", "Red Gambeson", [("red_gambeson_a",0)],  itp_type_body_armor|itp_covers_legs|itp_civilian,0,
 275 , weight(5)|abundance(100)|head_armor(0)|body_armor(21)|leg_armor(5)|difficulty(0) ,imodbits_cloth ],
["leather_jerkin", "Leather Jerkin", [("ragged_leather_jerkin",0)], itp_merchandise| itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 270 , weight(6)|abundance(100)|head_armor(0)|body_armor(23)|leg_armor(6)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_2,fac_kingdom_4]],
["nomad_vest", "Nomad Vest", [("nomad_vest_new",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs|itp_civilian ,0,
 260 , weight(7)|abundance(50)|head_armor(0)|body_armor(22)|leg_armor(8)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_3]],
["ragged_outfit", "Ragged Outfit", [("ragged_outfit_a_new",0)], itp_merchandise| itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 390 , weight(7)|abundance(100)|head_armor(0)|body_armor(23)|leg_armor(9)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_1]],

["padded_leather", "Padded Leather", [("leather_armor_b",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs|itp_civilian,0,
 454 , weight(12)|abundance(100)|head_armor(0)|body_armor(27)|leg_armor(10)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_1]],
["tribal_warrior_outfit", "Tribal Warrior Outfit", [("tribal_warrior_outfit_a_new",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs|itp_civilian ,0,
 520 , weight(14)|abundance(100)|head_armor(0)|body_armor(30)|leg_armor(10)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_2,fac_kingdom_4]],
["nomad_robe", "Nomad Robe", [("nomad_robe_a",0)],  itp_type_body_armor |itp_civilian |itp_covers_legs |itp_civilian,0,
 610 , weight(15)|abundance(100)|head_armor(0)|body_armor(32)|leg_armor(10)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_3]],
["studded_leather_coat", "Studded Leather Coat", [("leather_armor_a",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 1190 , weight(19)|abundance(100)|head_armor(0)|body_armor(39)|leg_armor(12)|difficulty(11) ,imodbits_armor , [], [fac_kingdom_2,fac_kingdom_4]],



["lamellar_vest", "Lamellar Vest", [("lamellar_vest_a",0)], itp_merchandise| itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 1270 , weight(18)|abundance(100)|head_armor(0)|body_armor(35)|leg_armor(8)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_2,fac_kingdom_3]],
["lamellar_vest_khergit", "Lamellar Vest", [("lamellar_vest_b",0)], itp_merchandise| itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 1270 , weight(18)|abundance(100)|head_armor(0)|body_armor(35)|leg_armor(8)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_2,fac_kingdom_3]],
["lamellar_vest1", "Lamellar Vest", [("zzz_lamellar_vest_a",0)], itp_merchandise| itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 2270 , weight(23)|abundance(50)|head_armor(0)|body_armor(45)|leg_armor(8)|difficulty(14) ,imodbits_cloth , [], [fac_culture_2,fac_culture_3]],
["lamellar_vest_khergit1", "Lamellar Vest", [("zzz_lamellar_vest_b",0)], itp_merchandise| itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 2270 , weight(23)|abundance(50)|head_armor(0)|body_armor(45)|leg_armor(8)|difficulty(14) ,imodbits_cloth , [], [fac_culture_2,fac_culture_3]],
 
["lamellar_armor", "Lamellar Armor", [("lamellar_armor_b",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 2410 , weight(25)|abundance(100)|head_armor(0)|body_armor(48)|leg_armor(13)|difficulty(14) ,imodbits_armor , [], [fac_culture_2,fac_culture_3]],

 #NEW: was mail_shirt
["mail_shirt", "Mail Shirt", [("mail_shirt_a",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 1040 , weight(19)|abundance(100)|head_armor(0)|body_armor(37)|leg_armor(12)|difficulty(12) ,imodbits_armor , [], [fac_kingdom_2,fac_kingdom_4]],
["byrnie", "Byrnie", [("byrnie_a_new",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 1295 , weight(17)|abundance(100)|head_armor(0)|body_armor(39)|leg_armor(9)|difficulty(12) ,imodbits_armor , [], [fac_kingdom_2,fac_kingdom_4]],
["mail_hauberk", "Mail Hauberk", [("hauberk_a_new",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 1320 , weight(19)|abundance(100)|head_armor(0)|body_armor(40)|leg_armor(12)|difficulty(12) ,imodbits_armor , [], [fac_kingdom_2,fac_kingdom_4]],
["banded_armor", "Banded Armor", [("banded_armor_a",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 2710 , weight(23)|abundance(100)|head_armor(0)|body_armor(49)|leg_armor(14)|difficulty(14) ,imodbits_armor , [], [fac_culture_2,fac_culture_4]],
#NEW: was hard_lthr_a
["cuir_bouilli", "Cuir Bouilli", [("cuir_bouilli_a",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 3100 , weight(24)|abundance(100)|head_armor(0)|body_armor(50)|leg_armor(15)|difficulty(18) ,imodbits_armor , [], [fac_culture_2,fac_culture_4]],

["mail_with_surcoat", "Mail with Surcoat", [("mail_long_surcoat_new",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 1744 , weight(22)|abundance(100)|head_armor(0)|body_armor(42)|leg_armor(14)|difficulty(9) ,imodbits_armor , [], [fac_kingdom_1,fac_kingdom_2]],
["surcoat_over_mail", "Surcoat over Mail", [("surcoat_over_mail_new",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 1720 , weight(22)|abundance(100)|head_armor(0)|body_armor(43)|leg_armor(14)|difficulty(9) ,imodbits_armor , [], [fac_kingdom_1,fac_kingdom_2]],

 ["tot_armor_1", "Haubergeon", [("tot_armor_1",0)],  itp_type_body_armor  |itp_covers_legs ,0,
 1463 , weight(18)|abundance(100)|head_armor(0)|body_armor(41)|leg_armor(6)|difficulty(9) ,imodbits_armor , [], [fac_kingdom_1]],
 ["tot_armor_2", "Haubergeon", [("tot_armor_2",0)],  itp_merchandise|itp_type_body_armor  |itp_covers_legs ,0,
 1463 , weight(18)|abundance(100)|head_armor(0)|body_armor(41)|leg_armor(6)|difficulty(9) ,imodbits_armor , [], [fac_kingdom_1]],
# ["tot_armor_3", "Haubergeon", [("tot_armor_3",0)],  itp_type_body_armor  |itp_covers_legs ,0,
# 1863 , weight(18)|abundance(100)|head_armor(0)|body_armor(41)|leg_armor(6)|difficulty(9) ,imodbits_armor , [], [fac_kingdom_1]],
# ["tot_armor_4", "Haubergeon", [("tot_armor_4",0)],  itp_type_body_armor  |itp_covers_legs ,0,
# 1863 , weight(18)|abundance(100)|head_armor(0)|body_armor(41)|leg_armor(6)|difficulty(9) ,imodbits_armor , [], [fac_kingdom_1]],
# ["tot_armor_5", "Haubergeon", [("tot_armor_5",0)],  itp_type_body_armor  |itp_covers_legs ,0,
# 1863 , weight(18)|abundance(100)|head_armor(0)|body_armor(41)|leg_armor(6)|difficulty(9) ,imodbits_armor , [], [fac_kingdom_1]], 

["haubergeon", "Haubergeon", [("haubergeon_c",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 1763 , weight(18)|abundance(100)|head_armor(0)|body_armor(41)|leg_armor(16)|difficulty(11) ,imodbits_armor , [], [fac_kingdom_1]], 
["brigandine_red", "Brigandine", [("brigandine_b",0)], itp_merchandise| itp_type_body_armor|itp_covers_legs,0,
 1830 , weight(19)|abundance(100)|head_armor(0)|body_armor(46)|leg_armor(12)|difficulty(12) ,imodbits_armor , [], [fac_culture_1]],
["scale_armor", "Scale Armor", [("lamellar_armor_e",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 2558 , weight(25)|abundance(100)|head_armor(0)|body_armor(52)|leg_armor(13)|difficulty(12) ,imodbits_armor , [], [fac_culture_1]],
["coat_of_plates", "Coat of Plates", [("coat_of_plates_a",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 3828 , weight(25)|abundance(100)|head_armor(0)|body_armor(52)|leg_armor(16)|difficulty(15) ,imodbits_armor , [], [fac_culture_1,fac_culture_2]],
["coat_of_plates_red", "Coat of Plates", [("coat_of_plates_red",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 3828 , weight(25)|abundance(100)|head_armor(0)|body_armor(52)|leg_armor(16)|difficulty(15) ,imodbits_armor , [], [fac_culture_1,fac_culture_2]],
["plate_armor", "Plate Armor", [("full_plate_armor",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 8553 , weight(27)|abundance(100)|head_armor(0)|body_armor(65)|leg_armor(27)|difficulty(19) ,imodbits_plate , [], [fac_culture_1]],

 
["black_armor", "Black Armor", [("black_armor",0)], itp_type_body_armor  |itp_covers_legs ,0,
 9496 , weight(28)|abundance(100)|head_armor(0)|body_armor(57)|leg_armor(18)|difficulty(10) ,imodbits_plate ],

##armors_d

##armors_e
["khergit_elite_armor", "Elite Armor", [("lamellar_armor_d",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 6828 , weight(25)|abundance(20)|head_armor(0)|body_armor(52)|leg_armor(16)|difficulty(18) ,imodbits_armor , [], [fac_culture_3,fac_culture_6]],
["vaegir_elite_armor", "Elite Armor", [("lamellar_armor_c",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 6828 , weight(25)|abundance(20)|head_armor(0)|body_armor(52)|leg_armor(16)|difficulty(18) ,imodbits_armor , [], [fac_culture_3,fac_culture_6]],
["sarranid_elite_armor", "Elite Armor", [("tunic_armor_a",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs |itp_civilian ,0,
 6828 , weight(25)|abundance(20)|head_armor(0)|body_armor(52)|leg_armor(16)|difficulty(18) ,imodbits_armor , [], [fac_culture_3,fac_culture_6]],


 ["sarranid_dress_a", "Dress", [("woolen_dress",0)], itp_type_body_armor  |itp_civilian|itp_covers_legs ,0,
 33 , weight(1)|abundance(100)|head_armor(0)|body_armor(9)|leg_armor(9)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_6]],
 ["sarranid_dress_b", "Dress", [("woolen_dress",0)],  itp_type_body_armor  |itp_civilian|itp_covers_legs ,0,
 33 , weight(1)|abundance(100)|head_armor(0)|body_armor(9)|leg_armor(9)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_6]],
 ["sarranid_cloth_robe", "Worn Robe", [("sar_robe",0)], itp_merchandise| itp_type_body_armor  |itp_civilian|itp_covers_legs ,0,
 33 , weight(1)|abundance(100)|head_armor(0)|body_armor(9)|leg_armor(9)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_6]],
 ["sarranid_cloth_robe_b", "Worn Robe", [("sar_robe_b",0)], itp_merchandise| itp_type_body_armor  |itp_civilian|itp_covers_legs ,0,
 33 , weight(1)|abundance(100)|head_armor(0)|body_armor(9)|leg_armor(9)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_6]],
["skirmisher_armor", "Skirmisher Armor", [("skirmisher_armor",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 274 , weight(3)|abundance(100)|head_armor(0)|body_armor(15)|leg_armor(9)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_6]],
["archers_vest", "Archer's Padded Vest", [("archers_vest",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 360 , weight(6)|abundance(100)|head_armor(0)|body_armor(23)|leg_armor(12)|difficulty(8) ,imodbits_cloth , [], [fac_kingdom_6]],
["sarranid_leather_armor", "Sarranid Leather Armor", [("sarranid_leather_armor",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 650 , weight(9)|abundance(100)|head_armor(0)|body_armor(32)|leg_armor(12)|difficulty(10) ,imodbits_armor , [], [fac_kingdom_6]],
["sarranid_cavalry_robe", "Cavalry Robe", [("arabian_armor_a",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs |itp_civilian,0,
 990 , weight(19)|abundance(100)|head_armor(0)|body_armor(39)|leg_armor(9)|difficulty(10) ,imodbits_armor , [], [fac_kingdom_6]],
["arabian_armor_b", "Sarranid Guard Armor", [("arabian_armor_b",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs ,0,
 1200 , weight(19)|abundance(100)|head_armor(0)|body_armor(41)|leg_armor(12)|difficulty(12) ,imodbits_armor, [], [fac_culture_6]],
 ["sarranid_mail_shirt", "Sarranid Mail Shirt", [("sarranian_mail_shirt",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs|itp_civilian ,0,
 1400 , weight(19)|abundance(100)|head_armor(0)|body_armor(45)|leg_armor(14)|difficulty(12) ,imodbits_armor , [], [fac_culture_6]],
["mamluke_mail", "Mamluke Mail", [("sarranid_elite_cavalary",0)], itp_merchandise| itp_type_body_armor |itp_covers_legs|itp_civilian  ,0, 
2900 , weight(34)|abundance(100)|head_armor(0)|body_armor(58)|leg_armor(26)|difficulty(15) ,imodbits_armor , [], [fac_culture_6]],

#Quest-specific - perhaps can be used for prisoners, 
["burlap_tunic", "Burlap Tunic", [("shirt",0)], itp_type_body_armor  |itp_covers_legs ,0,
 55 , weight(1)|abundance(100)|head_armor(0)|body_armor(13)|leg_armor(6)|difficulty(0) ,imodbits_armor ],


["heraldic_mail_with_surcoat", "Heraldic Mail with Surcoat", [("heraldic_armor_new_a",0)],  itp_type_body_armor  |itp_covers_legs ,0,
 7454 , weight(22)|abundance(100)|head_armor(0)|body_armor(69)|leg_armor(37)|difficulty(17) ,imodbits_armor,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_heraldic_armor_a", ":agent_no", ":troop_no")])]],
["heraldic_mail_with_tunic", "Heraldic Mail", [("heraldic_armor_new_b",0)],  itp_type_body_armor  |itp_covers_legs ,0,
 7520 , weight(22)|abundance(100)|head_armor(0)|body_armor(70)|leg_armor(36)|difficulty(17) ,imodbits_armor,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_heraldic_armor_b", ":agent_no", ":troop_no")])]],
["heraldic_mail_with_tunic_b", "Heraldic Mail", [("heraldic_armor_new_c",0)],  itp_type_body_armor  |itp_covers_legs ,0,
 7610 , weight(22)|abundance(100)|head_armor(0)|body_armor(70)|leg_armor(36)|difficulty(17) ,imodbits_armor,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_heraldic_armor_c", ":agent_no", ":troop_no")])]],
["heraldic_mail_with_tabard", "Heraldic Mail with Tabard", [("heraldic_armor_new_d",0)],  itp_type_body_armor  |itp_covers_legs ,0,
 7654 , weight(21)|abundance(100)|head_armor(0)|body_armor(71)|leg_armor(35)|difficulty(17) ,imodbits_armor,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_heraldic_armor_d", ":agent_no", ":troop_no")])]],



["turret_hat_ruby", "Turret Hat", [("turret_hat_r",0)], itp_type_head_armor  |itp_civilian|itp_fit_to_head ,0, 70 , weight(0.5)|abundance(100)|head_armor(8)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ], 
["turret_hat_blue", "Turret Hat", [("turret_hat_b",0)], itp_type_head_armor  |itp_civilian|itp_fit_to_head ,0, 80 , weight(0.5)|abundance(100)|head_armor(8)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ], 
["turret_hat_green", "Barbette", [("barbette_new",0)], itp_type_head_armor|itp_civilian|itp_fit_to_head,0,70, weight(0.5)|abundance(100)|head_armor(6)|body_armor(0)|leg_armor(0)|difficulty(0),imodbits_cloth],
["head_wrappings","Head Wrapping",[("head_wrapping",0)],itp_type_head_armor|itp_fit_to_head,0,16, weight(0.25)|head_armor(3),imodbit_tattered | imodbit_ragged | imodbit_sturdy | imodbit_thick],
["court_hat", "Turret Hat", [("court_hat",0)], itp_type_head_armor  |itp_civilian|itp_fit_to_head ,0, 80 , weight(0.5)|abundance(100)|head_armor(8)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ], 
["wimple_a", "Wimple", [("wimple_a_new",0)], itp_type_head_armor|itp_civilian|itp_fit_to_head,0,10, weight(0.5)|abundance(100)|head_armor(4)|body_armor(0)|leg_armor(0)|difficulty(0),imodbits_cloth],
["wimple_with_veil", "Wimple with Veil", [("wimple_b_new",0)],itp_type_head_armor|itp_civilian|itp_fit_to_head,0,10, weight(0.5)|abundance(100)|head_armor(4)|body_armor(0)|leg_armor(0)|difficulty(0),imodbits_cloth],
["straw_hat", "Straw Hat", [("straw_hat_new",0)],itp_type_head_armor|itp_civilian,0,9, weight(1)|abundance(100)|head_armor(2)|body_armor(0)|leg_armor(0)|difficulty(0),imodbits_cloth],
["common_hood", "Hood", [("hood_new",0)],itp_type_head_armor|itp_civilian,0,9, weight(1)|abundance(100)|head_armor(10)|body_armor(0)|leg_armor(0)|difficulty(0),imodbits_cloth],
["hood_b", "Hood", [("hood_b",0)],itp_type_head_armor|itp_civilian,0,9, weight(1)|abundance(100)|head_armor(10)|body_armor(0)|leg_armor(0)|difficulty(0),imodbits_cloth],
["hood_c", "Hood", [("hood_c",0)],itp_type_head_armor|itp_civilian,0,9, weight(1)|abundance(100)|head_armor(10)|body_armor(0)|leg_armor(0)|difficulty(0),imodbits_cloth],
["hood_d", "Hood", [("hood_d",0)],itp_type_head_armor|itp_civilian,0,9, weight(1)|abundance(100)|head_armor(10)|body_armor(0)|leg_armor(0)|difficulty(0),imodbits_cloth],
["headcloth", "Headcloth", [("headcloth_a_new",0)],  itp_type_head_armor  |itp_civilian ,0, 1 , weight(0.5)|abundance(100)|head_armor(4)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["woolen_hood", "Woolen Hood", [("woolen_hood",0)],  itp_type_head_armor |itp_civilian  ,0, 4 , weight(1)|abundance(100)|head_armor(8)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["arming_cap", "Arming Cap", [("arming_cap_a_new",0)],  itp_type_head_armor  |itp_civilian ,0, 35 , weight(1)|abundance(100)|head_armor(14)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["fur_hat", "Fur Hat", [("fur_hat_a_new",0)],  itp_type_head_armor |itp_civilian  ,0, 4 , weight(0.5)|abundance(100)|head_armor(8)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["padded_coif", "Padded Coif", [("padded_coif_a_new",0)],  itp_type_head_armor   ,0, 56 , weight(1)|abundance(100)|head_armor(17)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["woolen_cap", "Woolen Cap", [("woolen_cap_new",0)],  itp_type_head_armor  |itp_civilian ,0, 2 , weight(1)|abundance(100)|head_armor(6)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["felt_hat", "Felt Hat", [("felt_hat_a_new",0)],  itp_type_head_armor |itp_civilian,0, 4 , weight(1)|abundance(100)|head_armor(8)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["felt_hat_b", "Felt Hat", [("felt_hat_b_new",0)],  itp_type_head_armor |itp_civilian,0, 4 , weight(1)|abundance(100)|head_armor(8)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["leather_cap", "Leather Cap", [("leather_cap_a_new",0)],  itp_type_head_armor|itp_civilian ,0, 48, weight(1)|abundance(100)|head_armor(18)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["female_hood", "Lady's Hood", [("ladys_hood_new",0)],  itp_type_head_armor |itp_civilian  ,0, 9 , weight(1)|abundance(100)|head_armor(10)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],


["nomad_cap", "Nomad Cap", [("nomad_cap_a_new",0)],  itp_type_head_armor |itp_civilian  ,0, 6 , weight(0.75)|abundance(100)|head_armor(10)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["nomad_cap_b", "Nomad Cap", [("nomad_cap_b_new",0)],  itp_type_head_armor |itp_civilian  ,0, 6 , weight(0.75)|abundance(100)|head_armor(13)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["steppe_cap", "Steppe Cap", [("steppe_cap_a_new",0)],  itp_type_head_armor  |itp_civilian ,0, 14 , weight(1)|abundance(100)|head_armor(16)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["leather_steppe_cap_a", "Steppe Cap", [("leather_steppe_cap_a_new",0)], itp_type_head_armor   ,0, 
24 , weight(1)|abundance(100)|head_armor(12)|body_armor(0)|leg_armor(0) ,imodbits_cloth ],
["leather_steppe_cap_b", "Steppe Cap ", [("tattered_steppe_cap_b_new",0)], itp_type_head_armor   ,0, 
136 , weight(1)|abundance(100)|head_armor(21)|body_armor(0)|leg_armor(0) ,imodbits_cloth ],
["leather_steppe_cap_c", "Steppe Cap", [("steppe_cap_a_new",0)], itp_type_head_armor   ,0,
 51 , weight(1)|abundance(100)|head_armor(16)|body_armor(0)|leg_armor(0) ,imodbits_cloth ],

["leather_warrior_cap", "Leather Warrior Cap", [("skull_cap_new_b",0)],  itp_type_head_armor  |itp_civilian ,0,
 14 , weight(1)|abundance(100)|head_armor(18)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["skullcap", "Skullcap", [("skull_cap_new_a",0)],  itp_type_head_armor   ,0,
 60 , weight(1.0)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_plate ],
["footman_helmet", "Footman's Helmet", [("skull_cap_new",0)], itp_type_head_armor   ,0,
 195 , weight(1.5)|abundance(100)|head_armor(24)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_plate ],
#missing...
["nasal_helmet", "Nasal Helmet", [("nasal_helmet_b",0)],  itp_type_head_armor   ,0,
 121 , weight(1.25)|abundance(100)|head_armor(26)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate ],
["norman_helmet", "Helmet with Cap", [("norman_helmet_a",0)], itp_merchandise| itp_type_head_armor|itp_fit_to_head ,0,
 147 , weight(1.25)|abundance(100)|head_armor(28)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate  , [], [fac_kingdom_1]],
["segmented_helmet", "Segmented Helmet", [("segmented_helm_new",0)],  itp_type_head_armor   ,0,
 174 , weight(1.25)|abundance(100)|head_armor(31)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate ],
["helmet_with_neckguard", "Helmet with Neckguard", [("neckguard_helm_new",0)], itp_type_head_armor   ,0, 
190 , weight(1.5)|abundance(100)|head_armor(32)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate ],
["flat_topped_helmet", "Flat Topped Helmet", [("flattop_helmet_new",0)],  itp_type_head_armor   ,0, 
203 , weight(1.75)|abundance(100)|head_armor(33)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate ],
["spiked_helmet", "Spiked Helmet", [("spiked_helmet_new",0)],  itp_type_head_armor   ,0,
 278 , weight(2)|abundance(100)|head_armor(38)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate ],
["nordic_helmet", "Nordic Helmet", [("helmet_w_eyeguard_new",0)],  itp_type_head_armor   ,0,
 340 , weight(2)|abundance(100)|head_armor(40)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate ],
["khergit_lady_hat", "Khergit Lady Hat", [("khergit_lady_hat",0)],  itp_type_head_armor   |itp_civilian |itp_doesnt_cover_hair | itp_fit_to_head,0,
 1 , weight(0.5)|abundance(100)|head_armor(4)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["khergit_lady_hat_b", "Khergit Lady Leather Hat", [("khergit_lady_hat_b",0)], itp_type_head_armor  | itp_doesnt_cover_hair | itp_fit_to_head  |itp_civilian ,0,
 1 , weight(0.5)|abundance(100)|head_armor(4)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],


["sarranid_felt_hat", "Sarranid Felt Hat", [("sar_helmet3",0)], itp_type_head_armor   ,0,
 16 , weight(2)|abundance(100)|head_armor(5)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_cloth ],
["turban", "Turban", [("tuareg_open",0)],  itp_type_head_armor|itp_civilian   ,0,
 128 , weight(1)|abundance(100)|head_armor(14)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_cloth ],
["desert_turban", "Desert Turban", [("tuareg",0)],  itp_type_head_armor | itp_covers_beard|itp_civilian ,0,
 138 , weight(1.50)|abundance(100)|head_armor(14)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_cloth ],
["sarranid_warrior_cap", "Sarranid Warrior Cap", [("tuareg_helmet",0)], itp_merchandise| itp_type_head_armor | itp_covers_beard  ,0,
 290 , weight(2)|abundance(100)|head_armor(24)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate , [], [fac_kingdom_6]],
["sarranid_horseman_helmet", "Horseman Helmet", [("sar_helmet2",0)], itp_merchandise| itp_type_head_armor   ,0,
 380 , weight(2.75)|abundance(100)|head_armor(32)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate , [], [fac_kingdom_6]],
["sarranid_helmet1", "Sarranid Keffiyeh Helmet", [("sar_helmet1",0)], itp_merchandise| itp_type_head_armor   ,0,
 450 , weight(2.50)|abundance(100)|head_armor(38)|body_armor(0)|leg_armor(0)|difficulty(9) ,imodbits_plate , [], [fac_culture_6]],
["sarranid_mail_coif", "Sarranid Mail Coif", [("tuareg_helmet2",0)], itp_merchandise| itp_type_head_armor ,0,
 530 , weight(3)|abundance(100)|head_armor(47)|body_armor(0)|leg_armor(0)|difficulty(12) ,imodbits_plate , [], [fac_culture_6]],
["sarranid_lord_helmet", "Sarranid Lord Coif", [("sar_lord_helmet",0)], itp_merchandise| itp_type_head_armor ,0,
 830 , weight(3)|abundance(100)|head_armor(51)|body_armor(0)|leg_armor(0)|difficulty(14) ,imodbits_plate , [], [fac_culture_6]], 
["sarranid_veiled_helmet", "Sarranid Veiled Helmet", [("sar_helmet4",0)], itp_merchandise| itp_type_head_armor | itp_covers_beard  ,0,
 910 , weight(3.50)|abundance(100)|head_armor(57)|body_armor(0)|leg_armor(0)|difficulty(15) ,imodbits_plate , [], [fac_culture_6]],


["nordic_archer_helmet", "Nordic Leather Helmet", [("Helmet_A_vs2",0)], itp_merchandise| itp_type_head_armor    ,0,
 70 , weight(1.5)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate , [], [fac_kingdom_4]],
["nordic_veteran_archer_helmet", "Nordic Leather Helmet", [("Helmet_A",0)], itp_merchandise| itp_type_head_armor,0,
 70 , weight(1.5)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate , [], [fac_kingdom_4]],
["nordic_footman_helmet", "Nordic Footman Helmet", [("Helmet_B_vs2",0)], itp_merchandise| itp_type_head_armor |itp_fit_to_head ,0,
 250 , weight(1.75)|abundance(100)|head_armor(35)|body_armor(0)|leg_armor(0)|difficulty(9) ,imodbits_plate , [], [fac_kingdom_4]],
["nordic_fighter_helmet", "Nordic Fighter Helmet", [("Helmet_B",0)], itp_merchandise| itp_type_head_armor|itp_fit_to_head ,0,
 240 , weight(2)|abundance(100)|head_armor(34)|body_armor(0)|leg_armor(0)|difficulty(10) ,imodbits_plate , [], [fac_kingdom_4]],
["nordic_huscarl_helmet", "Nordic Huscarl's Helmet", [("Helmet_C_vs2",0)], itp_merchandise| itp_type_head_armor   ,0,
 390 , weight(2)|abundance(100)|head_armor(40)|body_armor(0)|leg_armor(0)|difficulty(12) ,imodbits_plate , [], [fac_culture_4]],
["nordic_warlord_helmet", "Nordic Warlord Helmet", [("Helmet_C",0)], itp_merchandise| itp_type_head_armor ,0,
 880 , weight(2.25)|abundance(100)|head_armor(48)|body_armor(0)|leg_armor(0)|difficulty(14) ,imodbits_plate , [], [fac_culture_4]],
["nordic_warlord_heavy_helmet", "Nordic Warlord Helmet", [("Helmet_D",0),("inv_Helmet_D", ixmesh_inventory)], itp_merchandise| itp_type_head_armor ,0,
 920 , weight(2.25)|abundance(100)|head_armor(52)|body_armor(0)|leg_armor(0)|difficulty(17) ,imodbits_plate , [], [fac_culture_4]],

["vaegir_fur_cap", "Cap with Fur", [("vaeg_helmet3",0)], itp_merchandise| itp_type_head_armor   ,0,
 200 , weight(2)|abundance(100)|head_armor(26)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate , [], [fac_kingdom_2]],
["vaegir_fur_helmet", "Vaegir Helmet", [("vaeg_helmet2",0)], itp_merchandise| itp_type_head_armor   ,0,
 230 , weight(2)|abundance(100)|head_armor(28)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate , [], [fac_kingdom_2]],
["vaegir_spiked_helmet", "Spiked Cap", [("vaeg_helmet1",0)], itp_merchandise| itp_type_head_armor   ,0,
 230 , weight(2.50)|abundance(100)|head_armor(32)|body_armor(0)|leg_armor(0)|difficulty(8) ,imodbits_plate , [], [fac_kingdom_2]],
["vaegir_lamellar_helmet", "Helmet with Lamellar Guard", [("vaeg_helmet4",0)], itp_merchandise| itp_type_head_armor   ,0,
 230 , weight(2.75)|abundance(100)|head_armor(38)|body_armor(0)|leg_armor(0)|difficulty(9) ,imodbits_plate , [], [fac_kingdom_2]],
["vaegir_good_helmet", "Vaegir Nobleman Helmet", [("vaeg_helmet7",0)], itp_merchandise| itp_type_head_armor   ,0,
 710, weight(2.75)|abundance(100)|head_armor(45)|body_armor(0)|leg_armor(0)|difficulty(9) ,imodbits_plate , [], [fac_kingdom_2]],
["vaegir_noble_helmet", "Vaegir Nobleman Helmet", [("vaeg_helmet5",0)], itp_merchandise| itp_type_head_armor   ,0,
 710, weight(2.75)|abundance(100)|head_armor(45)|body_armor(0)|leg_armor(0)|difficulty(9) ,imodbits_plate , [], [fac_culture_2]],
["vaegir_war_helmet", "Vaegir War Helmet", [("vaeg_helmet6",0)], itp_merchandise| itp_type_head_armor   ,0,
 820 , weight(3)|abundance(100)|head_armor(47)|body_armor(0)|leg_armor(0)|difficulty(12) ,imodbits_plate , [], [fac_culture_2]],
["vaegir_mask", "Vaegir War Mask", [("vaeg_helmet9",0)], itp_merchandise| itp_type_head_armor |itp_covers_beard ,0,
 1350 , weight(3.50)|abundance(100)|head_armor(52)|body_armor(0)|leg_armor(0)|difficulty(18) ,imodbits_plate , [], [fac_culture_2]],
["vaegir_half_mask", "Vaegir War Mask", [("vaeg_helmet8",0)], itp_merchandise| itp_type_head_armor |itp_covers_beard ,0,
 1350 , weight(3.50)|abundance(100)|head_armor(52)|body_armor(0)|leg_armor(0)|difficulty(18) ,imodbits_plate , [], [fac_culture_2]],
["vaegir_wild_lord_mask", "Vaegir War Mask", [("valhelm_c",0)], itp_merchandise| itp_type_head_armor  ,0,
 1950 , weight(3.50)|abundance(100)|head_armor(57)|body_armor(0)|leg_armor(0)|difficulty(15) ,imodbits_plate , [], [fac_culture_2,fac_culture_4]],
 
["mail_coif", "Mail Coif", [("mail_coif_new",0)], itp_merchandise| itp_type_head_armor   ,0,
 371 , weight(2.25)|abundance(70)|head_armor(32)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_armor , [], [fac_kingdom_1]],
["kettle_hat", "Kettle Hat", [("Helmet_L",0)], itp_merchandise| itp_type_head_armor,0, 
440 , weight(2.75)|abundance(100)|head_armor(38)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate , [], [fac_kingdom_1]],
["kettle_helmet", "Kettle Hat", [("helmet_looter_2",0)], itp_merchandise| itp_type_head_armor,0, 
340 , weight(1.75)|abundance(100)|head_armor(35)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate , [], [fac_kingdom_1]],

["bascinet", "Bascinet", [("bascinet_avt_new",0)], itp_merchandise|itp_type_head_armor   ,0,
 479 , weight(2.25)|abundance(100)|head_armor(45)|body_armor(0)|leg_armor(0)|difficulty(8) ,imodbits_plate , [], [fac_kingdom_1]],
["bascinet_2", "Bascinet with Aventail", [("bascinet_new_a",0)], itp_merchandise|itp_type_head_armor   ,0,
 479 , weight(2.25)|abundance(100)|head_armor(45)|body_armor(0)|leg_armor(0)|difficulty(8) ,imodbits_plate , [], [fac_kingdom_1]],
["bascinet_3", "Bascinet with Nose Guard", [("bascinet_new_b",0)], itp_merchandise|itp_type_head_armor   ,0,
 479 , weight(2.25)|abundance(100)|head_armor(45)|body_armor(0)|leg_armor(0)|difficulty(8) ,imodbits_plate , [], [fac_kingdom_1]],
["guard_helmet", "Guard Helmet", [("Helmet_K",0)], itp_merchandise| itp_type_head_armor   ,0,
 555 , weight(2.5)|abundance(100)|head_armor(47)|body_armor(0)|leg_armor(0)|difficulty(9) ,imodbits_plate , [], [fac_culture_1]],
["full_helm", "Full Helm", [("great_helmet_new_b",0)], itp_merchandise| itp_type_head_armor |itp_covers_head ,0,
 811 , weight(2.5)|abundance(100)|head_armor(51)|body_armor(0)|leg_armor(0)|difficulty(10) ,imodbits_plate , [], [fac_culture_1]],
["great_helmet", "Great Helmet", [("great_helmet_new",0)], itp_merchandise| itp_type_head_armor|itp_covers_head,0,
 980 , weight(2.75)|abundance(100)|head_armor(56)|body_armor(0)|leg_armor(0)|difficulty(12) ,imodbits_plate , [], [fac_culture_1]],
["winged_great_helmet", "Winged Great Helmet", [("maciejowski_helmet_new",0)], itp_merchandise|itp_type_head_armor|itp_covers_head,0,
 1240 , weight(3.75)|abundance(100)|head_armor(65)|body_armor(0)|leg_armor(0)|difficulty(20) ,imodbits_plate , [], [fac_culture_1]],
["full_plate_helmet", "Full Helmet", [("full_plate_helmet",0)], itp_merchandise| itp_type_head_armor   ,0,
 2555 , weight(3.5)|abundance(10)|head_armor(57)|body_armor(0)|leg_armor(0)|difficulty(19) ,imodbits_plate , [], [fac_culture_1]],
["elit_helmet", "Full Helmet", [("elit_helmet",0)],  itp_type_head_armor   ,0,
 2255 , weight(3.5)|abundance(10)|head_armor(54)|body_armor(0)|leg_armor(0)|difficulty(17) ,imodbits_plate , [], [fac_culture_1]],
["elit_helmet2", "Full Helmet", [("elit_helmet2",0)],  itp_merchandise|itp_type_head_armor   ,0,
 4255 , weight(3.5)|abundance(10)|head_armor(74)|body_armor(0)|leg_armor(0)|difficulty(21) ,imodbits_plate , [], [fac_culture_1]],
 
["black_helmet", "Black Helmet", [("black_helm",0)], itp_type_head_armor,0, 638 , weight(2.75)|abundance(100)|head_armor(50)|body_armor(0)|leg_armor(0)|difficulty(9) ,imodbits_plate ],


#WEAPONS
["wooden_stick",         "Wooden Stick", [("wooden_stick",0)], itp_type_one_handed_wpn| itp_primary|itp_wooden_parry|itp_wooden_attack, itc_scimitar, 
4 , weight(2.5)|difficulty(0)|spd_rtng(99) | weapon_length(63)|swing_damage(13 , blunt) | thrust_damage(0 ,  pierce),imodbits_none ],
["cudgel",         "Cudgel", [("club",0)], itp_type_one_handed_wpn| itp_primary|itp_wooden_parry|itp_wooden_attack, itc_scimitar, 
4 , weight(2.5)|difficulty(0)|spd_rtng(99) | weapon_length(70)|swing_damage(13 , blunt) | thrust_damage(0 ,  pierce),imodbits_none ],
["hammer",         "Hammer", [("iron_hammer_new",0)], itp_type_one_handed_wpn|itp_can_knock_down| itp_primary|itp_wooden_parry, itc_scimitar, 
7 , weight(2)|difficulty(0)|spd_rtng(100) | weapon_length(55)|swing_damage(24 , blunt) | thrust_damage(0 ,  pierce),imodbits_mace ],

["club",         "Club", [("club",0)], itp_unique|itp_type_one_handed_wpn|itp_primary, itc_scimitar, 11 , weight(2.5)|difficulty(0)|spd_rtng(95) | weapon_length(95)|swing_damage(11 , blunt) | thrust_damage(0 ,  pierce),imodbits_none,
 [(ti_on_init_item, [
     (is_currently_night), 
     (set_position_delta,0,60,0),
     (particle_system_add_new, "psys_torch_fire"),
     (particle_system_add_new, "psys_torch_smoke"),
     (set_current_color,150, 130, 70),
     (add_point_light, 10, 30),
])]],

["winged_mace",         "Flanged Mace", [("flanged_mace",0)], itp_type_one_handed_wpn|itp_can_knock_down| itp_primary|itp_wooden_parry, itc_scimitar|itcf_carry_mace_left_hip, 
122 , weight(3.5)|difficulty(0)|spd_rtng(103) | weapon_length(70)|swing_damage(24 , blunt) | thrust_damage(0 ,  pierce),imodbits_mace ],
["spiked_mace",         "Spiked Mace", [("spiked_mace_new",0)], itp_unique|itp_type_one_handed_wpn|itp_can_knock_down| itp_primary|itp_wooden_parry, itc_scimitar|itcf_carry_mace_left_hip, 
180 , weight(3.5)|difficulty(0)|spd_rtng(98) | weapon_length(70)|swing_damage(28 , blunt) | thrust_damage(0 ,  pierce),imodbits_pick ],
["military_hammer", "Military Hammer", [("military_hammer",0)], itp_type_one_handed_wpn|itp_can_knock_down| itp_primary|itp_wooden_parry, itc_scimitar|itcf_carry_mace_left_hip, 
317 , weight(2)|difficulty(0)|spd_rtng(95) | weapon_length(70)|swing_damage(31 , blunt) | thrust_damage(0 ,  pierce),imodbits_mace ],
["maul",         "Maul", [("maul_b",0)], itp_crush_through|itp_type_two_handed_wpn|itp_can_knock_down |itp_primary|itp_two_handed|itp_wooden_parry|itp_wooden_attack|itp_unbalanced, itc_nodachi|itcf_carry_spear, 
97 , weight(6)|difficulty(11)|spd_rtng(83) | weapon_length(79)|swing_damage(36 , blunt) | thrust_damage(0 ,  pierce),imodbits_mace ],
["sledgehammer", "Sledgehammer", [("maul_c",0)], itp_crush_through|itp_type_two_handed_wpn|itp_can_knock_down|itp_primary|itp_two_handed|itp_wooden_parry|itp_wooden_attack|itp_unbalanced, itc_nodachi|itcf_carry_spear, 
101 , weight(7)|difficulty(12)|spd_rtng(81) | weapon_length(82)|swing_damage(39, blunt) | thrust_damage(0 ,  pierce),imodbits_mace ],
["warhammer",         "Great Hammer", [("maul_d",0)], itp_crush_through|itp_type_two_handed_wpn|itp_can_knock_down|itp_primary|itp_two_handed|itp_wooden_parry|itp_wooden_attack|itp_unbalanced, itc_nodachi|itcf_carry_spear, 
290 , weight(9)|difficulty(14)|spd_rtng(79) | weapon_length(75)|swing_damage(45 , blunt) | thrust_damage(0 ,  pierce),imodbits_mace ],
["pickaxe",         "Pickaxe", [("fighting_pick_new",0)], itp_type_one_handed_wpn|itp_primary|itp_wooden_parry, itc_scimitar|itcf_carry_mace_left_hip, 
27 , weight(3)|difficulty(0)|spd_rtng(99) | weapon_length(70)|swing_damage(19 , pierce) | thrust_damage(0 ,  pierce),imodbits_pick ],
["spiked_club",         "Spiked Club", [("spiked_club",0)], itp_unique|itp_type_two_handed_wpn|itp_primary|itp_wooden_parry, itc_morningstar, 
83 , weight(3)|difficulty(0)|spd_rtng(97) | weapon_length(70)|swing_damage(21 , pierce) | thrust_damage(0 ,  pierce),imodbits_mace ],

["fighting_pick", "Fighting Pick", [("fighting_pick_new",0)], itp_type_one_handed_wpn|itp_merchandise|itp_primary|itp_wooden_parry, itc_scimitar|itcf_carry_mace_left_hip, 
308 , weight(1.0)|difficulty(10)|spd_rtng(88) | weapon_length(70)|swing_damage(32 , pierce) | thrust_damage(0 ,  pierce),imodbits_pick , [], [fac_kingdom_1]],
["military_pick", "Military Pick", [("steel_pick_new",0)], itp_type_one_handed_wpn|itp_merchandise|itp_primary|itp_wooden_parry, itc_scimitar|itcf_carry_mace_left_hip, 
280 , weight(1.5)|difficulty(10)|spd_rtng(87) | weapon_length(70)|swing_damage(31 , pierce) | thrust_damage(0 ,  pierce),imodbits_pick , [], [fac_kingdom_1]],
["morningstar",         "Morningstar", [("mace_morningstar_new",0)], itp_crush_through|itp_type_two_handed_wpn|itp_merchandise|itp_primary|itp_wooden_parry|itp_unbalanced, itc_morningstar|itcf_carry_mace_left_hip, 
305 , weight(4.5)|difficulty(23)|spd_rtng(85) | weapon_length(85)|swing_damage(48 , pierce) | thrust_damage(0 ,  pierce),imodbits_mace , [], [fac_culture_1]],


["sickle",         "Sickle", [("sickle",0)], itp_type_one_handed_wpn|itp_primary|itp_secondary|itp_no_parry|itp_wooden_parry, itc_cleaver, 
9 , weight(1.5)|difficulty(0)|spd_rtng(99) | weapon_length(40)|swing_damage(20 , cut) | thrust_damage(0 ,  pierce),imodbits_none ],
["cleaver",         "Cleaver", [("cleaver_new",0)], itp_type_one_handed_wpn|itp_primary|itp_secondary|itp_no_parry|itp_wooden_parry, itc_cleaver, 
14 , weight(1.5)|difficulty(0)|spd_rtng(103) | weapon_length(35)|swing_damage(24 , cut) | thrust_damage(0 ,  pierce),imodbits_none ],
["knife",         "Knife", [("peasant_knife_new",0)], itp_type_one_handed_wpn|itp_primary|itp_secondary|itp_no_parry, itc_dagger|itcf_carry_dagger_front_left, 
18 , weight(0.5)|difficulty(0)|spd_rtng(110) | weapon_length(40)|swing_damage(21 , cut) | thrust_damage(13 ,  pierce),imodbits_sword ],
["butchering_knife", "Butchering Knife", [("khyber_knife_new",0)], itp_type_one_handed_wpn|itp_primary|itp_secondary|itp_no_parry, itc_dagger|itcf_carry_dagger_front_right, 
23 , weight(0.75)|difficulty(0)|spd_rtng(108) | weapon_length(60)|swing_damage(24 , cut) | thrust_damage(17 ,  pierce),imodbits_sword ],
["hatchet",         "Hatchet", [("hatchet",0)], itp_type_one_handed_wpn| itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_axe_left_hip, 
13 , weight(2)|difficulty(0)|spd_rtng(97) | weapon_length(60)|swing_damage(23 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
["hand_axe",         "Hand Axe", [("one_handed_axe",0),("one_handed_axe_scab", ixmesh_carry)],
 itp_type_one_handed_wpn| itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_quiver_right_vertical, 
524 , weight(2)|difficulty(7)|spd_rtng(85) | weapon_length(75)|swing_damage(32 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
["fighting_axe", "Fighting Axe", [("fighting_ax",0)], itp_type_one_handed_wpn| itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_axe_left_hip, 
77 , weight(2.5)|difficulty(9)|spd_rtng(92) | weapon_length(90)|swing_damage(31 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
["voulge1",         "Voulge", [("voulge",0)], itp_type_two_handed_wpn| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry, itc_nodachi|itcf_carry_axe_back, 
129 , weight(4.5)|difficulty(8)|spd_rtng(87) | weapon_length(119)|swing_damage(35 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
["battle_axe",         "Battle Axe", [("battle_ax",0)], itp_type_two_handed_wpn| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry, itc_nodachi|itcf_carry_axe_back, 
240 , weight(5)|difficulty(9)|spd_rtng(88) | weapon_length(108)|swing_damage(41 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
["war_axe",         "War Axe", [("war_ax",0)], itp_type_two_handed_wpn| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry, itc_nodachi|itcf_carry_axe_back, 
264 , weight(5)|difficulty(10)|spd_rtng(86) | weapon_length(110)|swing_damage(43 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],

["sword_two_handed_b",         "Two Handed Sword", [("sword_two_handed_b",0)], itp_type_two_handed_wpn|itp_merchandise| itp_two_handed|itp_primary, itc_greatsword|itcf_carry_sword_back,
 1123 , weight(2.75)|difficulty(20)|spd_rtng(97) | weapon_length(110)|swing_damage(50 , cut) | thrust_damage(29 ,  pierce),imodbits_sword_high , [], [fac_culture_1]],
["sword_two_handed_a",         "Two Handed Sword", [("sword_two_handed_a",0)], itp_type_two_handed_wpn|itp_merchandise|itp_two_handed|itp_primary, itc_greatsword|itcf_carry_sword_back,
 1123 , weight(2.75)|difficulty(20)|spd_rtng(96) | weapon_length(110)|swing_damage(50 , cut) | thrust_damage(29 ,  pierce),imodbits_sword_high , [], [fac_culture_1]],
["great_sword",         "Great Sword", [("b_bastard_sword",0),("scab_bastardsw_b", ixmesh_carry)], itp_type_two_handed_wpn|itp_merchandise| itp_two_handed|itp_primary, itc_greatsword|itcf_carry_sword_back|itcf_show_holster_when_drawn,
 1423 , weight(2.75)|difficulty(20)|spd_rtng(95) | weapon_length(125)|swing_damage(50 , cut) | thrust_damage(31 ,  pierce),imodbits_sword_high , [], [fac_culture_1]],
["sword_of_war", "Sword of War", [("b_bastard_sword",0),("scab_bastardsw_b", ixmesh_carry)], itp_type_two_handed_wpn|itp_merchandise| itp_two_handed|itp_primary, itc_greatsword|itcf_carry_sword_back|itcf_show_holster_when_drawn,
 1524 , weight(3)|difficulty(21)|spd_rtng(94) | weapon_length(130)|swing_damage(50 , cut) | thrust_damage(31 ,  pierce),imodbits_sword_high , [], [fac_culture_1]],





["falchion",         "Falchion", [("falchion_new",0)], itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_scimitar|itcf_carry_sword_left_hip, 
405 , weight(2.5)|difficulty(8)|spd_rtng(86) | weapon_length(68)|swing_damage(30 , cut) | thrust_damage(0 ,  pierce),imodbits_sword , [], [fac_kingdom_1]],
["military_cleaver_b", "Soldier's Cleaver", [("military_cleaver_b",0)], itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_scimitar|itcf_carry_sword_left_hip,
 493 , weight(2.5)|difficulty(9)|spd_rtng(86) | weapon_length(85)|swing_damage(31 , cut) | thrust_damage(0 ,  pierce),imodbits_sword_high , [], [fac_kingdom_1]],
["military_cleaver_c", "Military Cleaver", [("military_cleaver_c",0)], itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_scimitar|itcf_carry_sword_left_hip,
 463 , weight(2.5)|difficulty(9)|spd_rtng(86) | weapon_length(85)|swing_damage(35 , cut) | thrust_damage(0 ,  pierce),imodbits_sword_high , [], [fac_kingdom_1]],
["military_sickle_a", "Military Sickle", [("military_sickle_a",0)], itp_type_one_handed_wpn|itp_merchandise| itp_primary|itp_secondary|itp_wooden_parry,
 itc_scimitar|itcf_carry_axe_left_hip,
 920 , weight(3.0)|difficulty(9)|spd_rtng(90) | weapon_length(75)|swing_damage(46 , pierce) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_culture_1]],


["bastard_sword_a", "Bastard Sword", [("bastard_sword_a",0),("bastard_sword_a_scabbard", ixmesh_carry)],
 itp_type_two_handed_wpn|itp_merchandise| itp_primary, itc_bastardsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 1594 , weight(2.0)|difficulty(9)|spd_rtng(98) | weapon_length(101)|swing_damage(35 , cut) | thrust_damage(26 ,  pierce),imodbits_sword_high , [], [fac_culture_1]],
["bastard_sword_b", "Heavy Bastard Sword", [("bastard_sword_b",0),("bastard_sword_b_scabbard", ixmesh_carry)],
 itp_type_two_handed_wpn|itp_merchandise| itp_primary, itc_bastardsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 1526 , weight(2.25)|difficulty(9)|spd_rtng(97) | weapon_length(105)|swing_damage(37 , cut) | thrust_damage(27 ,  pierce),imodbits_sword_high , [], [fac_culture_1]],
["bastard_axe", "Heavy Bastard Axe", [("two_handed_axe",0),("two_handed_axe_scab", ixmesh_carry)],
 itp_type_two_handed_wpn|itp_merchandise| itp_primary, itc_morningstar|itcf_carry_axe_back|itcf_show_holster_when_drawn,
 1526 , weight(2.25)|difficulty(9)|spd_rtng(87) | weapon_length(85)|swing_damage(47 , cut) | thrust_damage(0 ,  blunt),imodbits_axe , [], [fac_culture_2,fac_culture_4]],

["one_handed_war_axe_a", "One Handed Axe", [("one_handed_war_axe_a",0)],
 itp_type_one_handed_wpn|itp_merchandise| itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_axe_left_hip,
 287 , weight(1.5)|difficulty(9)|spd_rtng(82) | weapon_length(65)|swing_damage(32 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_kingdom_2,fac_kingdom_4]],
["one_handed_battle_axe_a", "One Handed War Axe", [("one_handed_battle_axe_a",0)],
 itp_type_one_handed_wpn|itp_merchandise| itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_axe_left_hip,
 442 , weight(2.5)|difficulty(14)|spd_rtng(78) | weapon_length(73)|swing_damage(44 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_kingdom_2,fac_kingdom_4]],
["one_handed_war_axe_b", "One Handed War Axe", [("one_handed_war_axe_b",0)],
 itp_type_one_handed_wpn|itp_merchandise| itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_axe_left_hip,
 590 , weight(2.5)|difficulty(14)|spd_rtng(78) | weapon_length(76)|swing_damage(44 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_culture_2,fac_culture_4]],

["one_handed_battle_axe_b", "One Handed Battle Axe", [("one_handed_battle_axe_b",0)],
 itp_type_one_handed_wpn|itp_merchandise| itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_axe_left_hip,
 530 , weight(1.75)|difficulty(12)|spd_rtng(78) | weapon_length(72)|swing_damage(46 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_culture_1]],
["one_handed_battle_axe_c", "One Handed Battle Axe", [("one_handed_battle_axe_c",0)],
 itp_type_one_handed_wpn|itp_merchandise| itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_axe_left_hip,
 550 , weight(3.0)|difficulty(14)|spd_rtng(78) | weapon_length(76)|swing_damage(47 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_culture_1]],




["great_axe",         "Great Axe", [("two_handed_battle_axe_e",0)],
 itp_type_two_handed_wpn| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_unbalanced, itc_nodachi|itcf_carry_axe_back,
 316 , weight(4.5)|difficulty(10)|spd_rtng(94) | weapon_length(96)|swing_damage(47 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
["long_axe",         "Long Axe", [("long_axe_a",0)],
 itp_type_polearm|itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_next_item_as_melee|itp_unbalanced,itc_staff|itcf_carry_axe_back,
 390 , weight(4.75)|difficulty(10)|spd_rtng(93) | weapon_length(120)|swing_damage(46 , cut) | thrust_damage(19 ,  blunt),imodbits_axe ],
["long_axe_alt",         "Long Axe", [("long_axe_a",0)],
 itp_type_two_handed_wpn|itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_unbalanced, itc_nodachi|itcf_carry_axe_back,
 390 , weight(4.75)|difficulty(10)|spd_rtng(88) | weapon_length(120)|swing_damage(46 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
 ["long_axe_b",         "Long War Axe", [("long_axe_b",0)],
  itp_type_polearm| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_next_item_as_melee|itp_unbalanced, itc_staff|itcf_carry_axe_back,
 510 , weight(5.0)|difficulty(10)|spd_rtng(92) | weapon_length(125)|swing_damage(50 , cut) | thrust_damage(18 ,  blunt),imodbits_axe ],
["long_axe_b_alt",         "Long War Axe", [("long_axe_b",0)],
 itp_type_two_handed_wpn| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_unbalanced, itc_nodachi|itcf_carry_axe_back,
 510 , weight(5.0)|difficulty(10)|spd_rtng(87) | weapon_length(125)|swing_damage(50 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
 ["long_axe_c",         "Great Long Axe", [("long_axe_c",0)],
  itp_type_polearm| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_next_item_as_melee|itp_unbalanced, itc_staff|itcf_carry_axe_back,
 660 , weight(5.5)|difficulty(10)|spd_rtng(91) | weapon_length(127)|swing_damage(54 , cut) | thrust_damage(19 ,  blunt),imodbits_axe ],
["long_axe_c_alt",      "Great Long Axe", [("long_axe_c",0)],
 itp_type_two_handed_wpn| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_unbalanced, itc_nodachi|itcf_carry_axe_back,
 660 , weight(5.5)|difficulty(10)|spd_rtng(85) | weapon_length(127)|swing_damage(54 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
["great_bardiche",         "Great Bardiche", [("two_handed_battle_axe_f",0)],
 itp_type_two_handed_wpn|itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_unbalanced, itc_nodachi|itcf_carry_axe_back,
 617 , weight(5.0)|difficulty(10)|spd_rtng(89) | weapon_length(116)|swing_damage(50 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
["great_long_bardiche",         "Great Long Bardiche", [("two_handed_battle_long_axe_c",0)],
 itp_type_polearm| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry, itc_staff,
 660 , weight(5.0)|difficulty(12)|spd_rtng(88) | weapon_length(155)|swing_damage(50 , cut) | thrust_damage(17 ,  pierce),imodbits_axe ],
["shortened_military_scythe",         "Shortened Military Scythe", [("two_handed_battle_scythe_a",0)],
 itp_type_two_handed_wpn| itp_two_handed|itp_primary, itc_nodachi|itcf_carry_sword_back,
 264 , weight(3.0)|difficulty(10)|spd_rtng(90) | weapon_length(112)|swing_damage(45 , cut) | thrust_damage(0 ,  pierce),imodbits_sword_high ],
["long_bardiche",         "Long Bardiche", [("two_handed_battle_long_axe_b",0)],
 itp_type_polearm| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry, itc_staff,
390 , weight(4.75)|difficulty(11)|spd_rtng(79) | weapon_length(140)|swing_damage(48 , cut) | thrust_damage(17 ,  pierce),imodbits_axe ],





["sword_medieval_b_small", "Short Sword", [("sword_medieval_b_small",0),("sword_medieval_b_small_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 252 , weight(1)|difficulty(5)|spd_rtng(102) | weapon_length(85)|swing_damage(26, cut) | thrust_damage(24, pierce),imodbits_sword_high , [], [fac_kingdom_1]],
["sword_medieval_c_small", "Short Arming Sword", [("sword_medieval_c_small",0),("sword_medieval_c_small_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 243 , weight(1)|difficulty(5)|spd_rtng(103) | weapon_length(86)|swing_damage(26, cut) | thrust_damage(24 ,  pierce),imodbits_sword_high , [], [fac_kingdom_1]],

["sword_medieval_c", "Arming Sword", [("sword_medieval_c",0),("sword_medieval_c_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 410 , weight(1.5)|difficulty(0)|spd_rtng(99) | weapon_length(95)|swing_damage(33 , cut) | thrust_damage(24 ,  pierce),imodbits_sword_high , [], [fac_kingdom_1]],
["sword_medieval_a", "Sword", [("sword_medieval_a",0),("sword_medieval_a_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 263 , weight(1.5)|difficulty(7)|spd_rtng(99) | weapon_length(95)|swing_damage(27 , cut) | thrust_damage(22 ,  pierce),imodbits_sword_high , [], [fac_kingdom_1]],
["sword_medieval_b", "Sword", [("sword_medieval_b",0),("sword_medieval_b_scabbard", ixmesh_carry),("sword_rusty_a",imodbit_rusty),("sword_rusty_a_scabbard", ixmesh_carry|imodbit_rusty)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 243 , weight(1.5)|difficulty(7)|spd_rtng(99) | weapon_length(95)|swing_damage(28 , cut) | thrust_damage(23 ,  pierce),imodbits_sword_high , [], [fac_kingdom_1]],

["sword_medieval_c_long", "Arming Sword", [("sword_medieval_c_long",0),("sword_medieval_c_long_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 480 , weight(1.7)|difficulty(8)|spd_rtng(91) | weapon_length(100)|swing_damage(35 , cut) | thrust_damage(28 ,  pierce),imodbits_sword_high , [], [fac_culture_1]],
["sword_medieval_d_long", "Long Arming Sword", [("sword_medieval_d_long",0),("sword_medieval_d_long_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 550 , weight(1.8)|difficulty(9)|spd_rtng(92) | weapon_length(105)|swing_damage(39 , cut) | thrust_damage(28 ,  pierce),imodbits_sword , [], [fac_culture_1]],
 

["sword_viking_1", "Nordic Sword", [("sword_viking_c",0),("sword_viking_c_scabbard ", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 147 , weight(1.5)|difficulty(7)|spd_rtng(99) | weapon_length(94)|swing_damage(28 , cut) | thrust_damage(20 ,  pierce),imodbits_sword_high , [], [fac_kingdom_4]] ,
["sword_viking_2", "Nordic Sword", [("sword_viking_b",0),("sword_viking_b_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 276 , weight(1.5)|difficulty(7)|spd_rtng(99) | weapon_length(95)|swing_damage(29 , cut) | thrust_damage(21 ,  pierce),imodbits_sword_high , [], [fac_kingdom_4]],
["sword_viking_2_small", "Nordic Short Sword", [("sword_viking_b_small",0),("sword_viking_b_small_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 162 , weight(1.25)|difficulty(5)|spd_rtng(103) | weapon_length(85)|swing_damage(28 , cut) | thrust_damage(21 ,  pierce),imodbits_sword_high , [], [fac_kingdom_4]],
["sword_viking_3", "Nordic War Sword", [("sword_viking_a",0),("sword_viking_a_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 394 , weight(1.5)|difficulty(9)|spd_rtng(99) | weapon_length(95)|swing_damage(35 , cut) | thrust_damage(21 ,  pierce),imodbits_sword_high , [], [fac_kingdom_4]],
["sword_viking_3_small", "Nordic Short War Sword", [("sword_viking_a_small",0),("sword_viking_a_small_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 280 , weight(1.25)|difficulty(5)|spd_rtng(103) | weapon_length(86)|swing_damage(29 , cut) | thrust_damage(21 ,  pierce),imodbits_sword_high , [], [fac_kingdom_4]],
["sword_viking_c_long", "Nordic Short War Sword", [("sword_viking_c_long",0),("sword_viking_c_long_scabbard ", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 242 , weight(1.5)|difficulty(8)|spd_rtng(95) | weapon_length(105)|swing_damage(31 , cut) | thrust_damage(19 ,  pierce),imodbits_sword , [], [fac_culture_4]] ,


["sword_khergit_2", "Sabre", [("khergit_sword_c",0),("khergit_sword_c_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_scimitar|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 191 , weight(1.5)|difficulty(7)|spd_rtng(99) | weapon_length(97)|swing_damage(30 , cut),imodbits_sword_high , [], [fac_kingdom_3]],
["sword_khergit_3", "Sabre", [("khergit_sword_a",0),("khergit_sword_a_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_scimitar|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 294 , weight(1.5)|difficulty(7)|spd_rtng(99) | weapon_length(98)|swing_damage(31 , cut),imodbits_sword_high , [], [fac_kingdom_3]],
["sword_khergit_4", "Heavy Sabre", [("khergit_sword_d",0),("khergit_sword_d_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_scimitar|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 684 , weight(1.75)|difficulty(9)|spd_rtng(98) | weapon_length(96)|swing_damage(37 , cut),imodbits_sword_high , [], [fac_culture_3]],
["scimitar",         "Scimitar", [("scimitar_a",0),("scab_scimeter_a", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_scimitar|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn, 
210 , weight(1.5)|difficulty(6)|spd_rtng(101) | weapon_length(97)|swing_damage(30 , cut) | thrust_damage(0 ,  pierce),imodbits_sword_high , [], [fac_kingdom_3]],
["scimitar_b",         "Elite Scimitar", [("scimitar_b",0),("scab_scimeter_b", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_scimitar|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn, 
290 , weight(1.5)|difficulty(6)|spd_rtng(100) | weapon_length(103)|swing_damage(32 , cut) | thrust_damage(0 ,  pierce),imodbits_sword_high , [], [fac_kingdom_3]],
 ["hafted_blade_b",         "Hafted Blade", [("khergit_pike_b",0)],
  itp_type_polearm|itp_merchandise| itp_primary|itp_two_handed|itp_penalty_with_shield|itp_wooden_parry, itc_guandao|itcf_carry_spear,
 585 , weight(2.75)|difficulty(10)|spd_rtng(95) | weapon_length(135)|swing_damage(37 , cut) | thrust_damage(20 ,  pierce),imodbits_polearm , [], [fac_culture_3]],
 ["hafted_blade_a",         "Hafted Blade", [("khergit_pike_a",0)],
  itp_type_polearm|itp_merchandise| itp_primary|itp_two_handed|itp_penalty_with_shield|itp_wooden_parry, itc_guandao|itcf_carry_spear,
 550 , weight(3.25)|difficulty(12)|spd_rtng(93) | weapon_length(153)|swing_damage(39 , cut) | thrust_damage(19 ,  pierce),imodbits_polearm , [], [fac_culture_3]],
["khergit_sword_two_handed_a",         "Two Handed Sabre", [("khergit_sword_two_handed_a",0)],
 itp_type_two_handed_wpn|itp_merchandise|itp_two_handed|itp_primary, itc_nodachi|itcf_carry_sword_back,
 523 , weight(2.75)|difficulty(10)|spd_rtng(96) | weapon_length(120)|swing_damage(40 , cut) | thrust_damage(0 ,  pierce),imodbits_sword_high , [], [fac_culture_3,fac_culture_6]],
["khergit_sword_two_handed_b",         "Two Handed Sabre", [("khergit_sword_two_handed_b",0)],
 itp_type_two_handed_wpn|itp_merchandise|itp_two_handed|itp_primary, itc_nodachi|itcf_carry_sword_back,
 520 , weight(2.75)|difficulty(10)|spd_rtng(96) | weapon_length(120)|swing_damage(41 , cut) | thrust_damage(0 ,  pierce),imodbits_sword_high , [], [fac_culture_3,fac_culture_6]],



["mace_1",         "Spiked Club", [("mace_d",0)], itp_type_one_handed_wpn|itp_can_knock_down|itp_merchandise| itp_primary|itp_wooden_parry, itc_scimitar|itcf_carry_mace_left_hip,
 45 , weight(1.5)|difficulty(7)|spd_rtng(89) | weapon_length(70)|swing_damage(19 , pierce) | thrust_damage(0 ,  pierce),imodbits_mace , [], [fac_kingdom_1]],
["mace_2",         "Knobbed_Mace", [("mace_a",0)], itp_type_one_handed_wpn|itp_can_knock_down|itp_merchandise| itp_primary|itp_wooden_parry, itc_scimitar|itcf_carry_mace_left_hip,
 348 , weight(2.5)|difficulty(10)|spd_rtng(88) | weapon_length(70)|swing_damage(33 , blunt) | thrust_damage(0 ,  pierce),imodbits_mace , [], [fac_kingdom_1]],
["mace_3",         "Spiked Mace", [("mace_c",0)], itp_type_one_handed_wpn|itp_can_knock_down|itp_merchandise| itp_primary|itp_wooden_parry, itc_scimitar|itcf_carry_mace_left_hip,
 352 , weight(2.75)|difficulty(10)|spd_rtng(88) | weapon_length(70)|swing_damage(33 , blunt) | thrust_damage(0 ,  pierce),imodbits_mace , [], [fac_kingdom_1]],
["mace_4",         "Winged_Mace", [("mace_b",0)], itp_type_one_handed_wpn|itp_can_knock_down|itp_merchandise| itp_primary|itp_wooden_parry, itc_scimitar|itcf_carry_mace_left_hip,
 352 , weight(2.75)|difficulty(10)|spd_rtng(88) | weapon_length(70)|swing_damage(34 , blunt) | thrust_damage(0 ,  pierce),imodbits_mace , [], [fac_culture_1]],
["club_with_spike_head",  "Spiked Staff", [("mace_e",0)],  itp_type_two_handed_wpn|itp_merchandise|itp_can_knock_down|itp_primary|itp_wooden_parry, itc_bastardsword|itcf_carry_axe_back,
 400 , weight(2.80)|difficulty(9)|spd_rtng(85) | weapon_length(117)|swing_damage(24 , blunt) | thrust_damage(20 ,  pierce),imodbits_mace , [], [fac_kingdom_1]],

["long_spiked_club",         "Long Spiked Club", [("mace_long_c",0)],
 itp_type_polearm|itp_can_knock_down|itp_merchandise|itp_two_handed| itp_primary|itp_wooden_parry, itc_staff|itcf_carry_axe_back,
 264 , weight(5)|difficulty(7)|spd_rtng(76) | weapon_length(126)|swing_damage(19 , pierce) | thrust_damage(20 ,  blunt),imodbits_mace , [], [fac_kingdom_1]],
["long_hafted_knobbed_mace",         "Long Hafted Knobbed Mace", [("mace_long_a",0)],
 itp_type_polearm| itp_can_knock_down|itp_two_handed|itp_primary|itp_wooden_parry, itc_staff|itcf_carry_axe_back,
 324 , weight(5)|difficulty(12)|spd_rtng(75) | weapon_length(133)|swing_damage(26 , blunt) | thrust_damage(24 ,  blunt),imodbits_mace , [], [fac_kingdom_1,fac_kingdom_2]],
["long_hafted_spiked_mace",         "Long Hafted Spiked Mace", [("mace_long_b",0)],
 itp_type_polearm|itp_can_knock_down|itp_merchandise|itp_two_handed| itp_primary|itp_wooden_parry, itc_staff|itcf_carry_axe_back,
 310 , weight(5)|difficulty(12)|spd_rtng(74) | weapon_length(140)|swing_damage(28 , blunt) | thrust_damage(26 ,  blunt),imodbits_mace , [], [fac_culture_1]],






["boar_spear",         "Boar Spear", [("spear",0)], itp_type_polearm| itp_primary|itp_penalty_with_shield|itp_wooden_parry,itc_staff|itcf_carry_spear, 
76 , weight(1.5)|difficulty(0)|spd_rtng(90) | weapon_length(157)|swing_damage(26 , cut) | thrust_damage(23 ,  pierce),imodbits_polearm ],
["jousting_lance", "Jousting Lance", [("joust_of_peace",0)], itp_couchable|itp_type_polearm| itp_primary|itp_penalty_with_shield|itp_wooden_parry, itc_greatlance,
 158 , weight(5)|difficulty(0)|spd_rtng(61) | weapon_length(240)|swing_damage(0 , cut) | thrust_damage(17 ,  blunt),imodbits_polearm ],
["double_sided_lance", "Double Sided Lance", [("lance_dblhead",0)], itp_couchable|itp_type_polearm|itp_offset_lance| itp_primary|itp_wooden_parry, itc_staff,
 261 , weight(4.0)|difficulty(0)|spd_rtng(95) | weapon_length(128)|swing_damage(25, cut) | thrust_damage(27 ,  pierce),imodbits_polearm ],
["poleaxe",         "Poleaxe", [("pole_ax",0)], itp_type_polearm|itp_offset_lance| itp_primary|itp_two_handed|itp_wooden_parry, itc_staff,
 384 , weight(4.5)|difficulty(13)|spd_rtng(77) | weapon_length(180)|swing_damage(50 , cut) | thrust_damage(15 ,  blunt),imodbits_polearm ],
["polehammer",         "Polehammer", [("pole_hammer",0)], itp_type_polearm|itp_offset_lance| itp_primary|itp_two_handed|itp_wooden_parry, itc_staff,
 169 , weight(7)|difficulty(18)|spd_rtng(50) | weapon_length(126)|swing_damage(50 , blunt) | thrust_damage(35 ,  blunt),imodbits_polearm ],
["staff",         "Staff", [("wooden_staff",0)], itp_type_polearm|itp_offset_lance| itp_primary|itp_penalty_with_shield|itp_wooden_parry|itp_wooden_attack, itc_staff|itcf_carry_sword_back,
 36 , weight(1.5)|difficulty(0)|spd_rtng(100) | weapon_length(130)|swing_damage(18 , blunt) | thrust_damage(19 ,  blunt),imodbits_polearm ],
["quarter_staff", "Quarter Staff", [("quarter_staff",0)], itp_type_polearm|itp_offset_lance| itp_primary|itp_wooden_parry|itp_wooden_attack, itc_staff|itcf_carry_sword_back,
 60 , weight(2)|difficulty(0)|spd_rtng(104) | weapon_length(140)|swing_damage(20 , blunt) | thrust_damage(20 ,  blunt),imodbits_polearm ],
["iron_staff",         "Iron Staff", [("iron_staff",0)], itp_type_polearm|itp_offset_lance| itp_primary, itc_staff|itcf_carry_sword_back,
 202 , weight(2)|difficulty(0)|spd_rtng(97) | weapon_length(140)|swing_damage(25 , blunt) | thrust_damage(26 ,  blunt),imodbits_polearm ],
["bamboo_spear",         "Bamboo Spear", [("arabian_spear_a_3m",0)],
 itp_unique|itp_type_polearm| itp_primary|itp_two_handed, itc_cutting_spear|itcf_carry_spear,
 80 , weight(2.0)|difficulty(0)|spd_rtng(88) | weapon_length(200)|swing_damage(15 , blunt) | thrust_damage(20 ,  pierce),imodbits_polearm ],
["great_lance",         "Great Lance", [("heavy_lance",0)], itp_couchable|itp_type_polearm| itp_primary|itp_penalty_with_shield|itp_wooden_parry, itc_greatlance, 
 410 , weight(5)|difficulty(11)|spd_rtng(55) | weapon_length(240)|swing_damage(0 , cut) | thrust_damage(21 ,  pierce),imodbits_polearm ],
["ashwood_pike", "Ashwood Pike", [("pike",0)], itp_type_polearm|itp_offset_lance| itp_primary|itp_two_handed|itp_wooden_parry, itc_cutting_spear,
 205 , weight(3.5)|difficulty(9)|spd_rtng(90) | weapon_length(170)|swing_damage(19 , blunt) | thrust_damage(29,  pierce),imodbits_polearm ],


["axe",  "Axe", [("one_handed_war_axe_a",0)], itp_type_two_handed_wpn| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry, itc_nodachi|itcf_carry_axe_left_hip, 
165 , weight(4)|difficulty(8)|spd_rtng(91) | weapon_length(78)|swing_damage(32 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
["two_handed_cleaver", "War Cleaver", [("military_cleaver_a",0)], itp_type_two_handed_wpn|itp_merchandise|itp_two_handed|itp_primary, itc_nodachi|itcf_carry_sword_back,
 640 , weight(2.75)|difficulty(10)|spd_rtng(83) | weapon_length(120)|swing_damage(45 , cut) | thrust_damage(0 ,  cut),imodbits_sword_high , [], [fac_culture_1]],
["two_handed_axe",         "Two Handed Axe", [("two_handed_battle_axe_a",0)],
 itp_type_two_handed_wpn|itp_cant_use_on_horseback|itp_merchandise| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_unbalanced, itc_nodachi|itcf_carry_axe_back,
 690 , weight(4.5)|difficulty(15)|spd_rtng(86) | weapon_length(90)|swing_damage(38 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_culture_2,fac_culture_4]],
["two_handed_battle_axe_2",         "Two Handed War Axe", [("two_handed_battle_axe_b",0)],
 itp_type_two_handed_wpn|itp_cant_use_on_horseback|itp_cant_use_on_horseback|itp_merchandise| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_unbalanced, itc_nodachi|itcf_carry_axe_back,
 752 , weight(4.5)|difficulty(15)|spd_rtng(86) | weapon_length(92)|swing_damage(54 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_culture_2,fac_culture_4]],
 ["bardiche",         "Bardiche", [("two_handed_battle_axe_d",0)],
  itp_type_two_handed_wpn|itp_cant_use_on_horseback|itp_merchandise| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_unbalanced, itc_nodachi|itcf_carry_axe_back,
 691 , weight(4.75)|difficulty(15)|spd_rtng(71) | weapon_length(102)|swing_damage(47 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_culture_2]],
["shortened_voulge",         "Shortened Voulge", [("two_handed_battle_axe_c",0)],
 itp_type_two_handed_wpn|itp_cant_use_on_horseback|itp_merchandise| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry|itp_unbalanced, itc_nodachi|itcf_carry_axe_back,
 628 , weight(4.5)|difficulty(15)|spd_rtng(72) | weapon_length(100)|swing_damage(45 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_culture_1]],
["voulge",         "Voulge", [("two_handed_battle_long_axe_a",0)],
 itp_type_polearm|itp_cant_use_on_horseback|itp_merchandise| itp_two_handed|itp_primary|itp_bonus_against_shield|itp_wooden_parry, itc_staff|itcf_carry_axe_back,
 920 , weight(3.0)|difficulty(21)|spd_rtng(62) | weapon_length(175)|swing_damage(65 , cut) | thrust_damage(28 ,  pierce),imodbits_axe , [], [fac_culture_1]],


["scythe",         "Scythe", [("scythe",0)], itp_unique|itp_type_polearm|itp_cant_use_on_horseback| itp_primary|itp_wooden_parry|itp_two_handed, itc_staff|itcf_carry_spear,
 43 , weight(2)|difficulty(5)|spd_rtng(87) | weapon_length(182)|swing_damage(30 , cut) | thrust_damage(14 ,  pierce),imodbits_polearm ],
["pitch_fork",         "Pitch Fork", [("pitch_fork",0)], itp_unique|itp_type_polearm|itp_cant_use_on_horseback|itp_primary|itp_wooden_parry|itp_two_handed,itc_staff,
 49 , weight(1.5)|difficulty(5)|spd_rtng(87) | weapon_length(154)|swing_damage(26 , blunt) | thrust_damage(22 ,  pierce),imodbits_polearm ],

["military_fork", "Military Fork", [("military_fork",0)], itp_type_polearm|itp_cant_use_on_horseback|itp_merchandise| itp_primary|itp_wooden_parry|itp_two_handed,itc_staff,
 253 , weight(2)|difficulty(8)|spd_rtng(85) | weapon_length(135)|swing_damage(15 , blunt) | thrust_damage(30 ,  pierce),imodbits_polearm , [], [fac_kingdom_1]],
["battle_fork",         "Battle Fork", [("battle_fork",0)], itp_type_polearm|itp_cant_use_on_horseback|itp_merchandise| itp_primary|itp_wooden_parry|itp_two_handed,itc_staff,
 282 , weight(2.2)|difficulty(8)|spd_rtng(80) | weapon_length(144)|swing_damage(15, blunt) | thrust_damage(35 ,  pierce),imodbits_polearm , [], [fac_kingdom_1]],


["shortened_spear", "Shortened Spear", [("spear_g_1-9m",0)], itp_type_polearm|itp_offset_lance|itp_merchandise| itp_primary|itp_wooden_parry, itc_staff|itcf_carry_spear,
 253 , weight(2.0)|difficulty(6)|spd_rtng(102) | weapon_length(120)|swing_damage(19 , blunt) | thrust_damage(25 ,  pierce),imodbits_polearm , [], [fac_kingdom_2,fac_kingdom_4]],
["spear", "Spear", [("spear_h_2-15m",0)], itp_type_polearm|itp_offset_lance|itp_merchandise| itp_primary|itp_wooden_parry, itc_staff|itcf_carry_spear,
 385 , weight(2.25)|difficulty(8)|spd_rtng(98) | weapon_length(135)|swing_damage(20 , blunt) | thrust_damage(26 ,  pierce),imodbits_polearm , [], [fac_kingdom_2,fac_kingdom_4]],
["war_spear", "War Spear", [("spear_i_2-3m",0)], itp_type_polearm|itp_offset_lance|itp_merchandise| itp_primary|itp_wooden_parry, itc_staff|itcf_carry_spear,
 540 , weight(2.5)|difficulty(12)|spd_rtng(95) | weapon_length(150)|swing_damage(20 , blunt) | thrust_damage(37 ,  pierce),imodbits_polearm , [], [fac_culture_2,fac_culture_4]],


["glaive",         "Glaive", [("glaive_b",0)],
 itp_type_polearm|itp_cant_use_on_horseback|itp_offset_lance|itp_merchandise| itp_primary|itp_two_handed|itp_wooden_parry, itc_staff|itcf_carry_spear,
 352 , weight(4.5)|difficulty(10)|spd_rtng(80) | weapon_length(157)|swing_damage(39 , cut) | thrust_damage(21 ,  pierce),imodbits_polearm , [], [fac_kingdom_1]],
["military_scythe",         "Military Scythe", [("spear_e_2-5m",0)],
 itp_type_polearm|itp_cant_use_on_horseback|itp_offset_lance|itp_merchandise| itp_primary|itp_penalty_with_shield|itp_wooden_parry, itc_staff|itcf_carry_spear,
 455 , weight(2.5)|difficulty(10)|spd_rtng(80) | weapon_length(155)|swing_damage(36 , cut) | thrust_damage(25 ,  pierce),imodbits_polearm , [], [fac_kingdom_1]],
["military_scythe_m",         "Military Scythe", [("spear_e_3-25m",0)],
 itp_type_polearm|itp_cant_use_on_horseback|itp_merchandise| itp_primary|itp_wooden_parry|itp_two_handed, itc_cutting_spear|itcf_carry_spear,
 450 , weight(4.5)|difficulty(10)|spd_rtng(81) | weapon_length(225)|swing_damage(19 , blunt) | thrust_damage(23 ,  pierce),imodbits_polearm , [], [fac_culture_1]],



["light_lance",         "Light Lance", [("spear_b_2-75m",0)],
 itp_couchable|itp_type_polearm|itp_offset_lance|itp_merchandise| itp_primary|itp_penalty_with_shield|itp_wooden_parry, itc_cutting_spear|itcf_carry_spear,
 180 , weight(2)|difficulty(7)|spd_rtng(85) | weapon_length(160)|swing_damage(16 , blunt) | thrust_damage(27 ,  pierce),imodbits_polearm , [], [fac_kingdom_3,fac_kingdom_6]],
["lance",         "Lance", [("spear_d_2-8m",0)],
 itp_couchable|itp_type_polearm|itp_offset_lance|itp_merchandise| itp_primary|itp_penalty_with_shield|itp_wooden_parry, itc_cutting_spear|itcf_carry_spear,
 270 , weight(2.5)|difficulty(9)|spd_rtng(80) | weapon_length(180)|swing_damage(16 , blunt) | thrust_damage(31 ,  pierce),imodbits_polearm , [], [fac_kingdom_3,fac_kingdom_6]],
["heavy_lance",         "Heavy Lance", [("spear_f_2-9m",0)],
 itp_couchable|itp_type_polearm|itp_offset_lance|itp_merchandise| itp_primary|itp_penalty_with_shield|itp_wooden_parry, itc_cutting_spear|itcf_carry_spear,
 660 , weight(3.75)|difficulty(12)|spd_rtng(75) | weapon_length(190)|swing_damage(16 , blunt) | thrust_damage(46 ,  pierce),imodbits_polearm , [], [fac_culture_3,fac_culture_6]],
["pike",         "Pike", [("spear_a_3m",0)],
 itp_type_polearm|itp_merchandise| itp_cant_use_on_horseback|itp_primary|itp_two_handed|itp_no_parry, itc_pike,
 325 , weight(3.0)|difficulty(10)|spd_rtng(81) | weapon_length(245)|swing_damage(16 , blunt) | thrust_damage(36 ,  pierce),imodbits_polearm , [], [fac_kingdom_1,fac_kingdom_6]],

["awlpike",    "Awlpike", [("awl_pike_b",0)], itp_type_polearm|itp_offset_lance|itp_merchandise| itp_primary|itp_penalty_with_shield|itp_wooden_parry, itc_cutting_spear|itcf_carry_spear,
 545 , weight(2.25)|difficulty(12)|spd_rtng(82) | weapon_length(165)|swing_damage(20 , blunt) | thrust_damage(33 ,  pierce),imodbits_polearm , [], [fac_kingdom_1]],
["awlpike_long",  "Long Awlpike", [("awl_pike_a",0)], itp_type_polearm|itp_offset_lance|itp_merchandise| itp_primary|itp_penalty_with_shield|itp_wooden_parry, itc_cutting_spear|itcf_carry_spear,
 785 , weight(3.25)|difficulty(21)|spd_rtng(79) | weapon_length(185)|swing_damage(26 , blunt) | thrust_damage(42 ,  pierce),imodbits_polearm , [], [fac_culture_1]],

["bec_de_corbin_a",  "War Hammer", [("bec_de_corbin_a",0)], itp_type_polearm|itp_merchandise| itp_cant_use_on_horseback|itp_primary|itp_penalty_with_shield|itp_wooden_parry|itp_two_handed, itc_cutting_spear|itcf_carry_spear,
 1125 , weight(6.0)|difficulty(24)|spd_rtng(81) | weapon_length(120)|swing_damage(48, blunt) | thrust_damage(38 ,  pierce),imodbits_polearm , [], [fac_culture_1]],



# SHIELDS

["wooden_shield", "Wooden Shield", [("Lord_Jamestown_shield_round_a",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,
 266 , weight(2)|difficulty(1)|hit_points(120)|body_armor(3)|spd_rtng(100)|shield_width(40),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["round_shield", "Round Shield", [("Lord_Jamestown_shield_round_g",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,
 266 , weight(2)|difficulty(1)|hit_points(120)|body_armor(3)|spd_rtng(100)|shield_width(40),imodbits_shield, [], [fac_kingdom_1]  ],
["nordic_shield", "Nordic Shield", [("Lord_Jamestown_shield_round_b",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,
 266 , weight(2)|difficulty(1)|hit_points(120)|body_armor(3)|spd_rtng(100)|shield_width(40),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["old_round_shield", "Round Shield", [("Lord_Jamestown_shield_wood_b",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,
 266 , weight(2)|difficulty(1)|hit_points(120)|body_armor(3)|spd_rtng(100)|shield_width(40),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["old_nordic_shield", "Nordic Shield", [("Lord_Jamestown_shield_round_c",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,
 266 , weight(2)|difficulty(1)|hit_points(120)|body_armor(3)|spd_rtng(100)|shield_width(40),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],


["large_round_shield", "Round Shield", [("Lord_Jamestown_shield_large_round_c",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,
 322 , weight(3)|difficulty(2)|hit_points(220)|body_armor(5)|spd_rtng(90)|shield_width(60),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["large_nordic_shield", "Nordic Shield", [("Lord_Jamestown_shield_large_round_a",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,
 322 , weight(3)|difficulty(2)|hit_points(220)|body_armor(5)|spd_rtng(90)|shield_width(60),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["large_old_round_shield", "Round Shield", [("Lord_Jamestown_shield_large_round_b",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,
 322 , weight(3)|difficulty(2)|hit_points(220)|body_armor(5)|spd_rtng(90)|shield_width(60),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["large_old_nordic_shield", "Nordic Shield", [("Lord_Jamestown_shield_large_wood_b",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,
 322 , weight(3)|difficulty(2)|hit_points(220)|body_armor(5)|spd_rtng(90)|shield_width(60),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],

 ["leather_covered_round_shield", "Leather Covered Round Shield", [("shield_round_d",0)], itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,
 340 , weight(2.5)|difficulty(1)|hit_points(140)|body_armor(5)|spd_rtng(96)|shield_width(40),imodbits_shield, [], [fac_kingdom_3,fac_kingdom_6]  ],
 
["hide_covered_round_shield", "Hide Covered Round Shield", [("shield_round_f",0)], itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,
 140 , weight(2)|difficulty(1)|hit_points(70)|body_armor(3)|spd_rtng(100)|shield_width(40),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["fur_covered_shield",  "Fur Covered Shield", [("shield_kite_m",0)], itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 227 , weight(3.5)|difficulty(1)|hit_points(120)|body_armor(1)|spd_rtng(76)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],


["steel_shield", "Steel Shield", [("shield_dragon",0)], itp_merchandise|itp_type_shield, itcf_carry_round_shield,
 697 , weight(4)|difficulty(5)|hit_points(300)|body_armor(17)|spd_rtng(61)|shield_width(40),imodbits_shield, [], [fac_kingdom_1]  ],
["plate_covered_round_shield", "Plate Covered Round Shield", [("shield_round_e",0)], itp_type_shield, itcf_carry_round_shield,
 740 , weight(4)|difficulty(5)|hit_points(300)|body_armor(16)|spd_rtng(90)|shield_width(40),imodbits_shield, [], [fac_kingdom_6]  ],
["small_round_shield", "Round Shield", [("small_shield",0)], itp_merchandise|itp_type_shield, itcf_carry_round_shield,
 540 , weight(4)|difficulty(5)|hit_points(300)|body_armor(16)|spd_rtng(90)|shield_width(25),imodbits_shield, [], [fac_kingdom_6]  ],
["small_round_shield1", "Round Shield", [("shield_small_round",0)], itp_merchandise|itp_type_shield, itcf_carry_round_shield,
 340 , weight(4)|difficulty(3)|hit_points(250)|body_armor(9)|spd_rtng(90)|shield_width(25),imodbits_shield, [], [fac_kingdom_2]  ],
["small_round_shield2", "Round Shield", [("shield_small_round2",0)], itp_merchandise|itp_type_shield, itcf_carry_round_shield,
 340 , weight(4)|difficulty(3)|hit_points(250)|body_armor(9)|spd_rtng(90)|shield_width(25),imodbits_shield, [], [fac_kingdom_2]  ],
["small_round_shield3", "Round Shield", [("shield_small_round3",0)], itp_merchandise|itp_type_shield, itcf_carry_round_shield,
 340 , weight(4)|difficulty(3)|hit_points(150)|body_armor(9)|spd_rtng(90)|shield_width(25),imodbits_shield, [], [fac_kingdom_2]  ],
["small_round_shield4", "Round Shield", [("shield_small_round4",0)], itp_merchandise|itp_type_shield, itcf_carry_round_shield,
 340 , weight(4)|difficulty(3)|hit_points(150)|body_armor(9)|spd_rtng(90)|shield_width(25),imodbits_shield, [], [fac_kingdom_3]  ],
["small_round_shield5", "Round Shield", [("shield_small_round5",0)], itp_merchandise|itp_type_shield, itcf_carry_round_shield,
 340 , weight(4)|difficulty(3)|hit_points(150)|body_armor(9)|spd_rtng(90)|shield_width(25),imodbits_shield, [], [fac_kingdom_6]  ],
 
["shield_heater_c", "Heater Shield", [("shield_heater_c",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,
 477 , weight(3.5)|difficulty(4)|hit_points(410)|body_armor(4)|spd_rtng(80)|shield_width(36)|shield_height(80),imodbits_shield, [], [fac_kingdom_1]  ],
["shield_heater_d", "Heater Shield", [("shield_heater_d",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,
 477 , weight(3.5)|difficulty(4)|hit_points(410)|body_armor(4)|spd_rtng(80)|shield_width(36)|shield_height(80),imodbits_shield, [], [fac_kingdom_6]  ],
["shield_heater_i", "Heater Shield", [("shield_kite_wood",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,
 277 , weight(3)|difficulty(4)|hit_points(310)|body_armor(2)|spd_rtng(80)|shield_width(36)|shield_height(80),imodbits_shield, [], [fac_kingdom_1,fac_kingdom_2]  ],
["shield_heater_j", "Heater Shield", [("shield_wood_heater_d",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,
 312 , weight(3)|difficulty(4)|hit_points(310)|body_armor(3)|spd_rtng(90)|shield_width(36)|shield_height(80),imodbits_shield, [], [fac_kingdom_1,fac_kingdom_2]  ],
["shield_heater1", "Heater Shield", [("shield_small_round6",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,
 312 , weight(3)|difficulty(4)|hit_points(310)|body_armor(3)|spd_rtng(90)|shield_width(32)|shield_height(70),imodbits_shield, [], [fac_kingdom_2]  ],
["shield_heater2", "Heater Shield", [("shield_small_round7",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,
 312 , weight(3)|difficulty(4)|hit_points(310)|body_armor(3)|spd_rtng(90)|shield_width(32)|shield_height(70),imodbits_shield, [], [fac_kingdom_2]  ],
["shield_heater3", "Heater Shield", [("shield_small_round8",0)], itp_merchandise|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,
 312 , weight(3)|difficulty(4)|hit_points(310)|body_armor(3)|spd_rtng(90)|shield_width(32)|shield_height(70),imodbits_shield, [], [fac_kingdom_6]  ],
 
["full_plate_shield", "Steel Shield", [("full_plate_shield",0)], itp_merchandise|itp_type_shield, itcf_carry_kite_shield,
 5312 , weight(9)|abundance(10)|difficulty(7)|hit_points(1500)|body_armor(32)|spd_rtng(90)|shield_width(32)|shield_height(70),imodbits_shield, [], [fac_culture_1]  ],
 
["shield_kite_j",         "Kite Shield", [("shield_wood_kite_k",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 318 , weight(2.5)|difficulty(4)|hit_points(380)|body_armor(3)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_1]  ], 
["shield_kite_i",         "Kite Shield", [("shield_kite_i",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 418 , weight(3.5)|difficulty(5)|hit_points(580)|body_armor(5)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_1]  ],
["shield_kite_k",         "Kite Shield", [("shield_kite_k",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 418 , weight(3.5)|difficulty(5)|hit_points(580)|body_armor(5)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_1]  ],
["shield_kite1",         "Kite Shield", [("shield_small_round9",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 418 , weight(3.5)|difficulty(4)|hit_points(580)|body_armor(5)|spd_rtng(82)|shield_width(36)|shield_height(90),imodbits_shield, [], [fac_kingdom_6]  ],
 
["norman_shield_1",         "Kite Shield", [("norman_shield_1",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 518 , weight(3.5)|difficulty(4)|hit_points(480)|body_armor(3)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["norman_shield_2",         "Kite Shield", [("norman_shield_2",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 518 , weight(3.5)|difficulty(4)|hit_points(480)|body_armor(3)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["norman_shield_3",         "Kite Shield", [("norman_shield_3",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 518 , weight(3.5)|difficulty(4)|hit_points(480)|body_armor(3)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["norman_shield_4",         "Kite Shield", [("norman_shield_4",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 518 , weight(3.5)|difficulty(4)|hit_points(480)|body_armor(3)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["norman_shield_5",         "Kite Shield", [("norman_shield_5",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 518 , weight(3.5)|difficulty(4)|hit_points(480)|body_armor(3)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["norman_shield_6",         "Kite Shield", [("norman_shield_6",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 518 , weight(3.5)|difficulty(4)|hit_points(480)|body_armor(3)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["norman_shield_7",         "Kite Shield", [("norman_shield_7",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 518 , weight(3.5)|difficulty(4)|hit_points(480)|body_armor(3)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["norman_shield_8",         "Kite Shield", [("norman_shield_8",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 518 , weight(3.5)|difficulty(4)|hit_points(480)|body_armor(3)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
["shield_kite_h",         "Kite Shield", [("shield_kite_h",0)], itp_merchandise|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,
 518 , weight(3.5)|difficulty(4)|hit_points(480)|body_armor(3)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],


#OLD shield

["tab_shield_round_a", "Old Round Shield", [("tableau_shield_round_5",0)], itp_unique|itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,  
126 , weight(2.5)|difficulty(1)|hit_points(50)|body_armor(4)|spd_rtng(93)|shield_width(30),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_round_shield_5", ":agent_no", ":troop_no")])]],
["tab_shield_kite_a", "Old Kite Shield",   [("tableau_shield_kite_1" ,0)], itp_unique|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,  
133 , weight(2)|difficulty(1)|hit_points(70)|body_armor(5)|spd_rtng(96)|shield_width(36)|shield_height(70),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_kite_shield_1", ":agent_no", ":troop_no")])]],
["tab_shield_pavise_b", "Plain Board Shield",   [("tableau_shield_pavise_2" ,0)], itp_unique|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_board_shield,  
114 , weight(4)|difficulty(1)|hit_points(90)|body_armor(8)|spd_rtng(85)|shield_width(43)|shield_height(100),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_pavise_shield_2", ":agent_no", ":troop_no")])]],




#USEFULL shield
#NORD
["tab_shield_round_b", "Plain Round Shield", [("tableau_shield_round_3",0)], itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,  
265 , weight(3)|difficulty(3)|hit_points(260)|body_armor(8)|spd_rtng(90)|shield_width(45),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_round_shield_3", ":agent_no", ":troop_no")])]],
["tab_shield_round_c", "Round Shield", [("tableau_shield_round_2",0)], itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,  
605 , weight(3.5)|difficulty(5)|hit_points(310)|body_armor(12)|spd_rtng(87)|shield_width(45),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner","tableau_round_shield_2", ":agent_no", ":troop_no")])]],
["tab_shield_round_d", "Heavy Round Shield", [("tableau_shield_round_1",0)], itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,  
810 , weight(4)|difficulty(6)|hit_points(350)|body_armor(15)|spd_rtng(84)|shield_width(45),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_round_shield_1", ":agent_no", ":troop_no")])]],
["tab_shield_round_e", "Huscarl's Round Shield", [("tableau_shield_round_4",0)], itp_type_shield|itp_cant_use_on_horseback, itcf_carry_round_shield,  
1430 , weight(4.5)|difficulty(8)|hit_points(710)|body_armor(21)|spd_rtng(81)|shield_width(55),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_round_shield_4", ":agent_no", ":troop_no")])]],
#VEGIR
["tab_shield_kite_b", "Plain Kite Shield",   [("tableau_shield_kite_3" ,0)], itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,  
470 , weight(2.5)|difficulty(3)|hit_points(250)|body_armor(10)|spd_rtng(93)|shield_width(36)|shield_height(70),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_kite_shield_3", ":agent_no", ":troop_no")])]],
["tab_shield_kite_c", "Kite Shield",   [("tableau_shield_kite_2" ,0)], itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,  
556 , weight(3)|difficulty(5)|hit_points(300)|body_armor(5)|spd_rtng(90)|shield_width(36)|shield_height(70),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_kite_shield_2", ":agent_no", ":troop_no")])]],
["tab_shield_kite_cav_a", "Horseman's Kite Shield",   [("tableau_shield_kite_4" ,0)], itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  
605 , weight(2)|difficulty(5)|hit_points(165)|body_armor(5)|spd_rtng(103)|shield_width(30)|shield_height(50),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_kite_shield_4", ":agent_no", ":troop_no")])]],
#SWAD
["tab_shield_heater_c", "Heater Shield",   [("tableau_shield_heater_1" ,0)], itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_kite_shield,  
560 , weight(3)|difficulty(5)|hit_points(260)|body_armor(14)|spd_rtng(90)|shield_width(36)|shield_height(70),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_heater_shield_1", ":agent_no", ":troop_no")])]],
["tab_shield_heater_cav_a", "Horseman's Heater Shield",   [("tableau_shield_heater_2" ,0)], itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  
529 , weight(2)|difficulty(5)|hit_points(160)|body_armor(16)|spd_rtng(103)|shield_width(30)|shield_height(50),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_heater_shield_2", ":agent_no", ":troop_no")])]],
 ["tab_shield_pavise_j", "Board Shield",   [("tableau_shield_pavise_5" ,0)], itp_type_shield|itp_wooden_parry, itcf_carry_board_shield,  
710 , weight(2.5)|difficulty(7)|hit_points(430)|body_armor(27)|spd_rtng(95)|shield_width(43)|shield_height(70),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_pavise_shield_2", ":agent_no", ":troop_no")])]],
#RODOK
["tab_shield_pavise_c", "Board Shield",   [("tableau_shield_pavise_1" ,0)], itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_board_shield,  
710 , weight(4.5)|difficulty(7)|hit_points(430)|body_armor(18)|spd_rtng(81)|shield_width(43)|shield_height(100),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_pavise_shield_1", ":agent_no", ":troop_no")])]],
#KERGIT+SARRANID
["tab_shield_small_round_b", "Round Cavalry Shield", [("tableau_shield_small_round_1",0)], itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,  
395 , weight(2.5)|difficulty(3)|hit_points(200)|body_armor(18)|spd_rtng(103)|shield_width(40),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_small_round_shield_1", ":agent_no", ":troop_no")])]],
 
["tab_shield_small_round_c", "Elite Cavalry Shield", [("tableau_shield_small_round_2",0)], itp_type_shield, itcf_carry_round_shield,  
470 , weight(3)|difficulty(5)|hit_points(270)|body_armor(22)|spd_rtng(100)|shield_width(40),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_small_round_shield_2", ":agent_no", ":troop_no")])]],
 
["tab_shield_small_round_a", "Plain Cavalry Shield", [("tableau_shield_small_round_3",0)], itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,  
596 , weight(2)|difficulty(2)|hit_points(460)|body_armor(12)|spd_rtng(105)|shield_width(40),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_small_round_shield_3", ":agent_no", ":troop_no")])]],

["tab_shield_small_round_d", "Plain Cavalry Shield", [("tableau_shield_small_round_4",0)], itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,  
596 , weight(2)|difficulty(4)|hit_points(260)|body_armor(12)|spd_rtng(105)|shield_width(25),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_pavise_shield_1", ":agent_no", ":troop_no")])]],

["tab_shield_small_round_e", "Plain Cavalry Shield", [("tableau_shield_small_round_5",0)], itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,  
696 , weight(2)|difficulty(5)|hit_points(360)|body_armor(18)|spd_rtng(105)|shield_width(25),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_round_shield_2", ":agent_no", ":troop_no")])]],

["tab_shield_small_round_i", "Plain Cavalry Shield", [("tableau_shield_small_round_6",0)], itp_type_shield|itp_wooden_parry, itcf_carry_round_shield,  
796 , weight(3)|difficulty(6)|hit_points(460)|body_armor(22)|spd_rtng(105)|shield_width(25),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_round_shield_1", ":agent_no", ":troop_no")])]],
 
 
["tab_shield_pavise_i", "Board Shield",   [("tableau_shield_pavise_4" ,0)], itp_type_shield|itp_wooden_parry, itcf_carry_board_shield,  
610 , weight(3.5)|difficulty(7)|hit_points(430)|body_armor(18)|spd_rtng(81)|shield_width(43)|shield_height(100),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_heater_shield_2", ":agent_no", ":troop_no")])]],

["tab_shield_pavise_k", "Board Shield",   [("tableau_shield_pavise_6" ,0)], itp_type_shield|itp_wooden_parry, itcf_carry_board_shield,  
610 , weight(3.5)|difficulty(6)|hit_points(430)|body_armor(18)|spd_rtng(81)|shield_width(43)|shield_height(90),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_pavise_shield_1", ":agent_no", ":troop_no")])]],

["tab_shield_pavise_l", "Board Shield",   [("tableau_shield_pavise_7" ,0)], itp_type_shield|itp_wooden_parry, itcf_carry_board_shield,  
610 , weight(3.5)|difficulty(7)|hit_points(430)|body_armor(18)|spd_rtng(81)|shield_width(43)|shield_height(100),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_pavise_shield_1", ":agent_no", ":troop_no")])]],
 
#UNUSEFULL shield
["tab_shield_kite_d", "Heavy Kite Shield",   [("tableau_shield_kite_2" ,0)], itp_unique|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  
320 , weight(3.5)|difficulty(5)|hit_points(310)|body_armor(18)|spd_rtng(87)|shield_width(36)|shield_height(70),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_kite_shield_2", ":agent_no", ":troop_no")])], [], [fac_kingdom_3,fac_kingdom_6]],
["tab_shield_kite_cav_b", "Knightly Kite Shield",   [("tableau_shield_kite_4" ,0)], itp_unique|itp_type_shield, itcf_carry_kite_shield,  
360 , weight(2.5)|hit_points(225)|body_armor(23)|spd_rtng(100)|shield_width(30)|shield_height(50),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_kite_shield_4", ":agent_no", ":troop_no")])]],
["tab_shield_heater_a", "Old Heater Shield",   [("tableau_shield_heater_1" ,0)], itp_unique|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  
36 , weight(2)|hit_points(160)|body_armor(6)|spd_rtng(96)|shield_width(36)|shield_height(70),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_heater_shield_1", ":agent_no", ":troop_no")])]],
["tab_shield_heater_b", "Plain Heater Shield",   [("tableau_shield_heater_1" ,0)], itp_unique|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  
74 , weight(2.5)|hit_points(210)|body_armor(11)|spd_rtng(93)|shield_width(36)|shield_height(70),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_heater_shield_1", ":agent_no", ":troop_no")])]],
["tab_shield_heater_d", "Heavy Heater Shield",   [("tableau_shield_heater_1" ,0)], itp_unique|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  
332 , weight(3.5)|hit_points(305)|body_armor(19)|spd_rtng(87)|shield_width(36)|shield_height(70),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_heater_shield_1", ":agent_no", ":troop_no")])]],
["tab_shield_heater_cav_b", "Knightly Heater Shield",   [("tableau_shield_heater_2" ,0)], itp_unique|itp_type_shield|itp_wooden_parry, itcf_carry_kite_shield,  
390 , weight(2.5)|hit_points(220)|body_armor(23)|spd_rtng(100)|shield_width(30)|shield_height(50),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_heater_shield_2", ":agent_no", ":troop_no")])]],
["tab_shield_pavise_a", "Old Board Shield",   [("tableau_shield_pavise_2" ,0)], itp_unique|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_board_shield,  
60 , weight(3.5)|hit_points(280)|body_armor(4)|spd_rtng(89)|shield_width(43)|shield_height(100),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_pavise_shield_2", ":agent_no", ":troop_no")])]],
["tab_shield_pavise_d", "Heavy Board Shield",   [("tableau_shield_pavise_1" ,0)], itp_unique|itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_board_shield,  
370 , weight(5)|hit_points(550)|body_armor(14)|spd_rtng(78)|shield_width(43)|shield_height(100),imodbits_shield,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),
                     (call_script, "script_shield_item_set_banner", "tableau_pavise_shield_1", ":agent_no", ":troop_no")])]],

 #RANGED


#TODO:
["darts",         "Darts", [("tot_dart_a",0),("dart_a_bag", ixmesh_carry)],
 itp_type_thrown |itp_merchandise|itp_primary ,itcf_throw_javelin|itcf_carry_quiver_back|itcf_show_holster_when_drawn, 
155 , weight(4)|abundance(50)|difficulty(1)|spd_rtng(95) | shoot_speed(28) | thrust_damage(27 ,  pierce)|max_ammo(4)|accuracy(75)|weapon_length(32),imodbits_thrown, [], [fac_kingdom_1] ],
["war_darts",         "War Darts", [("tot_dart_b",0),("dart_b_bag", ixmesh_carry)],
 itp_type_thrown |itp_merchandise|itp_primary ,itcf_throw_javelin|itcf_carry_quiver_back|itcf_show_holster_when_drawn, 
385 , weight(5)|abundance(50)|difficulty(3)|spd_rtng(93) | shoot_speed(27) | thrust_damage(35 ,  pierce)|max_ammo(4)|accuracy(75)|weapon_length(45),imodbits_thrown, [], [fac_kingdom_2] ],

["javelin",         "Javelins", [("javelin",0),("javelins_quiver_new", ixmesh_carry)],
 itp_type_thrown |itp_merchandise|itp_primary|itp_next_item_as_melee ,itcf_throw_javelin|itcf_carry_quiver_back|itcf_show_holster_when_drawn, 
1200, weight(6)|abundance(50)|difficulty(3)|spd_rtng(91) | shoot_speed(25) | thrust_damage(34 ,  pierce)|max_ammo(4)|accuracy(65)|weapon_length(75),imodbits_thrown, [], [fac_kingdom_2,fac_kingdom_4] ],
["javelin_melee",         "Javelin", [("javelin",0)], itp_unique| itp_type_polearm|itp_primary|itp_wooden_parry , itc_staff,
 300, weight(1.5)|abundance(50)|difficulty(3)|spd_rtng(95) |swing_damage(12, cut)| thrust_damage(14,  pierce)|weapon_length(75),imodbits_polearm ],

["throwing_spears",         "Throwing Spears", [("tot_jarid_new_b",0),("jarid_new_b_bag", ixmesh_carry)], itp_type_thrown |itp_merchandise|itp_primary|itp_next_item_as_melee ,itcf_throw_javelin|itcf_carry_quiver_back|itcf_show_holster_when_drawn, 
2000 , weight(8)|abundance(20)|difficulty(5)|spd_rtng(87) | shoot_speed(22) | thrust_damage(54 ,  pierce)|max_ammo(4)|accuracy(65)|weapon_length(65),imodbits_thrown, [], [fac_kingdom_2,fac_kingdom_4] ],
["throwing_spear_melee",         "Throwing Spear", [("jarid_new_b",0),("jarid_new_b_bag", ixmesh_carry)],itp_unique| itp_type_polearm|itp_primary|itp_wooden_parry , itc_staff, 
500 , weight(2)|abundance(20)|difficulty(5)|spd_rtng(91) | swing_damage(18, cut) | thrust_damage(33 ,  pierce)|weapon_length(75),imodbits_thrown ],

["jarid",         "Jarids", [("jarid_new",0),("jarid_quiver", ixmesh_carry)], itp_type_thrown |itp_merchandise|itp_primary|itp_next_item_as_melee ,itcf_throw_javelin|itcf_carry_quiver_back|itcf_show_holster_when_drawn, 
1800 , weight(6)|abundance(20)|difficulty(5)|spd_rtng(89) | shoot_speed(24) | thrust_damage(52 ,  pierce)|max_ammo(3)|accuracy(65)|weapon_length(65),imodbits_thrown, [], [fac_kingdom_6] ],
["jarid_melee",         "Jarid", [("jarid_new",0),("jarid_quiver", ixmesh_carry)], itp_type_polearm|itp_primary|itp_wooden_parry , itc_staff,
600 , weight(2)|abundance(20)|difficulty(5)|spd_rtng(93) | swing_damage(16, cut) | thrust_damage(30 ,  pierce)|weapon_length(65),imodbits_thrown ],


#TODO:
#TODO: Heavy throwing Spear
["stones",         "Stones", [("throwing_stone",0)], itp_unique|itp_type_thrown |itp_merchandise|itp_primary ,itcf_throw_stone,
 1 , weight(4)|difficulty(0)|spd_rtng(97) | shoot_speed(30) | thrust_damage(11 ,  blunt)|max_ammo(18)|accuracy(35)|weapon_length(8),imodbit_large_bag ],

["throwing_knives", "Throwing Knives", [("throwing_knife",0)], itp_type_thrown |itp_merchandise|itp_primary ,itcf_throw_knife,
 76 , weight(2.5)|difficulty(0)|spd_rtng(121) | shoot_speed(25) | thrust_damage(19 ,  cut)|max_ammo(14)|weapon_length(0),imodbits_thrown ],
["throwing_daggers", "Throwing Daggers", [("throwing_dagger",0)], itp_type_thrown |itp_merchandise|itp_primary ,itcf_throw_knife,
 193 , weight(2.5)|difficulty(0)|spd_rtng(110) | shoot_speed(24) | thrust_damage(25 ,  cut)|max_ammo(13)|weapon_length(0),imodbits_thrown ],
["dagger",         "Dagger", [("dagger_b",0),("dagger_b_scabbard",ixmesh_carry)], itp_type_one_handed_wpn|itp_merchandise|itp_primary|itp_secondary|itp_no_parry,
 itc_dagger|itcf_carry_dagger_front_left|itcf_show_holster_when_drawn, 
37 , weight(0.75)|difficulty(0)|spd_rtng(109) | weapon_length(47)|swing_damage(22 , cut) | thrust_damage(19 ,  pierce),imodbits_sword_high , [], [fac_kingdom_1]],

#TODO: Light Trowing axe, Heavy Throwing Axe
["light_throwing_axes", "Light Throwing Axes", [("francisca",0)], itp_type_thrown |itp_merchandise|itp_primary|itp_next_item_as_melee,itcf_throw_axe,
900, weight(4.5)|abundance(50)|difficulty(2)|spd_rtng(99) | shoot_speed(18) | thrust_damage(45,cut)|max_ammo(3)|accuracy(75)|weapon_length(53),imodbits_thrown_minus_heavy, [], [fac_kingdom_2,fac_kingdom_4] ],
["light_throwing_axes_melee", "Light Throwing Axe", [("francisca",0)], itp_unique| itp_type_one_handed_wpn |itp_primary|itp_bonus_against_shield,itc_scimitar,
300, weight(1.5)|abundance(50)|difficulty(2)|spd_rtng(69)|weapon_length(53)| swing_damage(26,cut),imodbits_thrown_minus_heavy ],
 
["throwing_axes", "Throwing Axes", [("throwing_axe_a",0)], itp_type_thrown |itp_merchandise|itp_primary|itp_next_item_as_melee,itcf_throw_axe,
1200, weight(6)|abundance(40)|difficulty(3)|spd_rtng(98) | shoot_speed(20) | thrust_damage(59,cut)|max_ammo(3)|accuracy(65)|weapon_length(53),imodbits_thrown_minus_heavy, [], [fac_kingdom_2,fac_kingdom_4] ],
["throwing_axes_melee", "Throwing Axe", [("throwing_axe_a",0)], itp_unique| itp_type_one_handed_wpn |itp_primary|itp_bonus_against_shield,itc_scimitar,
400, weight(2)|abundance(40)|difficulty(3)|spd_rtng(69) | swing_damage(34,cut)|weapon_length(53),imodbits_thrown_minus_heavy ],
 
["heavy_throwing_axes", "Heavy Throwing Axes", [("throwing_axe_b",0)], itp_type_thrown |itp_merchandise|itp_primary|itp_next_item_as_melee,itcf_throw_axe,
1800, weight(7.5)|abundance(30)|difficulty(5)|spd_rtng(97) | shoot_speed(22) | thrust_damage(64,cut)|max_ammo(3)|accuracy(65)|weapon_length(53),imodbits_thrown_minus_heavy,
 [], [fac_culture_2,fac_culture_4] ],
["heavy_throwing_axes_melee", "Heavy Throwing Axe", [("throwing_axe_b",0)], itp_unique| itp_type_one_handed_wpn |itp_primary|itp_bonus_against_shield,itc_scimitar,
600, weight(2.5)|abundance(30)|difficulty(5)|spd_rtng(69) | swing_damage(42,cut)|weapon_length(53),imodbits_thrown_minus_heavy ],



["hunting_bow",         "Hunting Bow", [("bow_hunting",0),("bow_hunting_carry",ixmesh_carry)],itp_type_bow |itp_merchandise|itp_primary|itp_two_handed,itcf_shoot_bow|itcf_carry_bow_back, 
170 , weight(1)|abundance(50)|difficulty(1)|spd_rtng(100) | shoot_speed(52) | thrust_damage(15 ,  pierce)|accuracy(55),imodbits_bow, [], [fac_kingdom_1,fac_kingdom_2,fac_kingdom_3,fac_kingdom_4] ],

["bamboo_bow",         "Bamboo Bow", [("bow_bamb",0),("bow_bamb_carry",ixmesh_carry)],itp_type_bow |itp_merchandise|itp_primary,itcf_shoot_bow|itcf_carry_bow_back, 
210 , weight(1.3)|abundance(50)|difficulty(2)|spd_rtng(90) | shoot_speed(52) | thrust_damage(18 ,  pierce)|accuracy(65),imodbits_bow, [], [fac_kingdom_6] ],

 
["short_bow",         "Short Bow", [("bow_short",0),("bow_short_carry",ixmesh_carry)], itp_type_bow |itp_merchandise|itp_primary ,itcf_shoot_bow|itcf_carry_bow_back, 
245 , weight(1)|abundance(50)|difficulty(3)|spd_rtng(97) | shoot_speed(55) | thrust_damage(18 ,  pierce  )|accuracy(70),imodbits_bow, [], [fac_kingdom_2,fac_kingdom_4] ],
["long_bow",         "Long Bow", [("bow_long",0),("bow_long_carry",ixmesh_carry)], itp_type_bow |itp_cant_use_on_horseback|itp_merchandise|itp_primary ,itcf_shoot_bow|itcf_carry_bow_back, 
980 , weight(2.75)|abundance(30)|difficulty(5)|spd_rtng(79) | shoot_speed(56) | thrust_damage(27 ,  pierce)|accuracy(100),imodbits_bow, [], [fac_culture_1] ],

["long_bow_v",         "Long Bow", [("bow_long_v",0),("bow_long_v_carry",ixmesh_carry)], itp_type_bow |itp_cant_use_on_horseback|itp_merchandise|itp_primary ,itcf_shoot_bow|itcf_carry_bow_back, 
880 , weight(2.75)|abundance(30)|difficulty(5)|spd_rtng(79) | shoot_speed(56) | thrust_damage(29 ,  pierce)|accuracy(90),imodbits_bow, [], [fac_culture_4,fac_kingdom_2] ],

["nomad_bow",         "Nomad Bow", [("bow_nomad",0),("bow_nomad_case", ixmesh_carry)], itp_type_bow |itp_merchandise|itp_primary ,itcf_shoot_bow|itcf_carry_bowcase_left|itcf_show_holster_when_drawn, 
264 , weight(1.25)|abundance(50)|difficulty(4)|spd_rtng(94) | shoot_speed(56) | thrust_damage(20 ,  pierce)|accuracy(60),imodbits_bow, [], [fac_kingdom_2,fac_kingdom_3,fac_kingdom_4,fac_kingdom_6] ],
["khergit_bow",         "Khergit Bow", [("bow_khergit",0),("bow_khergit_case", ixmesh_carry)], itp_type_bow |itp_merchandise|itp_primary,itcf_shoot_bow|itcf_carry_bowcase_left|itcf_show_holster_when_drawn, 
669 , weight(1.25)|abundance(30)|difficulty(6)|spd_rtng(90) | shoot_speed(57) | thrust_damage(26 ,pierce)|accuracy(85),imodbits_bow, [], [fac_culture_3] ],
 
["strong_bow",         "Strong Bow", [("bow_strong",0),("bow_strong_carry", ixmesh_carry)], itp_type_bow |itp_merchandise|itp_primary ,itcf_shoot_bow|itcf_carry_bow_back, 
1437 , weight(1.25)|abundance(10)|difficulty(7)|spd_rtng(88) | shoot_speed(68) | thrust_damage(33 ,pierce)|accuracy(65),imodbit_strong |imodbit_masterwork, [], [fac_culture_2,fac_culture_6] ],
["elit_bow",         "Strong Bow", [("bow_elit",0),("bow_elit_caryy", ixmesh_carry)], itp_type_bow |itp_merchandise|itp_primary ,itcf_shoot_bow|itcf_carry_bow_back, 
1237 , weight(1.25)|abundance(10)|difficulty(7)|spd_rtng(98) | shoot_speed(68) | thrust_damage(31 ,pierce)|accuracy(70),imodbit_strong |imodbit_masterwork, [], [fac_culture_3,fac_culture_6] ],

["war_bow",         "War Bow", [("bow_war",0),("bow_war_carry",ixmesh_carry)],itp_type_bow|itp_cant_use_on_horseback|itp_merchandise|itp_primary ,itcf_shoot_bow|itcf_carry_bow_back, 
1728 , weight(1.5)|abundance(10)|difficulty(7)|spd_rtng(88) | shoot_speed(80) | thrust_damage(35 ,pierce)|accuracy(85),imodbit_strong |imodbit_masterwork, [], [fac_culture_2,fac_culture_4]],
["bow_reinforsed",         "War Bow", [("bow_reinforsed",0),("bow_reinforsed_carry",ixmesh_carry)],itp_type_bow|itp_cant_use_on_horseback|itp_primary ,itcf_shoot_bow|itcf_carry_bow_back, 
728 , weight(1.5)|abundance(10)|difficulty(3)|spd_rtng(88) | shoot_speed(59) | thrust_damage(25 ,pierce)|accuracy(55),imodbit_strong |imodbit_masterwork, [], [fac_kingdom_2,fac_kingdom_4]],

 
["hunting_crossbow", "Hunting Crossbow", [("crossbow_d",0)], itp_type_crossbow |itp_primary|itp_two_handed ,
itc_parry_polearm|itcf_shoot_crossbow|itcf_carry_crossbow_back, 
122 , weight(2.25)|abundance(50)|difficulty(0)|spd_rtng(47) | shoot_speed(50) | thrust_damage(37 ,  pierce)|max_ammo(1)|accuracy(65),imodbits_crossbow, [], [fac_kingdom_1] ],
["light_crossbow", "Light Crossbow", [("crossbow_a",0)], itp_type_crossbow |itp_merchandise|itp_primary|itp_two_handed ,
itc_parry_polearm|itcf_shoot_crossbow|itcf_carry_crossbow_back, 
467 , weight(2.5)|abundance(20)|difficulty(0)|spd_rtng(52) | shoot_speed(59) | thrust_damage(44 ,  pierce)|max_ammo(1)|accuracy(75),imodbits_crossbow, [], [fac_kingdom_1] ],

["crossbow",         "Crossbow",         [("crossbow_b",0)], itp_type_crossbow |itp_cant_use_on_horseback|itp_merchandise|itp_primary|itp_two_handed ,
itc_parry_polearm|itcf_shoot_crossbow|itcf_carry_crossbow_back, 
682 , weight(3)|abundance(50)|difficulty(8)|spd_rtng(43) | shoot_speed(66) | thrust_damage(54,pierce)|max_ammo(1)|accuracy(65),imodbits_crossbow, [], [fac_kingdom_1,fac_culture_2] ],
["heavy_crossbow", "Heavy Crossbow", [("crossbow_c",0)], itp_type_crossbow |itp_cant_use_on_horseback|itp_merchandise|itp_primary|itp_two_handed ,
itc_parry_polearm|itcf_shoot_crossbow|itcf_carry_crossbow_back, 
749 , weight(3.5)|abundance(10)|difficulty(9)|spd_rtng(41) | shoot_speed(68) | thrust_damage(68 ,pierce)|max_ammo(1)|accuracy(65),imodbits_crossbow, [], [fac_culture_1,fac_culture_2] ],

["sniper_crossbow", "Siege Crossbow", [("crossbow_e",0)], itp_merchandise|itp_type_crossbow |itp_cant_use_on_horseback|itp_primary|itp_two_handed|itp_next_item_as_melee ,
itc_parry_polearm|itcf_shoot_crossbow|itcf_carry_crossbow_back, 
1683 , weight(3.75)|abundance(10)|difficulty(10)|spd_rtng(37) | shoot_speed(90) | thrust_damage(73 ,pierce)|max_ammo(1)|accuracy(85),imodbits_crossbow, [], [fac_culture_1] ],
 ["sniper_crossbow_melee",  "Siege Crossbow", [("crossbow_e",0)],  itp_type_two_handed_wpn|itp_can_knock_down|itp_primary|itp_wooden_parry, itc_crossbow|itcf_carry_axe_back,
1683 , weight(3.75)|abundance(10)|difficulty(10)|spd_rtng(85) | weapon_length(117)|swing_damage(34 , blunt) ,imodbits_mace , [], [fac_kingdom_1]],

["flintlock_pistol", "Flintlock Pistol", [("flintlock_pistol",0)], itp_type_pistol |itp_merchandise|itp_primary ,itcf_shoot_pistol|itcf_reload_pistol, 230 , weight(1.5)|difficulty(0)|spd_rtng(38) | shoot_speed(160) | thrust_damage(45 ,pierce)|max_ammo(1)|accuracy(65),imodbits_none,
 [(ti_on_weapon_attack, [(play_sound,"snd_pistol_shot"),(position_move_x, pos1,27),(position_move_y, pos1,36),(particle_system_burst, "psys_pistol_smoke", pos1, 15),(particle_system_burst, "psys_torch_fire", pos1, 15)])]],
 
["flintlock_pistol1", "Flintlock Pistol", [("flintlock_pistol",0)], itp_type_musket |itp_merchandise|itp_primary ,itcf_shoot_musket|itcf_reload_musket, 230 , weight(1.5)|difficulty(0)|spd_rtng(38) | shoot_speed(160) | thrust_damage(45 ,pierce)|max_ammo(1)|accuracy(65),imodbits_none,
 [(ti_on_weapon_attack, [(play_sound,"snd_pistol_shot"),(position_move_x, pos1,0),(position_move_y, pos1,96),(particle_system_burst, "psys_torch_smoke", pos1, 15),(particle_system_burst, "psys_torch_fire", pos1, 1)])]],
 
["torch",         "Torch", [("club",0)], itp_type_one_handed_wpn|itp_primary, itc_scimitar, 11 , weight(2.5)|difficulty(0)|spd_rtng(95) | weapon_length(95)|swing_damage(11 , blunt) | thrust_damage(0 ,  pierce),imodbits_none,
 [(ti_on_init_item, [(set_position_delta,0,60,0),(particle_system_add_new, "psys_torch_fire"),(particle_system_add_new, "psys_torch_smoke"),(set_current_color,150, 130, 70),(add_point_light, 10, 30),
])]],

["lyre",         "Lyre", [("lyre",0)], itp_type_shield|itp_wooden_parry|itp_civilian, itcf_carry_bow_back,  118 , weight(2.5)|hit_points(480)|body_armor(1)|spd_rtng(82)|weapon_length(90),0 ],
["lute",         "Lute", [("lute",0)], itp_type_shield|itp_wooden_parry|itp_civilian, itcf_carry_bow_back,  118 , weight(2.5)|hit_points(480)|body_armor(1)|spd_rtng(82)|weapon_length(90),0 ],

##["short_sword", "Short Sword",
## [("sword_norman",0),("sword_norman_scabbard", ixmesh_carry),("sword_norman_rusty",imodbit_rusty),("sword_norman_rusty_scabbard", ixmesh_carry|imodbit_rusty)],
## itp_type_one_handed_wpn|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn, 183 , weight(1.25)|difficulty(0)|spd_rtng(103) | weapon_length(75)|swing_damage(25 , cut) | thrust_damage(19 ,  pierce),imodbits_sword ],

["strange_armor",  "Strange Armor", [("samurai_armor",0)], itp_type_body_armor  |itp_covers_legs ,0, 1259 , weight(18)|abundance(100)|head_armor(0)|body_armor(38)|leg_armor(19)|difficulty(7) ,imodbits_armor ],
["strange_boots",  "Strange Boots", [("samurai_boots",0)], itp_type_foot_armor | itp_attach_armature,0, 465 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(21)|difficulty(0) ,imodbits_cloth ],
["strange_helmet", "Strange Helmet", [("samurai_helmet",0)], itp_type_head_armor   ,0, 824 , weight(2)|abundance(100)|head_armor(44)|body_armor(0)|leg_armor(0)|difficulty(7) ,imodbits_plate ],
["strange_sword", "Strange Sword", [("katana",0),("katana_scabbard",ixmesh_carry)], itp_type_two_handed_wpn| itp_primary, itc_bastardsword|itcf_carry_katana|itcf_show_holster_when_drawn, 679 , weight(2.0)|difficulty(9)|spd_rtng(108) | weapon_length(95)|swing_damage(32 , cut) | thrust_damage(18 ,  pierce),imodbits_sword ],
["strange_great_sword",  "Strange Great Sword", [("no_dachi",0),("no_dachi_scabbard",ixmesh_carry)], itp_type_two_handed_wpn|itp_two_handed|itp_primary, itc_nodachi|itcf_carry_sword_back|itcf_show_holster_when_drawn, 920 , weight(3.5)|difficulty(11)|spd_rtng(92) | weapon_length(125)|swing_damage(38 , cut) | thrust_damage(0 ,  pierce),imodbits_axe ],
["strange_short_sword", "Strange Short Sword", [("wakizashi",0),("wakizashi_scabbard",ixmesh_carry)], itp_type_one_handed_wpn|itp_primary, itc_longsword|itcf_carry_wakizashi|itcf_show_holster_when_drawn, 321 , weight(1.25)|difficulty(0)|spd_rtng(108) | weapon_length(65)|swing_damage(25 , cut) | thrust_damage(19 ,  pierce),imodbits_sword ],
["court_dress", "Court Dress", [("court_dress",0)], itp_type_body_armor|itp_covers_legs|itp_civilian   ,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(14)|leg_armor(4)|difficulty(0) ,imodbits_cloth ],
["rich_outfit", "Rich Outfit", [("merchant_outf",0)], itp_type_body_armor|itp_covers_legs|itp_civilian   ,0, 348 , weight(4)|abundance(100)|head_armor(0)|body_armor(16)|leg_armor(4)|difficulty(0) ,imodbits_cloth ],

["khergit_guard_armor", "Khergit Guard Armor", [("lamellar_armor_a",0)], itp_type_body_armor|itp_covers_legs   ,0, 
3048 , weight(25)|abundance(100)|head_armor(0)|body_armor(50)|leg_armor(18)|difficulty(0) ,imodbits_armor ],
 
["felt_steppe_cap", "Felt Steppe Cap", [("felt_steppe_cap",0)], itp_type_head_armor|itp_civilian   ,0, 237 , weight(2)|abundance(100)|head_armor(16)|body_armor(0)|leg_armor(0) ,imodbits_cloth ],

["khergit_war_helmet", "Khergit War Helmet", [("tattered_steppe_cap_a_new",0)], itp_type_head_armor | itp_merchandise   ,0,
 500 , weight(2)|difficulty(10)|abundance(50)|head_armor(36)|body_armor(0)|leg_armor(0) ,imodbits_armor , [], [fac_kingdom_3]],
 ["khergit_katafrakt_helmet", "Khergit Katafrakt Helmet", [("kergit_katafrakt_helmet",0)], itp_type_head_armor | itp_merchandise   ,0,
 700 , weight(3)|difficulty(15)|abundance(30)|head_armor(46)|body_armor(0)|leg_armor(0) ,imodbits_armor , [], [fac_culture_3]],
["khergit_helmet", "Khergit Helmet", [("khergit_guard_helmet",0)], itp_type_head_armor   ,0,
 361 , weight(2)|abundance(100)|head_armor(33)|body_armor(0)|leg_armor(0) ,imodbits_armor ],
["khergit_guard_boots",  "Khergit Guard Boots", [("lamellar_boots_a",0)], itp_type_foot_armor | itp_attach_armature,0,
 254 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(20)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_3]],
["khergit_guard_helmet", "Khergit Guard Helmet", [("lamellar_helmet_a",0)], itp_type_head_armor    ,0,
 433 , weight(2)|abundance(100)|head_armor(40)|body_armor(0)|leg_armor(0) ,imodbits_armor , [], [fac_kingdom_3]],
["khergit_cavalry_helmet", "Khergit Cavalry Helmet", [("lamellar_helmet_b",0)], itp_type_head_armor    ,0,
 333 , weight(2)|abundance(100)|head_armor(36)|body_armor(0)|leg_armor(0) ,imodbits_armor , [], [fac_kingdom_3]],



["byzantion_helmet_a", "Byzantion Helmet", [("byzantion_helmet_a",0)], itp_type_head_armor   ,0, 278 , weight(2)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0) ,imodbits_cloth ],
["magyar_helmet_a", "Magyar Helmet", [("magyar_helmet_a",0)], itp_type_head_armor   ,0, 278 , weight(2)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0) ,imodbits_cloth ],
["rus_helmet_a", "Rus Helmet", [("rus_helmet_a",0)], itp_type_head_armor   ,0, 278 , weight(2)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0) ,imodbits_cloth ],
["sipahi_helmet_a", "Sipahi Helmet", [("sipahi_helmet_a",0)], itp_type_head_armor   ,0, 278 , weight(2)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0) ,imodbits_cloth ],
["shahi", "Shahi", [("shahi",0)], itp_type_head_armor   ,0, 278 , weight(2)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0) ,imodbits_cloth ],
["rabati", "Rabati", [("rabati",0)], itp_type_head_armor   ,0, 278 , weight(2)|abundance(100)|head_armor(20)|body_armor(0)|leg_armor(0) ,imodbits_cloth ],

["keys", "Ring of Keys", [("throwing_axe_a",0)], itp_type_one_handed_wpn |itp_primary|itp_bonus_against_shield,itc_scimitar,
240, weight(5)|spd_rtng(98) | swing_damage(29,cut)|max_ammo(5)|weapon_length(53),imodbits_thrown ], 
["bride_dress", "Bride Dress", [("bride_dress",0)], itp_type_body_armor  |itp_covers_legs|itp_civilian ,0, 500 , weight(3)|abundance(100)|head_armor(0)|body_armor(10)|leg_armor(10)|difficulty(0) ,imodbits_cloth],
["bride_crown", "Crown of Flowers", [("bride_crown",0)],  itp_type_head_armor | itp_doesnt_cover_hair |itp_civilian |itp_attach_armature,0, 1 , weight(0.5)|abundance(100)|head_armor(4)|body_armor(0)|leg_armor(0)|difficulty(0) ,imodbits_cloth ],
["bride_shoes", "Bride Shoes", [("bride_shoes",0)], itp_type_foot_armor |itp_civilian | itp_attach_armature ,0,
 30 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(8)|difficulty(0) ,imodbits_cloth ],

["practice_bow_2","Practice Bow", [("hunting_bow",0), ("hunting_bow_carry",ixmesh_carry)], itp_type_bow |itp_primary|itp_two_handed,itcf_shoot_bow|itcf_carry_bow_back, 0, weight(1.5)|spd_rtng(90) | shoot_speed(40) | thrust_damage(21, blunt),imodbits_bow ],
["practice_arrows_2","Practice Arrows", [("arena_arrow",0),("flying_missile",ixmesh_flying_ammo),("quiver", ixmesh_carry)], itp_type_arrows, itcf_carry_quiver_back, 0,weight(1.5)|weapon_length(95)|max_ammo(80),imodbits_missile],



["heraldic_mail_with_surcoat_for_tableau", "{!}Heraldic Mail with Surcoat", [("heraldic_armor_new_a",0)], itp_type_body_armor |itp_covers_legs ,0,
 1, weight(22)|abundance(100)|head_armor(0)|body_armor(1)|leg_armor(1),imodbits_armor,
 [(ti_on_init_item, [(store_trigger_param_1, ":agent_no"),(store_trigger_param_2, ":troop_no"),(call_script, "script_shield_item_set_banner", "tableau_heraldic_armor_a", ":agent_no", ":troop_no")])]],
["mail_boots_for_tableau", "Mail Boots", [("mail_boots_a",0)], itp_type_foot_armor | itp_attach_armature  ,0,
 1, weight(3)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(1) ,imodbits_armor ],

# SWAD itemc  weapon





# SARRANIDS itemc  weapon

["sword_khergit_1", "Nomad Sabre", [("khergit_sword_b",0),("khergit_sword_b_scabbard", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_scimitar|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn,
 105 , weight(1.25)|difficulty(5)|spd_rtng(100) | weapon_length(87)|swing_damage(19 , cut),imodbits_sword_high , [], [fac_kingdom_6]],
["arabian_sword_a",         "Sarranid Sword", [("arabian_sword_a",0),("scab_arabian_sword_a", ixmesh_carry)], itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_scimitar|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn, 
108 , weight(1.5)|difficulty(7)|spd_rtng(99) | weapon_length(87)|swing_damage(19 , cut) | thrust_damage(0 ,  pierce),imodbits_sword_high , [], [fac_kingdom_6]],
["arabian_sword_b",         "Sarranid Arming Sword", [("arabian_sword_b",0),("scab_arabian_sword_b", ixmesh_carry)],
 itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_scimitar|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn, 
218 , weight(1.7)|difficulty(9)|spd_rtng(99) | weapon_length(97)|swing_damage(28 , cut) | thrust_damage(19 ,  pierce),imodbits_sword_high , [], [fac_kingdom_6]],
["sarranid_cavalry_sword",         "Sarranid Cavalry Sword", [("arabian_sword_c",0),("scab_arabian_sword_c", ixmesh_carry)], itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn, 
710 , weight(1.5)|difficulty(9)|spd_rtng(98) | weapon_length(105)|swing_damage(32 , cut) | thrust_damage(19 ,  pierce),imodbits_sword_high , [], [fac_kingdom_6]],
["arabian_sword_d",         "Sarranid Guard Sword", [("arabian_sword_d",0),("scab_arabian_sword_d", ixmesh_carry)], itp_type_one_handed_wpn|itp_merchandise|itp_primary, itc_longsword|itcf_carry_sword_left_hip|itcf_show_holster_when_drawn, 
990 , weight(1.7)|difficulty(10)|spd_rtng(99) | weapon_length(97)|swing_damage(37 , cut) | thrust_damage(20 ,  pierce),imodbits_sword_high , [], [fac_kingdom_6]],
["sarranid_two_handed_mace_1",         "Iron Mace", [("mace_long_d",0)],
 itp_type_two_handed_wpn|itp_merchandise| itp_primary|itp_can_knock_down|itp_bonus_against_shield|itp_unbalanced , itc_morningstar|itcf_carry_axe_back,
970 , weight(4.5)|difficulty(15)|spd_rtng(70) | weapon_length(105)|swing_damage(55 , blunt) | thrust_damage(0 ,  blunt),imodbits_mace , [], [fac_kingdom_6]],
["sarranid_mace_1",         "Iron Mace", [("mace_small_d",0)],
 itp_type_one_handed_wpn|itp_merchandise|itp_can_knock_down |itp_primary|itp_bonus_against_shield|itp_unbalanced, itc_scimitar|itcf_carry_mace_left_hip,
 345 , weight(2.0)|difficulty(12)|spd_rtng(79) | weapon_length(73)|swing_damage(22 , blunt) | thrust_damage(0 ,  pierce),imodbits_mace , [], [fac_kingdom_6]],
["sarranid_axe_a", "Iron Battle Axe", [("one_handed_battle_axe_g",0)], itp_type_one_handed_wpn|itp_merchandise| itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_axe_left_hip,
 250 , weight(1.65)|difficulty(9)|spd_rtng(87) | weapon_length(71)|swing_damage(35 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_kingdom_6]],
["sarranid_axe_b", "Iron War Axe", [("one_handed_battle_axe_h",0)], itp_type_one_handed_wpn|itp_merchandise| itp_primary|itp_secondary|itp_bonus_against_shield|itp_wooden_parry, itc_scimitar|itcf_carry_axe_left_hip,
 360 , weight(1.75)|difficulty(9)|spd_rtng(87) | weapon_length(71)|swing_damage(38 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_kingdom_6]],
["sarranid_two_handed_axe_a",         "Sarranid Battle Axe", [("two_handed_battle_axe_g",0)], itp_type_two_handed_wpn|itp_two_handed|itp_primary|itp_bonus_against_shield|itp_unbalanced, itc_nodachi|itcf_carry_axe_back,
 350 , weight(3.0)|difficulty(10)|spd_rtng(79) | weapon_length(95)|swing_damage(49 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_kingdom_6]],
["sarranid_two_handed_axe_b",         "Sarranid War Axe", [("two_handed_battle_axe_h",0)], itp_type_two_handed_wpn|itp_two_handed|itp_primary|itp_bonus_against_shield|itp_unbalanced, itc_nodachi|itcf_carry_axe_back,
 280 , weight(2.50)|difficulty(10)|spd_rtng(80) | weapon_length(90)|swing_damage(46 , cut) | thrust_damage(0 ,  pierce),imodbits_axe , [], [fac_kingdom_6]],






["nomad_armor", "Nomad Armor", [("nomad_armor_new",0)], itp_merchandise| itp_type_body_armor |itp_covers_legs   ,0,
 75 , weight(6)|abundance(100)|head_armor(0)|body_armor(24)|leg_armor(7)|difficulty(7) ,imodbits_cloth, [], [fac_kingdom_3] ],
["khergit_armor", "Khergit Armor", [("khergit_armor_new",0)], itp_merchandise| itp_type_body_armor | itp_covers_legs ,0,
 78 , weight(6)|abundance(100)|head_armor(0)|body_armor(24)|leg_armor(7)|difficulty(7) ,imodbits_cloth, [], [fac_kingdom_3] ],




["pelt_coat", "Pelt Coat", [("thick_coat_a",0)],  itp_merchandise|itp_type_body_armor  |itp_covers_legs ,0,
 44, weight(2)|abundance(100)|head_armor(0)|body_armor(9)|leg_armor(1)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_2,fac_kingdom_4]], 
["leather_jacket", "Leather Jacket", [("leather_jacket_new",0)], itp_merchandise| itp_type_body_armor | itp_covers_legs  |itp_civilian ,0,
 79 , weight(6)|abundance(100)|head_armor(0)|body_armor(24)|leg_armor(6)|difficulty(7) ,imodbits_cloth , [], [fac_kingdom_2,fac_kingdom_4]],
["rawhide_coat", "Rawhide Coat", [("coat_of_plates_b",0)], itp_merchandise| itp_type_body_armor |itp_civilian |itp_covers_legs ,0,
 72 , weight(5)|abundance(100)|head_armor(0)|body_armor(18)|leg_armor(6)|difficulty(7) ,imodbits_cloth, [], [fac_kingdom_2,fac_kingdom_4] ],
["fur_coat", "Fur Coat", [("fur_coat",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs |itp_civilian,0,
 117 , weight(6)|abundance(100)|head_armor(0)|body_armor(18)|leg_armor(6)|difficulty(9) ,imodbits_armor, [], [fac_kingdom_2,fac_kingdom_4] ],



["tunic_with_green_cape", "Tunic with Green Cape", [("peasant_man_a",0)], itp_merchandise| itp_type_body_armor  |itp_covers_legs|itp_civilian ,0,
 46 , weight(1)|abundance(100)|head_armor(0)|body_armor(6)|leg_armor(2)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_1]], 


["leather_armor", "Leather Armor", [("tattered_leather_armor_a",0)], itp_merchandise| itp_type_body_armor |itp_covers_legs  ,0,
 165 , weight(7)|abundance(100)|head_armor(0)|body_armor(24)|leg_armor(9)|difficulty(9) ,imodbits_cloth, [], [fac_kingdom_1] ],
["black_hood", "Black Hood", [("hood_black",0)], itp_type_head_armor|itp_merchandise   ,0,
 193 , weight(2)|abundance(100)|head_armor(18)|body_armor(0)|leg_armor(0) ,imodbits_cloth , [], [fac_kingdom_1]],
["light_leather", "Light Leather", [("light_leather",0)], itp_type_body_armor|itp_covers_legs|itp_merchandise   ,0,
 352 , weight(5)|abundance(100)|head_armor(0)|body_armor(26)|leg_armor(7)|difficulty(0) ,imodbits_armor , [], [fac_kingdom_1]],
["light_leather_boots",  "Light Leather Boots", [("light_leather_boots",0)], itp_type_foot_armor |itp_merchandise| itp_attach_armature,0,
 91 , weight(1)|abundance(100)|head_armor(0)|body_armor(0)|leg_armor(15)|difficulty(0) ,imodbits_cloth , [], [fac_kingdom_1]],
 
["mail_and_plate", "Mail and Plate", [("mail_and_plate",0)], itp_type_body_armor|itp_covers_legs|itp_merchandise   ,0,
 1793 , weight(16)|abundance(20)|head_armor(0)|body_armor(54)|leg_armor(22)|difficulty(17) ,imodbits_armor , [], [fac_kingdom_1]],
["light_mail_and_plate", "Light Mail and Plate", [("light_mail_and_plate",0)], itp_type_body_armor|itp_covers_legs|itp_merchandise   ,0,
 1732 , weight(10)|abundance(20)|head_armor(0)|body_armor(52)|leg_armor(22)|difficulty(17) ,imodbits_armor , [], [fac_kingdom_1]],
 
["nord_armor_new", "mail and Plate", [("nord_armor_new",0)], itp_type_body_armor|itp_covers_legs   ,0,
 1093 , weight(16)|abundance(20)|head_armor(0)|body_armor(44)|leg_armor(12)|difficulty(14) ,imodbits_armor , [], [fac_culture_4]],
 
["bosshunter_leather_armor", "Leather Armor", [("bosshunter",0)], itp_unique| itp_type_body_armor |itp_covers_legs  ,0,
 1565 , weight(7)|abundance(10)|head_armor(0)|body_armor(37)|leg_armor(11)|difficulty(9) ,imodbits_cloth, [], [fac_culture_1] ],
["bosshunter_leather_boots", "Boots", [("bosshunter_boots",0)], itp_merchandise| itp_type_foot_armor | itp_attach_armature,0,
 770 , weight(1.5)|abundance(20)|head_armor(0)|body_armor(0)|leg_armor(23)|difficulty(9) ,imodbits_cloth, [], [fac_culture_1] ],
["bosshunter_helmet", "Helmet", [("bosshunter_helmet",0)], itp_unique|itp_type_head_armor   ,0,
 1293 , weight(3)|abundance(10)|head_armor(38)|body_armor(0)|leg_armor(0)|difficulty(14) ,imodbits_armor , [], [fac_culture_1]],
 
["vaegr_guard_helmet", "Elit Helmet", [("vaegr_guard_helmet",0)], itp_unique|itp_type_head_armor   ,0,
 2293 , weight(3)|abundance(10)|head_armor(58)|body_armor(0)|leg_armor(0)|difficulty(19) ,imodbits_armor , [], [fac_culture_4]],
["vaegr_guard_gauntlets","Gauntlets", [("vaegr_guard_L",0)], itp_unique|itp_type_hand_armor,0,
 1440, weight(1.5)|abundance(20)|body_armor(11)|difficulty(19),imodbits_armor, [], [fac_culture_4]],
["vaegr_guard_boots", "Elit Boots", [("vaegr_guard_boots",0)], itp_merchandise| itp_type_foot_armor | itp_attach_armature,0,
 2770 , weight(5.5)|abundance(20)|head_armor(0)|body_armor(0)|leg_armor(43)|difficulty(19) ,imodbits_plate, [], [fac_culture_4] ],
 
["elit_glv_khergit","Gauntlets", [("elit_glv_khergit_L",0)], itp_merchandise|itp_type_hand_armor,0,
 1040, weight(1.0)|abundance(20)|body_armor(14)|difficulty(18),imodbits_armor, [], [fac_culture_3]],
["elit_helmet_khergit", "Khergit Elit Helmet", [("elit_helmet_khergit",0)], itp_type_head_armor | itp_merchandise   ,0,
 700 , weight(3)|difficulty(18)|abundance(30)|head_armor(46)|body_armor(0)|leg_armor(0) ,imodbits_armor , [], [fac_culture_3]],
["elit_boots_khergit", "Khergit Elit Boots", [("elit_boots_khergit",0)], itp_merchandise| itp_type_foot_armor | itp_attach_armature,0,
 2770 , weight(5.5)|abundance(20)|head_armor(0)|body_armor(0)|leg_armor(43)|difficulty(18) ,imodbits_plate, [], [fac_culture_3] ],

 
["elit_vaeg_helmet", "Veager Katafrakt Helmet", [("vaeg_helmet_11",0)], itp_type_head_armor | itp_merchandise   ,0,
 700 , weight(3)|difficulty(15)|abundance(30)|head_armor(46)|body_armor(0)|leg_armor(0) ,imodbits_armor , [], [fac_culture_2]],
 
["looter_armor_new", "mail", [("looter_mail_6",0)], itp_merchandise|itp_type_body_armor|itp_covers_legs   ,0,
 593 , weight(16)|abundance(20)|head_armor(0)|body_armor(34)|leg_armor(6)|difficulty(8) ,imodbits_armor , [], [fac_kingdom_2,fac_kingdom_4]], 
["looter_armor_2_new", "mail", [("looter_mail_1",0)], itp_merchandise|itp_type_body_armor|itp_covers_legs   ,0,
 593 , weight(16)|abundance(20)|head_armor(0)|body_armor(34)|leg_armor(6)|difficulty(8) ,imodbits_armor , [], [fac_kingdom_2,fac_kingdom_4]],  
 ["looter_armor_3_new", "mail", [("looter_mail_2",0)], itp_merchandise|itp_type_body_armor|itp_covers_legs   ,0,
 593 , weight(16)|abundance(20)|head_armor(0)|body_armor(34)|leg_armor(6)|difficulty(8) ,imodbits_armor , [], [fac_kingdom_2,fac_kingdom_4]],  
 ["looter_armor_4_new", "mail", [("looter_mail_3",0)], itp_merchandise|itp_type_body_armor|itp_covers_legs   ,0,
 593 , weight(16)|abundance(20)|head_armor(0)|body_armor(34)|leg_armor(6)|difficulty(8) ,imodbits_armor , [], [fac_kingdom_2,fac_kingdom_4]],  
 ["looter_armor_5_new", "mail", [("looter_mail_4",0)], itp_merchandise|itp_type_body_armor|itp_covers_legs   ,0,
 593 , weight(16)|abundance(20)|head_armor(0)|body_armor(24)|leg_armor(6)|difficulty(8) ,imodbits_armor , [], [fac_kingdom_2,fac_kingdom_4]],  
  ["looter_armor_6_new", "mail", [("looter_mail_5",0)], itp_merchandise|itp_type_body_armor|itp_covers_legs   ,0,
 593 , weight(16)|abundance(20)|head_armor(0)|body_armor(24)|leg_armor(6)|difficulty(8) ,imodbits_armor , [], [fac_kingdom_2,fac_kingdom_4]], 
 ["looter_shield_pavise", "Board Shield",   [("looter_shield_pavise" ,0)], itp_type_shield|itp_cant_use_on_horseback|itp_wooden_parry, itcf_carry_board_shield,  
 518 , weight(3.5)|difficulty(4)|hit_points(480)|body_armor(3)|spd_rtng(82)|shield_width(43)|shield_height(100),imodbits_shield, [], [fac_kingdom_2,fac_kingdom_4]  ],
 
["zzz_byrnie_a_new", "cloth", [("zzz_byrnie_a_new",0)], itp_merchandise|itp_type_body_armor|itp_covers_legs   ,0,
 593 , weight(16)|abundance(20)|head_armor(0)|body_armor(34)|leg_armor(6)|difficulty(8) ,imodbits_cloth , [], [fac_kingdom_2,fac_kingdom_4]], 
 
["torch1",         "Torch", [("mace_long_b",0)], itp_type_one_handed_wpn|itp_primary, 0,
 1100000 , weight(2.5)|difficulty(0)|spd_rtng(95) | weapon_length(95)|swing_damage(11 , blunt) | thrust_damage(0 ,  pierce),imodbits_none,
 [(ti_on_init_item, [
     (set_position_delta,0,110,0),
     (particle_system_add_new, "psys_torch_fire"),
     (particle_system_add_new, "psys_torch_smoke"),
     (set_current_color,150, 130, 70),
     (add_point_light, 10, 30),
             
])]],
["torch2",         "Torch", [("mace_long_b",0)], itp_type_one_handed_wpn|itp_primary, 0,
 1100000 , weight(2.5)|difficulty(0)|spd_rtng(95) | weapon_length(95)|swing_damage(11 , blunt) | thrust_damage(0 ,  pierce),imodbits_none,
 [(ti_on_init_item, [
     (set_position_delta,0,110,0),
     (particle_system_add_new, "psys_torch_fire"),
     (particle_system_add_new, "psys_torch_smoke"),
     (set_current_color,150, 130, 70),
     (add_point_light, 10, 30),
     (store_trigger_param_1, ":agent_no"),
               (agent_is_alive, ":agent_no"),          
               (agent_get_troop_id, ":troop_id", ":agent_no"),
               (agent_get_party_id, ":agent_party", ":agent_no"),    
               (store_skill_level,":skill","skl_leadership",":troop_id"),
               (store_character_level,":skill_2",":troop_id"),
#               (val_mul, ":skill", 3),
               (val_mul, ":skill_2", 50),
               (val_min, ":skill_2", 1500),
         
               (agent_get_position, pos14, ":agent_no"),
                 (try_for_agents, ":agent_2_no"),
                    (agent_is_alive, ":agent_2_no"),
                    (agent_get_party_id, ":agent_2_party", ":agent_2_no"),
                    (neq,":agent_2_party",":agent_party"),          
                    (agent_get_position, pos16, ":agent_2_no"),          
                    (get_distance_between_positions, ":agent_distance_to_target", pos16, pos14),          
                    (lt, ":agent_distance_to_target", ":skill_2"),          
                    (agent_deliver_damage_to_agent_advanced, ":skill", ":agent_no", ":agent_2_no", ":skill","itm_flintlock_pistol"),
                    (particle_system_burst, "psys_village_fire_big", pos14, 35),
                    (particle_system_burst, "psys_night_smoke_1", pos14, 155),
                 (try_end),               
])]],
["catapult","Catapult", [("Catapult",0)], itp_type_goods, 0, 12000,weight(50)|abundance(20),imodbits_none, [], [fac_commoners]],
["trebuchet","Trebuchet", [("trebuchet_old",0)], itp_type_goods, 0, 15000,weight(50)|abundance(20),imodbits_none, [], [fac_commoners]],
["belfry","Belfry", [("belfry_a",0)], itp_type_goods, 0, 5000,weight(50)|abundance(50),imodbits_none, [], [fac_commoners]],
["siege_ladder","Siege ladder", [("siege_ladder_move_6m",0)], itp_type_goods, 0, 100,weight(50)|abundance(60),imodbits_none, [], [fac_commoners]],
["siege_stone","Siege stones", [("stone_ball",0)], itp_type_goods, 0, 100,weight(50),imodbits_none, [], [fac_commoners]],
["items_end", "Items End", [("shield_round_a",0)], 0, 0, 1, 0, 0],
]
